@@ -65,14 +65,14 @@ typedef struct {
 } helper_arrays;
 
 /* soft constraint contributions function (interior-loops) */
-typedef FLT_OR_DBL (sc_int)(vrna_fold_compound_t *,
+typedef FLT_OR_DBL (*sc_int)(vrna_fold_compound_t *,
                             int,
                             int,
                             int,
                             int);
 
 /* QI5 contribution function for unpaired probability computations */
-typedef void (add_QI5)(FLT_OR_DBL **,
+typedef void (*add_QI5)(FLT_OR_DBL **,
                        int,
                        int,
                        FLT_OR_DBL,
@@ -126,7 +126,7 @@ compute_probs(vrna_fold_compound_t        *vc,
               int                         j,
               helper_arrays               *aux_arrays,
               int                         ulength,
-              vrna_probs_window_callback  *cb,
+              vrna_probs_window_f  cb,
               void                        *data,
               unsigned int                options,
               int                         *ov);
@@ -156,7 +156,7 @@ compute_pU(vrna_fold_compound_t       *vc,
            int                        k,
            int                        ulength,
            helper_arrays              *aux_arrays,
-           vrna_probs_window_callback *cb,
+           vrna_probs_window_f cb,
            void                       *data,
            unsigned int               options);
 
@@ -171,7 +171,7 @@ return_pU(int                         size,
           int                         i,
           int                         max_size,
           helper_arrays               *aux_arrays,
-          vrna_probs_window_callback  *cb,
+          vrna_probs_window_f  cb,
           void                        *data,
           unsigned int                options);
 
@@ -405,7 +405,7 @@ return_pU(int                         size,
           int                         i,
           int                         max_size,
           helper_arrays               *aux_arrays,
-          vrna_probs_window_callback  *cb,
+          vrna_probs_window_f  cb,
           void                        *data,
           unsigned int                options)
 {
@@ -476,7 +476,7 @@ allocate_dp_matrices(vrna_fold_compound_t *vc,
         if (sc->exp_energy_up)
           sc->exp_energy_up[i] = (FLT_OR_DBL *)vrna_alloc((winSize + 1) * sizeof(FLT_OR_DBL));
 
-        vrna_sc_update(vc, i, VRNA_OPTION_PF | VRNA_OPTION_WINDOW);
+        vrna_sc_update(vc, i, VRNA_OPTION_PF | VRNA_OPTION_WINDOW_F5);
       }
 
       break;
@@ -491,15 +491,15 @@ PRIVATE INLINE void
 free_dp_matrices(vrna_fold_compound_t *vc,
                  unsigned int         options)
 {
-  size_t        i;
+  size_t        i, n;
   char          **ptype;
-  int           n, winSize;
+  int           winSize;
   FLT_OR_DBL    **pR, **q, **qb, **qm, **qm2, **QI5, **qmb, **q2l;
   vrna_mx_pf_t  *mx;
   vrna_hc_t     *hc;
   vrna_sc_t     *sc;
 
-  n       = (int)vc->length;
+  n       = (size_t)vc->length;
   winSize = vc->window_size;
   mx      = vc->exp_matrices;
   pR      = mx->pR;
@@ -510,7 +510,11 @@ free_dp_matrices(vrna_fold_compound_t *vc,
   hc      = vc->hc;
   sc      = vc->sc;
 
-  for (i = MAX2(1, n - (winSize + MAXLOOP)); i <= n; i++) {
+  i = 1;
+  if (n > winSize + MAXLOOP)
+    i = n - winSize - MAXLOOP;
+
+  for (; i <= n; i++) {
     free(pR[i] + i);
     free(q[i] + i);
     free(qb[i] + i);
@@ -649,8 +653,8 @@ init_constraints(vrna_fold_compound_t *fc,
 
   for (j = 1; j <= max_j; j++) {
     make_ptypes(fc, j);
-    vrna_hc_update(fc, j, VRNA_CONSTRAINT_WINDOW_UPDATE_5);
-    vrna_sc_update(fc, j, VRNA_OPTION_PF | VRNA_OPTION_WINDOW);
+    vrna_hc_update(fc, j, VRNA_OPTION_WINDOW_F5);
+    vrna_sc_update(fc, j, VRNA_OPTION_PF | VRNA_OPTION_WINDOW_F5);
   }
 }
 
@@ -662,8 +666,8 @@ rotate_constraints(vrna_fold_compound_t *fc,
 {
   if (j + 1 <= fc->length) {
     make_ptypes(fc, j + 1);
-    vrna_hc_update(fc, j + 1, VRNA_CONSTRAINT_WINDOW_UPDATE_5);
-    vrna_sc_update(fc, j + 1, VRNA_OPTION_PF | VRNA_OPTION_WINDOW);
+    vrna_hc_update(fc, j + 1, VRNA_OPTION_WINDOW_F5);
+    vrna_sc_update(fc, j + 1, VRNA_OPTION_PF | VRNA_OPTION_WINDOW_F5);
   }
 }
 
@@ -672,7 +676,7 @@ PUBLIC int
 vrna_probs_window(vrna_fold_compound_t        *vc,
                   int                         ulength,
                   unsigned int                options,
-                  vrna_probs_window_callback  *cb,
+                  vrna_probs_window_f  cb,
                   void                        *data)
 {
   unsigned char       hc_decompose;
@@ -1021,7 +1025,7 @@ compute_probs(vrna_fold_compound_t        *vc,
               int                         j,
               helper_arrays               *aux_arrays,
               int                         ulength,
-              vrna_probs_window_callback  *cb,
+              vrna_probs_window_f  cb,
               void                        *data,
               unsigned int                options,
               int                         *ov)
@@ -1037,8 +1041,8 @@ compute_probs(vrna_fold_compound_t        *vc,
   vrna_md_t         *md;
   vrna_hc_t         *hc;
   vrna_sc_t         *sc;
-  sc_int            *sc_int_f;
-  add_QI5           *add_QI5_f;
+  sc_int            sc_int_f;
+  add_QI5           add_QI5_f;
 
   max_real = (sizeof(FLT_OR_DBL) == sizeof(float)) ? FLT_MAX : DBL_MAX;
 
@@ -1541,7 +1545,7 @@ compute_pU(vrna_fold_compound_t       *vc,
            int                        k,
            int                        ulength,
            helper_arrays              *aux_arrays,
-           vrna_probs_window_callback *cb,
+           vrna_probs_window_f cb,
            void                       *data,
            unsigned int               options)
 {
