@@ -1,6 +1,21 @@
 #ifndef VIENNA_RNA_PACKAGE_BOLTZMANN_SAMPLING_H
 #define VIENNA_RNA_PACKAGE_BOLTZMANN_SAMPLING_H
 
+#ifdef VRNA_WARN_DEPRECATED
+# if defined(DEPRECATED)
+#   undef DEPRECATED
+# endif
+# if defined(__clang__)
+#  define DEPRECATED(func, msg) func __attribute__ ((deprecated("", msg)))
+# elif defined(__GNUC__)
+#  define DEPRECATED(func, msg) func __attribute__ ((deprecated(msg)))
+# else
+#  define DEPRECATED(func, msg) func
+# endif
+#else
+# define DEPRECATED(func, msg) func
+#endif
+
 /**
  *  @file boltzmann_sampling.h
  *  @ingroup subopt_and_representatives
@@ -31,7 +46,7 @@
  *  @brief  Boltzmann sampling flag indicating non-redundant backtracing mode
  *
  *  This flag will turn the Boltzmann sampling into non-redundant backtracing
- *  mode along the lines of Michalik et al. 2017 @cite michalik:2017
+ *  mode along the lines of @rstinline :cite:t:`michalik:2017` @endrst
  *
  *  @see    vrna_pbacktrack5_num(), vrna_pbacktrack5_cb(), vrna_pbacktrack5_resume(),
  *          vrna_pbacktrack5_resume_cb(), vrna_pbacktrack_num(), vrna_pbacktrack_cb(),
@@ -54,9 +69,14 @@
  * @param structure The secondary structure in dot-bracket notation
  * @param data      Some arbitrary, auxiliary data address as provided to the calling function
  */
-typedef void (vrna_boltzmann_sampling_callback)(const char  *structure,
+typedef void (*vrna_bs_result_f)(const char  *structure,
                                                 void        *data);
 
+DEPRECATED(typedef void (vrna_boltzmann_sampling_callback)(const char  *structure,
+                                                void        *data),
+           "Use vrna_bs_result_f instead!");
+
+
 /**
  *  @brief  Boltzmann sampling memory data structure
  *
@@ -85,16 +105,18 @@ typedef struct vrna_pbacktrack_memory_s *vrna_pbacktrack_mem_t;
  *
  *  The structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -119,20 +141,22 @@ vrna_pbacktrack5(vrna_fold_compound_t *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -170,23 +194,25 @@ vrna_pbacktrack5_num(vrna_fold_compound_t *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5() and vrna_pbacktrack5_num() this function yields the
  *  structure samples through a callback mechanism.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -214,7 +240,7 @@ unsigned int
 vrna_pbacktrack5_cb(vrna_fold_compound_t              *fc,
                     unsigned int                      num_samples,
                     unsigned int                      length,
-                    vrna_boltzmann_sampling_callback  *cb,
+                    vrna_bs_result_f  cb,
                     void                              *data,
                     unsigned int                      options);
 
@@ -228,15 +254,17 @@ vrna_pbacktrack5_cb(vrna_fold_compound_t              *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5_cb() this function allows for resuming a previous
  *  sampling round in specialized Boltzmann sampling, such as non-redundant backtracking.
@@ -268,8 +296,8 @@ vrna_pbacktrack5_cb(vrna_fold_compound_t              *fc,
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -294,7 +322,7 @@ vrna_pbacktrack5_cb(vrna_fold_compound_t              *fc,
  *  @return               A set of secondary structure samples in dot-bracket notation terminated by NULL (or NULL on error)
  */
 char **
-vrna_pbacktrack5_resume(vrna_fold_compound_t  *vc,
+vrna_pbacktrack5_resume(vrna_fold_compound_t  *fc,
                         unsigned int          num_samples,
                         unsigned int          length,
                         vrna_pbacktrack_mem_t *nr_mem,
@@ -310,15 +338,17 @@ vrna_pbacktrack5_resume(vrna_fold_compound_t  *vc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5_resume() this function yields the structure samples
  *  through a callback mechanism.
@@ -351,8 +381,8 @@ vrna_pbacktrack5_resume(vrna_fold_compound_t  *vc,
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -382,7 +412,7 @@ unsigned int
 vrna_pbacktrack5_resume_cb(vrna_fold_compound_t             *fc,
                            unsigned int                     num_samples,
                            unsigned int                     length,
-                           vrna_boltzmann_sampling_callback *cb,
+                           vrna_bs_result_f cb,
                            void                             *data,
                            vrna_pbacktrack_mem_t            *nr_mem,
                            unsigned int                     options);
@@ -396,16 +426,18 @@ vrna_pbacktrack5_resume_cb(vrna_fold_compound_t             *fc,
  *
  *  The structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -427,20 +459,22 @@ vrna_pbacktrack(vrna_fold_compound_t *fc);
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -475,23 +509,25 @@ vrna_pbacktrack_num(vrna_fold_compound_t  *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack() and vrna_pbacktrack_num() this function yields the
  *  structure samples through a callback mechanism.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -517,7 +553,7 @@ vrna_pbacktrack_num(vrna_fold_compound_t  *fc,
 unsigned int
 vrna_pbacktrack_cb(vrna_fold_compound_t             *fc,
                    unsigned int                     num_samples,
-                   vrna_boltzmann_sampling_callback *cb,
+                   vrna_bs_result_f cb,
                    void                             *data,
                    unsigned int                     options);
 
@@ -530,15 +566,17 @@ vrna_pbacktrack_cb(vrna_fold_compound_t             *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack_cb() this function allows for resuming a previous
  *  sampling round in specialized Boltzmann sampling, such as non-redundant backtracking.
@@ -568,8 +606,8 @@ vrna_pbacktrack_cb(vrna_fold_compound_t             *fc,
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -607,15 +645,17 @@ vrna_pbacktrack_resume(vrna_fold_compound_t   *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5_resume() this function yields the structure samples
  *  through a callback mechanism.
@@ -646,8 +686,8 @@ vrna_pbacktrack_resume(vrna_fold_compound_t   *fc,
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -675,7 +715,7 @@ vrna_pbacktrack_resume(vrna_fold_compound_t   *fc,
 unsigned int
 vrna_pbacktrack_resume_cb(vrna_fold_compound_t              *fc,
                           unsigned int                      num_samples,
-                          vrna_boltzmann_sampling_callback  *cb,
+                          vrna_bs_result_f  cb,
                           void                              *data,
                           vrna_pbacktrack_mem_t             *nr_mem,
                           unsigned int                      options);
@@ -698,16 +738,18 @@ vrna_pbacktrack_resume_cb(vrna_fold_compound_t              *fc,
  *  The resulting substructure @f$ s_{start,end} @f$ with free energy @f$ E(s_{start, end}) @f$ is picked from
  *  the Boltzmann distributed sub ensemble of all structures within the interval @f$ [start:end] @f$ according
  *  to its probability
+ *
  *  @f[
  *  p(s_{start,end}) = \frac{exp(-E(s_{start,end}) / kT)}{Z_{start,end}}
  *  @f]
+ *
  *  with partition function @f$ Z_{start,end} = \sum_{s_{start,end}} exp(-E(s_{start,end}) / kT) @f$,
  *  Boltzmann constant @f$ k @f$ and thermodynamic temperature @f$ T @f$.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -734,20 +776,22 @@ vrna_pbacktrack_sub(vrna_fold_compound_t *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -787,23 +831,25 @@ vrna_pbacktrack_sub_num(vrna_fold_compound_t *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5() and vrna_pbacktrack5_num() this function yields the
  *  structure samples through a callback mechanism.
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -833,7 +879,7 @@ vrna_pbacktrack_sub_cb(vrna_fold_compound_t              *fc,
                        unsigned int                      num_samples,
                        unsigned int                      start,
                        unsigned int                      end,
-                       vrna_boltzmann_sampling_callback  *cb,
+                       vrna_bs_result_f  cb,
                        void                              *data,
                        unsigned int                      options);
 
@@ -847,15 +893,17 @@ vrna_pbacktrack_sub_cb(vrna_fold_compound_t              *fc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5_cb() this function allows for resuming a previous
  *  sampling round in specialized Boltzmann sampling, such as non-redundant backtracking.
@@ -887,8 +935,8 @@ vrna_pbacktrack_sub_cb(vrna_fold_compound_t              *fc,
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -914,7 +962,7 @@ vrna_pbacktrack_sub_cb(vrna_fold_compound_t              *fc,
  *  @return               A set of secondary structure samples in dot-bracket notation terminated by NULL (or NULL on error)
  */
 char **
-vrna_pbacktrack_sub_resume(vrna_fold_compound_t  *vc,
+vrna_pbacktrack_sub_resume(vrna_fold_compound_t  *fc,
                            unsigned int          num_samples,
                            unsigned int          start,
                            unsigned int          end,
@@ -931,15 +979,17 @@ vrna_pbacktrack_sub_resume(vrna_fold_compound_t  *vc,
  *
  *  Any structure @f$ s @f$ with free energy @f$ E(s) @f$ is picked from the Boltzmann distributed
  *  ensemble according to its probability
+ *
  *  @f[
  *  p(s) = \frac{exp(-E(s) / kT)}{Z}
  *  @f]
+ *
  *  with partition function @f$ Z = \sum_s exp(-E(s) / kT) @f$, Boltzmann constant @f$ k @f$ and
  *  thermodynamic temperature @f$ T @f$.
  *
  *  Using the @p options flag one can switch between regular (#VRNA_PBACKTRACK_DEFAULT) backtracing
- *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of Michalik
- *  et al. 2017 @cite michalik:2017.
+ *  mode, and non-redundant sampling (#VRNA_PBACKTRACK_NON_REDUNDANT) along the lines of
+ *  @rstinline :cite:t:`michalik:2017` @endrst.
  *
  *  In contrast to vrna_pbacktrack5_resume() this function yields the structure samples
  *  through a callback mechanism.
@@ -972,8 +1022,8 @@ vrna_pbacktrack_sub_resume(vrna_fold_compound_t  *vc,
  *
  *  @pre    Unique multiloop decomposition has to be active upon creation of @p fc with vrna_fold_compound()
  *          or similar. This can be done easily by passing vrna_fold_compound() a model details parameter
- *          with vrna_md_t.uniq_ML = 1.
- *  @pre    vrna_pf() has to be called first to fill the partition function matrices
+ *          with vrna_md_t.uniq_ML = 1.<br>
+ *          vrna_pf() has to be called first to fill the partition function matrices
  *
  *  @note This function is polymorphic. It accepts #vrna_fold_compound_t of type
  *        #VRNA_FC_TYPE_SINGLE, and #VRNA_FC_TYPE_COMPARATIVE.
@@ -1005,7 +1055,7 @@ vrna_pbacktrack_sub_resume_cb(vrna_fold_compound_t             *fc,
                               unsigned int                     num_samples,
                               unsigned int                     start,
                               unsigned int                     end,
-                              vrna_boltzmann_sampling_callback *bs_cb,
+                              vrna_bs_result_f cb,
                               void                             *data,
                               vrna_pbacktrack_mem_t            *nr_mem,
                               unsigned int                     options);
