@@ -603,8 +603,8 @@ vrna_hc_free(vrna_hc_t *hc)
 
 
 PUBLIC void
-vrna_hc_add_f(vrna_fold_compound_t      *vc,
-              vrna_callback_hc_evaluate *f)
+vrna_hc_add_f(vrna_fold_compound_t  *vc,
+              vrna_hc_eval_f        f)
 {
   if (vc && f) {
     if (vc->type == VRNA_FC_TYPE_SINGLE) {
@@ -618,9 +618,9 @@ vrna_hc_add_f(vrna_fold_compound_t      *vc,
 
 
 PUBLIC void
-vrna_hc_add_data(vrna_fold_compound_t       *vc,
-                 void                       *data,
-                 vrna_callback_free_auxdata *f)
+vrna_hc_add_data(vrna_fold_compound_t *vc,
+                 void                 *data,
+                 vrna_auxdata_free_f  f)
 {
   if (vc && data) {
     if (vc->type == VRNA_FC_TYPE_SINGLE) {
@@ -799,19 +799,19 @@ populate_hc_up(vrna_fold_compound_t *fc,
 
   if (hc->type == VRNA_HC_WINDOW) {
     strand    = fc->strand_number[i];
-    actual_i  = fc->strand_start[strand] + i - 1;
+    actual_i  = i - fc->strand_start[strand] + 1;
 
     if ((hc->depot) &&
         (hc->depot->up) &&
-        (hc->depot->up_size[strand] >= i)) {
+        (hc->depot->up_size[strand] >= actual_i)) {
       /* We use user-defined constraints for unpaired nucleotides */
-      context = hc->depot->up[strand][i].context;
+      context = hc->depot->up[strand][actual_i].context;
 
-      if (hc->depot->up[strand][i].nonspec) {
-        /* this nucleotide must not stay unpaired */
-        hc->matrix_local[actual_i][0] = VRNA_CONSTRAINT_CONTEXT_NONE;
-
-        /* pairing direction will be enforced by populate_hc_bp() */
+      if (hc->depot->up[strand][actual_i].nonspec) {
+        if (context & VRNA_CONSTRAINT_CONTEXT_ENFORCE)
+          /* this nucleotide must not stay unpaired */
+          hc->matrix_local[i][0] = VRNA_CONSTRAINT_CONTEXT_NONE;
+        /* the actual pairing direction will be enforced by populate_hc_bp() */
       } else if (context & VRNA_CONSTRAINT_CONTEXT_ENFORCE) {
         hc->matrix_local[i][0] = context & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
         /* restriction of base pairing contexts and removal of possible pairing will be handled by populate_hc_bp() */
@@ -1072,7 +1072,7 @@ populate_hc_bp(vrna_fold_compound_t *fc,
                unsigned int         i,
                unsigned int         options)
 {
-  unsigned char constraint, type;
+  unsigned char constraint, type, t_down, t_up;
   unsigned int  max_span, maxdist, j, k, p, n, l, turn, strand, sj, sl, actual_i, actual_j,
                 actual_l, *sn, *ss;
   vrna_hc_t     *hc;
@@ -1087,7 +1087,7 @@ populate_hc_bp(vrna_fold_compound_t *fc,
   turn      = fc->params->model_details.min_loop_size;
   hc        = fc->hc;
 
-  if (options & VRNA_CONSTRAINT_WINDOW_UPDATE_3) {
+  if (options & VRNA_OPTION_F3) {
     /* the sliding window moves from 3' to 5' side */
 
     /* apply default constraints first */
@@ -1108,19 +1108,20 @@ populate_hc_bp(vrna_fold_compound_t *fc,
         if ((hc->depot->up[strand]) &&
             (hc->depot->up_size[strand] >= actual_i)) {
           constraint = hc->depot->up[strand][actual_i].context;
+          type = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
 
           if (hc->depot->up[strand][actual_i].nonspec) {
             /* handle unspecific pairing contraint */
+            t_down  = (hc->depot->up[strand][actual_i].direction >= 0) ? type : VRNA_CONSTRAINT_CONTEXT_NONE;
 
-            /* remove downstream pairs if necessary */
-            if (hc->depot->up[strand][actual_i].direction < 0) {
+            if (constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)
+              /* only allow for possibly non-canonical pairs, do not enforce them */
               for (k = i + 1; k < MIN2(i + max_span, n + 1); k++)
-                hc->matrix_local[i][k - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
-            } else {
-              /* enforce the base pair type */
+                hc->matrix_local[i][k - i] |= t_down;
+            else
+              /* remove downstream pairs if necessary */
               for (k = i + 1; k < MIN2(i + max_span, n + 1); k++)
-                hc->matrix_local[i][k - i] &= constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
-            }
+                hc->matrix_local[i][k - i] &= t_down;
           } else {
             /* handle 'regular' unpairedness constraint */
 
@@ -1131,7 +1132,6 @@ populate_hc_bp(vrna_fold_compound_t *fc,
                   hc->matrix_local[i][k - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
               }
             } else {
-              type = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
               if (!(constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)) {
                 /* only allow i to be paired for particular types */
                 for (k = i + 1; k < MIN2(i + max_span, n + 1); k++)
@@ -1156,22 +1156,20 @@ populate_hc_bp(vrna_fold_compound_t *fc,
           if ((hc->depot->up[sj]) &&
               (hc->depot->up_size[sj] >= actual_j)) {
             constraint = hc->depot->up[sj][actual_j].context;
+            type = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
 
             if (hc->depot->up[sj][actual_j].nonspec) {
-              /* j must be paired, check preferred direction */
-              if (hc->depot->up[sj][actual_j].direction > 0)
-                /* j must pair downstream, so we remove base pair (i, j) */
-                hc->matrix_local[i][j - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
+              t_up  = (hc->depot->up[sj][actual_j].direction <= 0) ? type : VRNA_CONSTRAINT_CONTEXT_NONE;
+              if (constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)
+                hc->matrix_local[i][j - i] |= t_up;
               else
-                /* enforce base pair type */
-                hc->matrix_local[i][j - i] &= constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
+                hc->matrix_local[i][j - i] &= t_up;
             } else if (!(constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)) {
               if (constraint & VRNA_CONSTRAINT_CONTEXT_ENFORCE) {
                 /* remove (i, j) base pair */
                 hc->matrix_local[i][j - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
               } else {
-                constraint                  = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
-                hc->matrix_local[i][j - i]  &= ~constraint;
+                hc->matrix_local[i][j - i]  &= ~type;
               }
             }
           }
@@ -1269,7 +1267,7 @@ populate_hc_bp(vrna_fold_compound_t *fc,
     }
 
     hc_update_up_window(fc, i, options);
-  } else if (options & VRNA_CONSTRAINT_WINDOW_UPDATE_5) {
+  } else if (options & VRNA_OPTION_F5) {
     /* the sliding window moves from 5' to 3' side (i is 3' nucleotide) */
 
     j         = i;
@@ -1294,23 +1292,18 @@ populate_hc_bp(vrna_fold_compound_t *fc,
           if ((hc->depot->up[sj]) &&
               (hc->depot->up_size[sj] >= actual_j)) {
             constraint = hc->depot->up[sj][actual_j].context;
+            type  = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
 
             if (hc->depot->up[sj][actual_j].nonspec) {
               /* handle unspecific pairing constraint */
+              t_up  = (hc->depot->up[sj][actual_j].direction <= 0) ? type : VRNA_CONSTRAINT_CONTEXT_NONE;
 
-              /* remove upstream pairs if necessary */
-              if (hc->depot->up[sj][actual_j].direction > 0) {
-                /*
-                 * j is only allowed to pair downstream
-                 * remove all base pairs (i, j) with j - maxdist < i < j
-                 */
+              if (constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)
                 for (i = start_i; i < j; i++)
-                  hc->matrix_local[i][j - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
-              } else {
-                /* enforce the base pair type */
+                  hc->matrix_local[i][j - i] |= t_up;
+              else
                 for (i = start_i; i < j; i++)
-                  hc->matrix_local[i][j - i] &= constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
-              }
+                  hc->matrix_local[i][j - i] &= t_up;
             } else {
               /* handle 'regular' unpairedness constraint */
 
@@ -1321,7 +1314,6 @@ populate_hc_bp(vrna_fold_compound_t *fc,
                     hc->matrix_local[i][j - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
                 }
               } else {
-                type = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
                 if (!(constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)) {
                   /* only allow j to be paired for particular types */
                   for (i = start_i; i < j; i++)
@@ -1342,22 +1334,20 @@ populate_hc_bp(vrna_fold_compound_t *fc,
             if ((hc->depot->up[strand]) &&
                 (hc->depot->up_size[strand] >= actual_i)) {
               constraint = hc->depot->up[strand][actual_i].context;
+              type = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
 
               if (hc->depot->up[strand][actual_i].nonspec) {
-                /* i must be paired, check preferred direction */
-                if (hc->depot->up[strand][actual_i].direction < 0)
-                  /* remove (i, j) base pair */
-                  hc->matrix_local[i][j - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
+                t_down  = (hc->depot->up[sj][actual_j].direction >= 0) ? type : VRNA_CONSTRAINT_CONTEXT_NONE;
+                if (constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)
+                  hc->matrix_local[i][j - i] |= t_down;
                 else
-                  /* enforce base pair type */
-                  hc->matrix_local[i][j - i] &= constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
+                  hc->matrix_local[i][j - i] &= t_down;
               } else if (!(constraint & VRNA_CONSTRAINT_CONTEXT_NO_REMOVE)) {
                 if (constraint & VRNA_CONSTRAINT_CONTEXT_ENFORCE) {
                   /* remove (i, j) base pair */
                   hc->matrix_local[i][j - i] = VRNA_CONSTRAINT_CONTEXT_NONE;
                 } else {
-                  constraint                  = constraint & VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
-                  hc->matrix_local[i][j - i]  &= ~constraint;
+                  hc->matrix_local[i][j - i]  &= ~type;
                 }
               }
             }
@@ -1514,6 +1504,9 @@ apply_DB_constraint(vrna_fold_compound_t  *vc,
           bp_unspecific[num_bp_unspecific].j        = 0;  /* direction */
           bp_unspecific[num_bp_unspecific].options  = VRNA_CONSTRAINT_CONTEXT_ALL_LOOPS;
 
+          if (options & VRNA_CONSTRAINT_DB_ENFORCE_BP)
+            bp_unspecific[num_bp_unspecific].options |= VRNA_CONSTRAINT_CONTEXT_ENFORCE;
+
           num_bp_unspecific++;
 
           if (num_bp_unspecific == size_bp_unspecific) {
@@ -1928,7 +1921,7 @@ hc_update_up_window(vrna_fold_compound_t  *vc,
   hc      = vc->hc;
   winsize = vc->window_size;
 
-  if (options & VRNA_CONSTRAINT_WINDOW_UPDATE_5) {
+  if (options & VRNA_OPTION_F5) {
     up_ext = (hc->matrix_local[i][0] & VRNA_CONSTRAINT_CONTEXT_EXT_LOOP) ?
              1 : 0;
     up_hp = (hc->matrix_local[i][0] & VRNA_CONSTRAINT_CONTEXT_HP_LOOP) ?
@@ -1957,7 +1950,7 @@ hc_update_up_window(vrna_fold_compound_t  *vc,
   hc->up_int[i] = up_int;
   hc->up_ml[i]  = up_ml;
 
-  if (options & VRNA_CONSTRAINT_WINDOW_UPDATE_5) {
+  if (options & VRNA_OPTION_F5) {
     /* the sliding window proceeds from 5' to 3' so we update constraints 3' to 5' */
     if (up_ext > 0) {
       for (k = i - 1; k >= MAX2(1, i - winsize); k--) {
@@ -2005,7 +1998,6 @@ hc_update_up_window(vrna_fold_compound_t  *vc,
  * # deprecated functions below              #
  *###########################################
  */
-
 PUBLIC void
 print_tty_constraint_full(void)
 {
