@@ -106,6 +106,11 @@ PRIVATE void
 prepare_sc_stack_pf(vrna_fold_compound_t *fc);
 
 
+PRIVATE int
+prepare_sc_user_cb(vrna_fold_compound_t *fc,
+                   unsigned int         options);
+
+
 PRIVATE INLINE void
 sc_init_up_storage(vrna_sc_t *sc);
 
@@ -232,14 +237,17 @@ vrna_sc_init_window(vrna_fold_compound_t *fc)
 }
 
 
-PUBLIC void
+PUBLIC int
 vrna_sc_prepare(vrna_fold_compound_t  *fc,
                 unsigned int          options)
 {
+  int ret = 0;
+
   if (fc) {
     if (options & VRNA_OPTION_MFE) {
       prepare_sc_up_mfe(fc, options);
       prepare_sc_bp_mfe(fc, options);
+
     }
 
     if (options & VRNA_OPTION_PF) {
@@ -247,7 +255,11 @@ vrna_sc_prepare(vrna_fold_compound_t  *fc,
       prepare_sc_bp_pf(fc, options);
       prepare_sc_stack_pf(fc);
     }
+
+    ret |= prepare_sc_user_cb(fc, options);
   }
+
+  return ret;
 }
 
 
@@ -257,6 +269,7 @@ vrna_sc_update(vrna_fold_compound_t *fc,
                unsigned int         options)
 {
   unsigned int  n, maxdist;
+  int           ret = 0;
   vrna_sc_t     *sc;
 
   if (fc) {
@@ -293,6 +306,9 @@ vrna_sc_update(vrna_fold_compound_t *fc,
                 populate_sc_bp_pf(fc, i, maxdist);
             }
 
+            if ((sc->data) && (sc->prepare_data))
+              ret |= sc->prepare_data(fc, sc->data, options, (void *)&i);
+
             return 1;
           }
 
@@ -591,17 +607,34 @@ vrna_sc_add_stack_comparative(vrna_fold_compound_t  *fc,
 
 
 PUBLIC int
-vrna_sc_add_data(vrna_fold_compound_t       *fc,
-                 void                       *data,
-                 vrna_callback_free_auxdata *free_data)
+vrna_sc_add_data(vrna_fold_compound_t *fc,
+                 void                 *data,
+                 vrna_auxdata_free_f  free_data)
+{
+  return vrna_sc_add_auxdata(fc, data, NULL, free_data);
+}
+
+
+PUBLIC int
+vrna_sc_add_auxdata(vrna_fold_compound_t    *fc,
+                    void                    *data,
+                    vrna_auxdata_prepare_f  prepare_cb,
+                    vrna_auxdata_free_f     free_cb)
 {
   if ((fc) &&
       (fc->type == VRNA_FC_TYPE_SINGLE)) {
     if (!fc->sc)
       vrna_sc_init(fc);
 
-    fc->sc->data      = data;
-    fc->sc->free_data = free_data;
+    vrna_sc_t *sc = fc->sc;
+
+    if (sc->free_data)
+      sc->free_data(sc->data);
+
+    sc->data          = data;
+    sc->free_data     = free_cb;
+    sc->prepare_data  = prepare_cb;
+
     return 1;
   }
 
@@ -610,9 +643,9 @@ vrna_sc_add_data(vrna_fold_compound_t       *fc,
 
 
 PUBLIC int
-vrna_sc_add_data_comparative(vrna_fold_compound_t       *fc,
-                             void                       **data,
-                             vrna_callback_free_auxdata **free_data)
+vrna_sc_add_data_comparative(vrna_fold_compound_t *fc,
+                             void                 **data,
+                             vrna_auxdata_free_f  *free_data)
 {
   unsigned int s;
 
@@ -621,14 +654,20 @@ vrna_sc_add_data_comparative(vrna_fold_compound_t       *fc,
     if (!fc->scs)
       vrna_sc_init(fc);
 
+    if (free_data)
+      for (s = 0; s < fc->n_seq; s++) {
+        if (fc->scs[s]->free_data) {
+          fc->scs[s]->free_data(fc->scs[s]->data);
+          fc->scs[s]->data = NULL;
+        }
+
+        fc->scs[s]->free_data = free_data[s];
+      }
+
     if (data)
       for (s = 0; s < fc->n_seq; s++)
         fc->scs[s]->data = data[s];
 
-    if (free_data)
-      for (s = 0; s < fc->n_seq; s++)
-        fc->scs[s]->free_data = free_data[s];
-
     return 1;
   }
 
@@ -637,8 +676,8 @@ vrna_sc_add_data_comparative(vrna_fold_compound_t       *fc,
 
 
 PUBLIC int
-vrna_sc_add_f(vrna_fold_compound_t    *fc,
-              vrna_callback_sc_energy *f)
+vrna_sc_add_f(vrna_fold_compound_t  *fc,
+              vrna_sc_f             f)
 {
   if ((fc) &&
       (f) &&
@@ -655,8 +694,8 @@ vrna_sc_add_f(vrna_fold_compound_t    *fc,
 
 
 PUBLIC int
-vrna_sc_add_f_comparative(vrna_fold_compound_t    *fc,
-                          vrna_callback_sc_energy **f)
+vrna_sc_add_f_comparative(vrna_fold_compound_t  *fc,
+                          vrna_sc_f             *f)
 {
   unsigned int s;
 
@@ -677,8 +716,8 @@ vrna_sc_add_f_comparative(vrna_fold_compound_t    *fc,
 
 
 PUBLIC int
-vrna_sc_add_bt(vrna_fold_compound_t       *fc,
-               vrna_callback_sc_backtrack *f)
+vrna_sc_add_bt(vrna_fold_compound_t *fc,
+               vrna_sc_bt_f         f)
 {
   if ((fc) &&
       (f) &&
@@ -695,8 +734,8 @@ vrna_sc_add_bt(vrna_fold_compound_t       *fc,
 
 
 PUBLIC int
-vrna_sc_add_exp_f(vrna_fold_compound_t        *fc,
-                  vrna_callback_sc_exp_energy *exp_f)
+vrna_sc_add_exp_f(vrna_fold_compound_t  *fc,
+                  vrna_sc_exp_f         exp_f)
 {
   if ((fc) &&
       (exp_f) &&
@@ -713,8 +752,8 @@ vrna_sc_add_exp_f(vrna_fold_compound_t        *fc,
 
 
 PUBLIC int
-vrna_sc_add_exp_f_comparative(vrna_fold_compound_t        *fc,
-                              vrna_callback_sc_exp_energy **exp_f)
+vrna_sc_add_exp_f_comparative(vrna_fold_compound_t  *fc,
+                              vrna_sc_exp_f         *exp_f)
 {
   unsigned int s;
 
@@ -871,9 +910,9 @@ populate_sc_bp_mfe(vrna_fold_compound_t *fc,
   int           e, *idx;
   vrna_sc_t     *sc;
 
-  n     = fc->length;
-  sc    = fc->sc;
-  idx   = fc->jindx;
+  n   = fc->length;
+  sc  = fc->sc;
+  idx = fc->jindx;
 
   if (sc->bp_storage[i]) {
     for (k = 1; k < maxdist; k++) {
@@ -1410,6 +1449,31 @@ prepare_sc_stack_pf(vrna_fold_compound_t *fc)
 }
 
 
+PRIVATE int
+prepare_sc_user_cb(vrna_fold_compound_t *fc,
+                   unsigned int         options)
+{
+  int       ret = 0;
+  vrna_sc_t *sc;
+
+  switch (fc->type) {
+    case VRNA_FC_TYPE_SINGLE:
+      sc = fc->sc;
+      if ((sc) &&
+          (sc->data) &&
+          (sc->prepare_data) &&
+          (sc->type == VRNA_SC_DEFAULT))
+        ret = sc->prepare_data(fc, sc->data, options, NULL);
+      break;
+
+    default:
+      break;
+  }
+
+  return ret;
+}
+
+
 PRIVATE vrna_sc_t *
 init_sc_default(unsigned int n)
 {
@@ -1460,10 +1524,11 @@ nullify(vrna_sc_t *sc)
     sc->exp_energy_stack  = NULL;
     sc->exp_energy_up     = NULL;
 
-    sc->f         = NULL;
-    sc->exp_f     = NULL;
-    sc->data      = NULL;
-    sc->free_data = NULL;
+    sc->f             = NULL;
+    sc->exp_f         = NULL;
+    sc->data          = NULL;
+    sc->prepare_data  = NULL;
+    sc->free_data     = NULL;
 
     switch (sc->type) {
       case VRNA_SC_DEFAULT:
