@@ -11,12 +11,6 @@
 /**
  *
  *  @addtogroup soft_constraints
- *  @brief      Functions and data structures for secondary structure soft constraints
- *
- *  Soft-constraints are used to change position specific contributions
- *  in the recursions by adding bonuses/penalties in form of pseudo free energies
- *  to certain loop configurations.
- *
  */
 
 
@@ -25,6 +19,8 @@
  */
 typedef struct  vrna_sc_s vrna_sc_t;
 
+#include <stdlib.h>
+
 #include <ViennaRNA/datastructures/basic.h>
 #include <ViennaRNA/fold_compound.h>
 #include <ViennaRNA/constraints/basic.h>
@@ -61,12 +57,28 @@ typedef struct  vrna_sc_s vrna_sc_t;
  * @param data      Auxiliary data
  * @return          Pseudo energy contribution in deka-kalories per mol
  */
-typedef int (vrna_callback_sc_energy)(int           i,
-                                      int           j,
-                                      int           k,
-                                      int           l,
-                                      unsigned char d,
-                                      void          *data);
+typedef int (*vrna_sc_f)(int            i,
+                         int            j,
+                         int            k,
+                         int            l,
+                         unsigned char  d,
+                         void           *data);
+
+DEPRECATED(typedef int (vrna_callback_sc_energy)(int i,
+                                                 int j,
+                                                 int k,
+                                                 int l,
+                                                 unsigned char d,
+                                                 void *data),
+           "Use vrna_sc_f instead!");
+
+
+typedef int (*vrna_sc_direct_f)(vrna_fold_compound_t  *fc,
+                                int                   i,
+                                int                   j,
+                                int                   k,
+                                int                   l,
+                                void                  *data);
 
 /**
  * @brief Callback to retrieve pseudo energy contribution as Boltzmann Factors for soft constraint feature
@@ -100,12 +112,29 @@ typedef int (vrna_callback_sc_energy)(int           i,
  * @param data      Auxiliary data
  * @return          Pseudo energy contribution in deka-kalories per mol
  */
-typedef FLT_OR_DBL (vrna_callback_sc_exp_energy)(int            i,
-                                                 int            j,
-                                                 int            k,
-                                                 int            l,
-                                                 unsigned char  d,
-                                                 void           *data);
+typedef FLT_OR_DBL (*vrna_sc_exp_f)(int           i,
+                                    int           j,
+                                    int           k,
+                                    int           l,
+                                    unsigned char d,
+                                    void          *data);
+
+DEPRECATED(typedef FLT_OR_DBL (vrna_callback_sc_exp_energy)(int i,
+                                                            int j,
+                                                            int k,
+                                                            int l,
+                                                            unsigned char d,
+                                                            void *data),
+           "Use vrna_sc_exp_f instead!");
+
+
+typedef FLT_OR_DBL (*vrna_sc_exp_direct_f)(vrna_fold_compound_t *fc,
+                                           int                  i,
+                                           int                  j,
+                                           int                  k,
+                                           int                  l,
+                                           void                 *data);
+
 
 /**
  * @brief Callback to retrieve auxiliary base pairs for soft constraint feature
@@ -133,12 +162,20 @@ typedef FLT_OR_DBL (vrna_callback_sc_exp_energy)(int            i,
  * @param data      Auxiliary data
  * @return          List of additional base pairs
  */
-typedef vrna_basepair_t *(vrna_callback_sc_backtrack)(int           i,
-                                                      int           j,
-                                                      int           k,
-                                                      int           l,
-                                                      unsigned char d,
-                                                      void          *data);
+typedef vrna_basepair_t *(*vrna_sc_bt_f)(int            i,
+                                         int            j,
+                                         int            k,
+                                         int            l,
+                                         unsigned char  d,
+                                         void           *data);
+
+DEPRECATED(typedef vrna_basepair_t *(vrna_callback_sc_backtrack)(int i,
+                                                                 int j,
+                                                                 int k,
+                                                                 int l,
+                                                                 unsigned char d,
+                                                                 void *data),
+           "Use vrna_sc_bt_f instead");
 
 
 /**
@@ -157,9 +194,9 @@ typedef enum {
  *  @brief  A base pair constraint
  */
 typedef struct {
-  unsigned int interval_start;
-  unsigned int interval_end;
-  int          e;
+  unsigned int  interval_start;
+  unsigned int  interval_end;
+  int           e;
 } vrna_sc_bp_storage_t;
 
 
@@ -185,47 +222,49 @@ struct vrna_sc_s {
   union {
     struct {
 #endif
-      int *energy_bp;                           /**<  @brief Energy contribution for base pairs */
-      FLT_OR_DBL *exp_energy_bp;                /**<  @brief Boltzmann Factors of the energy contribution for base pairs */
+  int *energy_bp;                               /**<  @brief Energy contribution for base pairs */
+  FLT_OR_DBL *exp_energy_bp;                    /**<  @brief Boltzmann Factors of the energy contribution for base pairs */
 #ifndef VRNA_DISABLE_C11_FEATURES
   /* C11 support for unnamed unions/structs */
-    };
-    struct {
+};
+struct {
 #endif
-      int         **energy_bp_local;                    /**<  @brief Energy contribution for base pairs (sliding window approach) */
-      FLT_OR_DBL  **exp_energy_bp_local;                /**<  @brief Boltzmann Factors of the energy contribution for base pairs (sliding window approach) */
+  int         **energy_bp_local;                        /**<  @brief Energy contribution for base pairs (sliding window approach) */
+  FLT_OR_DBL  **exp_energy_bp_local;                    /**<  @brief Boltzmann Factors of the energy contribution for base pairs (sliding window approach) */
 #ifndef VRNA_DISABLE_C11_FEATURES
   /* C11 support for unnamed unions/structs */
-    };
-  };
+};
+};
 #endif
 
-  int                         *energy_stack;      /**<  @brief Pseudo Energy contribution per base pair involved in a stack */
-  FLT_OR_DBL                  *exp_energy_stack;  /**<  @brief Boltzmann weighted pseudo energy contribution per nucleotide involved in a stack */
+  int           *energy_stack;                    /**<  @brief Pseudo Energy contribution per base pair involved in a stack */
+  FLT_OR_DBL    *exp_energy_stack;                /**<  @brief Boltzmann weighted pseudo energy contribution per nucleotide involved in a stack */
 
   /* generic soft contraints below */
-  vrna_callback_sc_energy     *f;     /**<  @brief  A function pointer used for pseudo
-                                       *            energy contribution in MFE calculations
-                                       *    @see    vrna_sc_add_f()
-                                       */
+  vrna_sc_f     f;            /**<  @brief  A function pointer used for pseudo
+                               *            energy contribution in MFE calculations
+                               *    @see    vrna_sc_add_f()
+                               */
 
-  vrna_callback_sc_backtrack  *bt;    /**<  @brief  A function pointer used to obtain backtraced
-                                       *            base pairs in loop regions that were altered
-                                       *            by soft constrained pseudo energy contributions
-                                       *    @see    vrna_sc_add_bt()
-                                       */
+  vrna_sc_bt_f  bt;           /**<  @brief  A function pointer used to obtain backtraced
+                               *            base pairs in loop regions that were altered
+                               *            by soft constrained pseudo energy contributions
+                               *    @see    vrna_sc_add_bt()
+                               */
 
-  vrna_callback_sc_exp_energy *exp_f; /**<  @brief  A function pointer used for pseudo energy
-                                       *            contribution boltzmann factors in PF
-                                       *            calculations
-                                       *    @see    vrna_sc_add_exp_f()
-                                       */
+  vrna_sc_exp_f exp_f;        /**<  @brief  A function pointer used for pseudo energy
+                               *            contribution boltzmann factors in PF
+                               *            calculations
+                               *    @see    vrna_sc_add_exp_f()
+                               */
 
-  void                        *data;  /**<  @brief  A pointer to the data object provided for
-                                       *            for pseudo energy contribution functions of the
-                                       *            generic soft constraints feature
-                                       */
-  vrna_callback_free_auxdata  *free_data;
+  void                *data;  /**<  @brief  A pointer to the data object provided for
+                               *            for pseudo energy contribution functions of the
+                               *            generic soft constraints feature
+                               */
+
+  vrna_auxdata_prepare_f  prepare_data;
+  vrna_auxdata_free_f     free_data;
 };
 
 /**
@@ -242,18 +281,20 @@ struct vrna_sc_s {
  *  @see  vrna_sc_set_bp(), vrna_sc_set_up(), vrna_sc_add_SHAPE_deigan(),
  *        vrna_sc_add_SHAPE_zarringhalam(), vrna_sc_remove(), vrna_sc_add_f(),
  *        vrna_sc_add_exp_f(), vrna_sc_add_pre(), vrna_sc_add_post()
- *  @param  vc  The #vrna_fold_compound_t where an empty soft constraint feature is to be added to
+ *
+ *  @param  fc  The #vrna_fold_compound_t where an empty soft constraint feature is to be added to
  */
-void vrna_sc_init(vrna_fold_compound_t *vc);
-
-
 void
-vrna_sc_prepare(vrna_fold_compound_t  *vc,
+vrna_sc_init(vrna_fold_compound_t *fc);
+
+
+int
+vrna_sc_prepare(vrna_fold_compound_t  *fc,
                 unsigned int          options);
 
 
 int
-vrna_sc_update(vrna_fold_compound_t *vc,
+vrna_sc_update(vrna_fold_compound_t *fc,
                unsigned int         i,
                unsigned int         options);
 
@@ -268,15 +309,15 @@ vrna_sc_update(vrna_fold_compound_t *vc,
  *
  *  @see      vrna_sc_add_bp(), vrna_sc_set_up(), vrna_sc_add_up()
  *
- *  @param  vc          The #vrna_fold_compound_t the soft constraints are associated with
+ *  @param  fc          The #vrna_fold_compound_t the soft constraints are associated with
  *  @param  constraints A two-dimensional array of pseudo free energies in @f$ kcal / mol @f$
  *  @param  options     The options flag indicating how/where to store the soft constraints
  *  @return             Non-zero on successful application of the constraint, 0 otherwise.
  */
 int
-vrna_sc_set_bp(vrna_fold_compound_t  *vc,
-               const FLT_OR_DBL      **constraints,
-               unsigned int          options);
+vrna_sc_set_bp(vrna_fold_compound_t *fc,
+               const FLT_OR_DBL     **constraints,
+               unsigned int         options);
 
 
 /**
@@ -286,7 +327,7 @@ vrna_sc_set_bp(vrna_fold_compound_t  *vc,
  *
  *  @see      vrna_sc_set_bp(), vrna_sc_set_up(), vrna_sc_add_up()
  *
- *  @param  vc          The #vrna_fold_compound_t the soft constraints are associated with
+ *  @param  fc          The #vrna_fold_compound_t the soft constraints are associated with
  *  @param  i           The 5' position of the base pair the soft constraint is added for
  *  @param  j           The 3' position of the base pair the soft constraint is added for
  *  @param  energy      The free energy (soft-constraint) in @f$ kcal / mol @f$
@@ -294,11 +335,11 @@ vrna_sc_set_bp(vrna_fold_compound_t  *vc,
  *  @return             Non-zero on successful application of the constraint, 0 otherwise.
  */
 int
-vrna_sc_add_bp(vrna_fold_compound_t  *vc,
-               int                   i,
-               int                   j,
-               FLT_OR_DBL            energy,
-               unsigned int          options);
+vrna_sc_add_bp(vrna_fold_compound_t *fc,
+               int                  i,
+               int                  j,
+               FLT_OR_DBL           energy,
+               unsigned int         options);
 
 
 /**
@@ -311,15 +352,15 @@ vrna_sc_add_bp(vrna_fold_compound_t  *vc,
  *
  *  @see      vrna_sc_add_up(), vrna_sc_set_bp(), vrna_sc_add_bp()
  *
- *  @param  vc          The #vrna_fold_compound_t the soft constraints are associated with
+ *  @param  fc          The #vrna_fold_compound_t the soft constraints are associated with
  *  @param  constraints A vector of pseudo free energies in @f$ kcal / mol @f$
  *  @param  options     The options flag indicating how/where to store the soft constraints
  *  @return             Non-zero on successful application of the constraint, 0 otherwise.
  */
 int
-vrna_sc_set_up(vrna_fold_compound_t  *vc,
-               const FLT_OR_DBL      *constraints,
-               unsigned int          options);
+vrna_sc_set_up(vrna_fold_compound_t *fc,
+               const FLT_OR_DBL     *constraints,
+               unsigned int         options);
 
 
 /**
@@ -329,23 +370,23 @@ vrna_sc_set_up(vrna_fold_compound_t  *vc,
  *
  *  @see      vrna_sc_set_up(), vrna_sc_add_bp(), vrna_sc_set_bp()
  *
- *  @param  vc          The #vrna_fold_compound_t the soft constraints are associated with
+ *  @param  fc          The #vrna_fold_compound_t the soft constraints are associated with
  *  @param  i           The nucleotide position the soft constraint is added for
  *  @param  energy      The free energy (soft-constraint) in @f$ kcal / mol @f$
  *  @param  options     The options flag indicating how/where to store the soft constraints
  *  @return             Non-zero on successful application of the constraint, 0 otherwise.
  */
 int
-vrna_sc_add_up(vrna_fold_compound_t  *vc,
-               int                   i,
-               FLT_OR_DBL            energy,
-               unsigned int          options);
+vrna_sc_add_up(vrna_fold_compound_t *fc,
+               int                  i,
+               FLT_OR_DBL           energy,
+               unsigned int         options);
 
 
 int
-vrna_sc_set_stack(vrna_fold_compound_t *vc,
-                  const FLT_OR_DBL     *constraints,
-                  unsigned int         options);
+vrna_sc_set_stack(vrna_fold_compound_t  *fc,
+                  const FLT_OR_DBL      *constraints,
+                  unsigned int          options);
 
 
 int
@@ -355,10 +396,10 @@ vrna_sc_set_stack_comparative(vrna_fold_compound_t  *fc,
 
 
 int
-vrna_sc_add_stack(vrna_fold_compound_t *vc,
-                  int                  i,
-                  FLT_OR_DBL           energy,
-                  unsigned int         options);
+vrna_sc_add_stack(vrna_fold_compound_t  *fc,
+                  int                   i,
+                  FLT_OR_DBL            energy,
+                  unsigned int          options);
 
 
 int
@@ -375,10 +416,10 @@ vrna_sc_add_stack_comparative(vrna_fold_compound_t  *fc,
  *
  *  @ingroup  soft_constraints
  *
- *  @param  vc  The #vrna_fold_compound_t possibly containing soft constraints
+ *  @param  fc  The #vrna_fold_compound_t possibly containing soft constraints
  */
 void
-vrna_sc_remove(vrna_fold_compound_t *vc);
+vrna_sc_remove(vrna_fold_compound_t *fc);
 
 
 /**
@@ -399,21 +440,28 @@ vrna_sc_free(vrna_sc_t *sc);
  *
  *  @see vrna_sc_add_f(), vrna_sc_add_exp_f(), vrna_sc_add_bt()
  *
- *  @param  vc        The fold compound the generic soft constraint function should be bound to
+ *  @param  fc        The fold compound the generic soft constraint function should be bound to
  *  @param  data      A pointer to the data structure that holds required data for function 'f'
  *  @param  free_data A pointer to a function that free's the memory occupied by @p data (Maybe NULL)
  *  @return           Non-zero on successful binding the data (and free-function), 0 otherwise
  */
 int
-vrna_sc_add_data(vrna_fold_compound_t       *vc,
-                 void                       *data,
-                 vrna_callback_free_auxdata *free_data);
+vrna_sc_add_data(vrna_fold_compound_t *fc,
+                 void                 *data,
+                 vrna_auxdata_free_f  free_data);
 
 
 int
-vrna_sc_add_data_comparative(vrna_fold_compound_t       *vc,
-                             void                       **data,
-                             vrna_callback_free_auxdata **free_data);
+vrna_sc_add_auxdata(vrna_fold_compound_t    *fc,
+                    void                    *data,
+                    vrna_auxdata_prepare_f  prepare_cb,
+                    vrna_auxdata_free_f     free_cb);
+
+
+int
+vrna_sc_add_data_comparative(vrna_fold_compound_t *fc,
+                             void                 **data,
+                             vrna_auxdata_free_f  *free_data);
 
 
 /**
@@ -428,18 +476,28 @@ vrna_sc_add_data_comparative(vrna_fold_compound_t       *vc,
  *
  *  @see vrna_sc_add_data(), vrna_sc_add_bt(), vrna_sc_add_exp_f()
  *
- *  @param  vc    The fold compound the generic soft constraint function should be bound to
+ *  @param  fc    The fold compound the generic soft constraint function should be bound to
  *  @param  f     A pointer to the function that evaluates the generic soft constraint feature
  *  @return       Non-zero on successful binding the callback function, 0 otherwise
  */
 int
-vrna_sc_add_f(vrna_fold_compound_t    *vc,
-              vrna_callback_sc_energy *f);
+vrna_sc_add_f(vrna_fold_compound_t  *fc,
+              vrna_sc_f             f);
+
+
+size_t
+vrna_sc_multi_cb_add(vrna_fold_compound_t   *fc,
+                     vrna_sc_direct_f       cb,
+                     vrna_sc_exp_direct_f   cb_exp,
+                     void                   *data,
+                     vrna_auxdata_prepare_f prepare_cb,
+                     vrna_auxdata_free_f    free_cb,
+                     unsigned int           decomp_type);
 
 
 int
-vrna_sc_add_f_comparative(vrna_fold_compound_t    *vc,
-                          vrna_callback_sc_energy **f);
+vrna_sc_add_f_comparative(vrna_fold_compound_t  *fc,
+                          vrna_sc_f             *f);
 
 
 /**
@@ -456,13 +514,13 @@ vrna_sc_add_f_comparative(vrna_fold_compound_t    *vc,
  *
  *  @see vrna_sc_add_data(), vrna_sc_add_f(), vrna_sc_add_exp_f()
  *
- *  @param  vc    The fold compound the generic soft constraint function should be bound to
+ *  @param  fc    The fold compound the generic soft constraint function should be bound to
  *  @param  f     A pointer to the function that returns additional base pairs
  *  @return       Non-zero on successful binding the callback function, 0 otherwise
  */
 int
-vrna_sc_add_bt(vrna_fold_compound_t       *vc,
-               vrna_callback_sc_backtrack *f);
+vrna_sc_add_bt(vrna_fold_compound_t *fc,
+               vrna_sc_bt_f         f);
 
 
 /**
@@ -478,18 +536,18 @@ vrna_sc_add_bt(vrna_fold_compound_t       *vc,
  *
  *  @see vrna_sc_add_bt(), vrna_sc_add_f(), vrna_sc_add_data()
  *
- *  @param  vc    The fold compound the generic soft constraint function should be bound to
+ *  @param  fc    The fold compound the generic soft constraint function should be bound to
  *  @param  exp_f A pointer to the function that evaluates the generic soft constraint feature
  *  @return       Non-zero on successful binding the callback function, 0 otherwise
  */
 int
-vrna_sc_add_exp_f(vrna_fold_compound_t        *vc,
-                  vrna_callback_sc_exp_energy *exp_f);
+vrna_sc_add_exp_f(vrna_fold_compound_t  *fc,
+                  vrna_sc_exp_f         exp_f);
 
 
 int
-vrna_sc_add_exp_f_comparative(vrna_fold_compound_t        *vc,
-                              vrna_callback_sc_exp_energy **exp_f);
+vrna_sc_add_exp_f_comparative(vrna_fold_compound_t  *fc,
+                              vrna_sc_exp_f         *exp_f);
 
 
 #endif
