@@ -27,6 +27,7 @@ typedef struct  vrna_mx_pf_s vrna_mx_pf_t;
 /**
  *  @brief  An enumerator that is used to specify the type of a polymorphic Dynamic Programming (DP)
  *  matrix data structure
+ *
  *  @see #vrna_mx_mfe_t, #vrna_mx_pf_t
  */
 typedef enum {
@@ -372,15 +373,15 @@ struct {
  *  required for RNA-RNA interaction prediction.
  *
  *  @note Usually, there is no need to call this function, since
- *  the constructors of #vrna_fold_compound_t are handling all the DP
- *  matrix memory allocation.
+ *        the constructors of #vrna_fold_compound_t are handling all the DP
+ *        matrix memory allocation.
  *
- *  @see vrna_mx_mfe_add(), vrna_mx_pf_add(), vrna_fold_compound(),
- *  vrna_fold_compound_comparative(), vrna_fold_compound_free(),
- *  vrna_mx_pf_free(), vrna_mx_mfe_free(), #vrna_mx_type_e,
- *  #VRNA_OPTION_MFE, #VRNA_OPTION_PF, #VRNA_OPTION_HYBRID, #VRNA_OPTION_EVAL_ONLY
+ *  @see  vrna_mx_mfe_add(), vrna_mx_pf_add(), vrna_fold_compound(),
+ *        vrna_fold_compound_comparative(), vrna_fold_compound_free(),
+ *        vrna_mx_pf_free(), vrna_mx_mfe_free(), #vrna_mx_type_e,
+ *        #VRNA_OPTION_MFE, #VRNA_OPTION_PF, #VRNA_OPTION_HYBRID, #VRNA_OPTION_EVAL_ONLY
  *
- *  @param  vc      The #vrna_fold_compound_t that holds pointers to the DP matrices
+ *  @param  fc      The #vrna_fold_compound_t that holds pointers to the DP matrices
  *  @param  type    The type of DP matrices requested
  *  @param  options Option flags that specify the kind of DP matrices, such
  *                  as MFE or PF arrays, and auxiliary requirements
@@ -388,25 +389,25 @@ struct {
  *                  0 otherwise
  */
 int
-vrna_mx_add(vrna_fold_compound_t  *vc,
+vrna_mx_add(vrna_fold_compound_t  *fc,
             vrna_mx_type_e        type,
             unsigned int          options);
 
 
 int
-vrna_mx_mfe_add(vrna_fold_compound_t  *vc,
+vrna_mx_mfe_add(vrna_fold_compound_t  *fc,
                 vrna_mx_type_e        mx_type,
                 unsigned int          options);
 
 
 int
-vrna_mx_pf_add(vrna_fold_compound_t *vc,
+vrna_mx_pf_add(vrna_fold_compound_t *fc,
                vrna_mx_type_e       mx_type,
                unsigned int         options);
 
 
 int
-vrna_mx_prepare(vrna_fold_compound_t  *vc,
+vrna_mx_prepare(vrna_fold_compound_t  *fc,
                 unsigned int          options);
 
 
@@ -415,10 +416,10 @@ vrna_mx_prepare(vrna_fold_compound_t  *vc,
  *
  *  @see vrna_fold_compound(), vrna_fold_compound_comparative(), vrna_fold_compound_free(), vrna_mx_pf_free()
  *
- *  @param  vc  The #vrna_fold_compound_t storing the MFE DP matrices that are to be erased from memory
+ *  @param  fc  The #vrna_fold_compound_t storing the MFE DP matrices that are to be erased from memory
  */
 void
-vrna_mx_mfe_free(vrna_fold_compound_t *vc);
+vrna_mx_mfe_free(vrna_fold_compound_t *fc);
 
 
 /**
@@ -426,10 +427,10 @@ vrna_mx_mfe_free(vrna_fold_compound_t *vc);
  *
  *  @see vrna_fold_compound(), vrna_fold_compound_comparative(), vrna_fold_compound_free(), vrna_mx_mfe_free()
  *
- *  @param  vc  The #vrna_fold_compound_t storing the PF DP matrices that are to be erased from memory
+ *  @param  fc  The #vrna_fold_compound_t storing the PF DP matrices that are to be erased from memory
  */
 void
-vrna_mx_pf_free(vrna_fold_compound_t *vc);
+vrna_mx_pf_free(vrna_fold_compound_t *fc);
 
 
 /**
