@@ -22,14 +22,6 @@
 /**
  *  @addtogroup   fold_compound   The Fold Compound
  *  @{
- *
- *  @brief  This module provides interfaces that deal with the most basic data structure used
- *          in structure predicting and energy evaluating function of the RNAlib.
- *
- *          Throughout the entire RNAlib, the #vrna_fold_compound_t, is used to group
- *          information and data that is required for structure prediction and energy evaluation.
- *          Here, you'll find interface functions to create, modify, and delete #vrna_fold_compound_t
- *          data structures.
  */
 
 /**
@@ -55,7 +47,22 @@ typedef struct vrna_fc_s vrna_fold_compound_t;
  *
  *  @param data    The data that needs to be free'd
  */
-typedef void (vrna_callback_free_auxdata)(void *data);
+typedef void (*vrna_auxdata_free_f)(void *data);
+
+
+typedef int (*vrna_auxdata_prepare_f)(vrna_fold_compound_t  *fc,
+                                      void                  *data,
+                                      unsigned int          event,
+                                      void                  *event_data);
+
+
+/**
+ *  @brief Callback to free memory allocated for auxiliary user-provided data
+ *
+ *  @deprecated   Use vrna_auxdata_free_f(void *data) instead!
+ */
+DEPRECATED(typedef void (vrna_callback_free_auxdata)(void *data),
+           "Use vrna_auxdata_free_f instead!");
 
 /**
  *  @brief Callback to perform specific user-defined actions before, or after recursive computations
@@ -75,13 +82,18 @@ typedef void (vrna_callback_free_auxdata)(void *data);
  *  @param status   The status indicator
  *  @param data     The data structure that was assigned with vrna_fold_compound_add_auxdata()
  */
-typedef void (vrna_callback_recursion_status)(unsigned char status,
+typedef void (*vrna_recursion_status_f)(unsigned char status,
                                               void          *data);
 
+DEPRECATED(typedef void (vrna_callback_recursion_status)(unsigned char status,
+                                              void          *data),
+           "Use vrna_recursion_status_f instead!");
+
+
 /**
  *  @brief  Status message indicating that MFE computations are about to begin
  *
- *  @see  #vrna_fold_compound_t.stat_cb, vrna_callback_recursion_status(), vrna_mfe(), vrna_fold(), vrna_circfold(),
+ *  @see  #vrna_fold_compound_t.stat_cb, vrna_recursion_status_f(), vrna_mfe(), vrna_fold(), vrna_circfold(),
  *        vrna_alifold(), vrna_circalifold(), vrna_cofold()
  */
 #define VRNA_STATUS_MFE_PRE     (unsigned char)1
@@ -89,7 +101,7 @@ typedef void (vrna_callback_recursion_status)(unsigned char status,
 /**
  *  @brief  Status message indicating that MFE computations are finished
  *
- *  @see  #vrna_fold_compound_t.stat_cb, vrna_callback_recursion_status(), vrna_mfe(), vrna_fold(), vrna_circfold(),
+ *  @see  #vrna_fold_compound_t.stat_cb, vrna_recursion_status_f(), vrna_mfe(), vrna_fold(), vrna_circfold(),
  *        vrna_alifold(), vrna_circalifold(), vrna_cofold()
  */
 #define VRNA_STATUS_MFE_POST    (unsigned char)2
@@ -97,14 +109,14 @@ typedef void (vrna_callback_recursion_status)(unsigned char status,
 /**
  *  @brief  Status message indicating that Partition function computations are about to begin
  *
- *  @see  #vrna_fold_compound_t.stat_cb, vrna_callback_recursion_status(), vrna_pf()
+ *  @see  #vrna_fold_compound_t.stat_cb, vrna_recursion_status_f(), vrna_pf()
  */
 #define VRNA_STATUS_PF_PRE      (unsigned char)3
 
 /**
  *  @brief  Status message indicating that Partition function computations are finished
  *
- *  @see  #vrna_fold_compound_t.stat_cb, vrna_callback_recursion_status(), vrna_pf()
+ *  @see  #vrna_fold_compound_t.stat_cb, vrna_recursion_status_f(), vrna_pf()
  */
 #define VRNA_STATUS_PF_POST     (unsigned char)4
 
@@ -137,10 +149,10 @@ typedef enum {
  *  @brief  The most basic data structure required by many functions throughout the RNAlib
  *
  *  @note   Please read the documentation of this data structure carefully! Some attributes are only available for
- *  specific types this data structure can adopt.
+ *          specific types this data structure can adopt.
  *
  *  @warning  Reading/Writing from/to attributes that are not within the scope of the current type usually result
- *  in undefined behavior!
+ *            in undefined behavior!
  *
  *  @see  #vrna_fold_compound_t.type, vrna_fold_compound(), vrna_fold_compound_comparative(), vrna_fold_compound_free(),
  *        #VRNA_FC_TYPE_SINGLE, #VRNA_FC_TYPE_COMPARATIVE
@@ -192,18 +204,18 @@ struct vrna_fc_s {
    *  @name User-defined data fields
    *  @{
    */
-  vrna_callback_recursion_status  *stat_cb;       /**<  @brief  Recursion status callback (usually called just before, and
-                                                   *            after recursive computations in the library
-                                                   *    @see    vrna_callback_recursion_status(), vrna_fold_compound_add_callback()
-                                                   */
+  vrna_recursion_status_f   stat_cb;       /**<  @brief  Recursion status callback (usually called just before, and
+                                            *            after recursive computations in the library
+                                            *    @see    vrna_recursion_status_f(), vrna_fold_compound_add_callback()
+                                            */
 
-  void                            *auxdata;       /**<  @brief  A pointer to auxiliary, user-defined data
-                                                   *    @see vrna_fold_compound_add_auxdata(), #vrna_fold_compound_t.free_auxdata
-                                                   */
+  void                      *auxdata;      /**<  @brief  A pointer to auxiliary, user-defined data
+                                            *    @see vrna_fold_compound_add_auxdata(), #vrna_fold_compound_t.free_auxdata
+                                            */
 
-  vrna_callback_free_auxdata      *free_auxdata;  /**<  @brief A callback to free auxiliary user data whenever the fold_compound itself is free'd
-                                                   *    @see  #vrna_fold_compound_t.auxdata, vrna_callback_free_auxdata()
-                                                   */
+  vrna_auxdata_free_f       free_auxdata;  /**<  @brief A callback to free auxiliary user data whenever the fold_compound itself is free'd
+                                            *    @see  #vrna_fold_compound_t.auxdata, vrna_auxdata_free_f()
+                                            */
 
   /**
    *  @}
@@ -380,7 +392,7 @@ struct {
  *
  *  @see vrna_fold_compound(), vrna_fold_compound_comparative(), #VRNA_OPTION_EVAL_ONLY
  */
-#define VRNA_OPTION_MFE             1U
+#define VRNA_OPTION_MFE             (1 << 0)
 
 /**
  *  @brief  Option flag to specify requirement of Partition Function (PF) DP matrices
@@ -388,12 +400,12 @@ struct {
  *
  *  @see vrna_fold_compound(), vrna_fold_compound_comparative(), #VRNA_OPTION_EVAL_ONLY
  */
-#define VRNA_OPTION_PF              2U
+#define VRNA_OPTION_PF              (1 << 1)
 
 /**
  *  @brief  Option flag to specify requirement of dimer DP matrices
  */
-#define VRNA_OPTION_HYBRID          4U
+#define VRNA_OPTION_HYBRID          (1 << 2)
 
 /**
  *  @brief  Option flag to specify that neither MFE, nor PF DP matrices are required
@@ -404,12 +416,18 @@ struct {
  *
  *  @see vrna_fold_compound(), vrna_fold_compound_comparative(), vrna_eval_structure()
  */
-#define VRNA_OPTION_EVAL_ONLY       8U
+#define VRNA_OPTION_EVAL_ONLY       (1 << 3)
 
 /**
  *  @brief  Option flag to specify requirement of DP matrices for local folding approaches
  */
-#define VRNA_OPTION_WINDOW          16U
+#define VRNA_OPTION_WINDOW          (1 << 4)
+
+
+#define VRNA_OPTION_F5              (1 << 5)
+#define VRNA_OPTION_F3              (1 << 6)
+#define VRNA_OPTION_WINDOW_F5       (VRNA_OPTION_WINDOW | VRNA_OPTION_F5)
+#define VRNA_OPTION_WINDOW_F3       (VRNA_OPTION_WINDOW | VRNA_OPTION_F3)
 
 /**
  *  @brief  Retrieve a #vrna_fold_compound_t data structure for single sequences and hybridizing sequences
@@ -535,23 +553,23 @@ vrna_fold_compound_free(vrna_fold_compound_t *fc);
  *  @brief  Add auxiliary data to the #vrna_fold_compound_t
  *
  *  This function allows one to bind arbitrary data to a #vrna_fold_compound_t which may later on be used
- *  by one of the callback functions, e.g. vrna_callback_recursion_status(). To allow for proper cleanup
+ *  by one of the callback functions, e.g. vrna_recursion_status_f(). To allow for proper cleanup
  *  of the memory occupied by this auxiliary data, the user may also provide a pointer to a cleanup function
  *  that free's the corresponding memory. This function will be called automatically when the #vrna_fold_compound_t
  *  is free'd with vrna_fold_compound_free().
  *
- *  @note Before attaching the arbitrary data pointer, this function will call the vrna_callback_free_auxdata()
+ *  @note Before attaching the arbitrary data pointer, this function will call the vrna_auxdata_free_f()
  *        on any pre-existing data that is already attached.
  *
- *  @see vrna_callback_free_auxdata()
+ *  @see vrna_auxdata_free_f()
  *  @param  fc    The fold_compound the arbitrary data pointer should be associated with
  *  @param  data  A pointer to an arbitrary data structure
  *  @param  f     A pointer to function that free's memory occupied by the arbitrary data (May be NULL)
  */
 void
-vrna_fold_compound_add_auxdata(vrna_fold_compound_t       *fc,
-                               void                       *data,
-                               vrna_callback_free_auxdata *f);
+vrna_fold_compound_add_auxdata(vrna_fold_compound_t *fc,
+                               void                 *data,
+                               vrna_auxdata_free_f  f);
 
 
 /**
@@ -563,15 +581,15 @@ vrna_fold_compound_add_auxdata(vrna_fold_compound_t       *fc,
  *  #vrna_fold_compound_t, and a status message. Hence, it has complete access to all variables that
  *  incluence the recursive computations.
  *
- *  @see  vrna_callback_recursion_status(), #vrna_fold_compound_t,
+ *  @see  vrna_recursion_status_f(), #vrna_fold_compound_t,
  *        #VRNA_STATUS_MFE_PRE, #VRNA_STATUS_MFE_POST, #VRNA_STATUS_PF_PRE, #VRNA_STATUS_PF_POST
  *
  *  @param  fc    The fold_compound the callback function should be attached to
  *  @param  f     The pointer to the recursion status callback function
  */
 void
-vrna_fold_compound_add_callback(vrna_fold_compound_t            *fc,
-                                vrna_callback_recursion_status  *f);
+vrna_fold_compound_add_callback(vrna_fold_compound_t    *fc,
+                                vrna_recursion_status_f f);
 
 
 /**
