@@ -7,6 +7,7 @@
 #include <ViennaRNA/datastructures/basic.h>
 #include <ViennaRNA/fold_compound.h>
 #include <ViennaRNA/params/basic.h>
+#include <ViennaRNA/params/salt.h>
 
 #ifdef VRNA_WARN_DEPRECATED
 # if defined(DEPRECATED)
@@ -40,7 +41,6 @@
  *
  *  @addtogroup   eval_loops_hp
  *  @{
- *  @brief  Functions to evaluate the free energy contributions for hairpin loops
  */
 
 
@@ -60,7 +60,7 @@
  *  conflict, this function returns #INF.
  *
  *  @note This function is polymorphic! The provided #vrna_fold_compound_t may be of type
- *  #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
+ *        #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
  *
  *  @param fc   The #vrna_fold_compound_t that stores all relevant model settings
  *  @param i    The 5' nucleotide of the base pair (3' to evaluate the pair as exterior hairpin loop)
@@ -78,7 +78,7 @@ vrna_E_hp_loop(vrna_fold_compound_t *fc,
  *          and consider possible hard constraints
  *
  *  @note This function is polymorphic! The provided #vrna_fold_compound_t may be of type
- *  #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
+ *        #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
  *
  */
 int
@@ -100,7 +100,7 @@ vrna_eval_ext_hp_loop(vrna_fold_compound_t  *fc,
  *  @brief Evaluate free energy of a hairpin loop
  *
  *  @note This function is polymorphic! The provided #vrna_fold_compound_t may be of type
- *  #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
+ *        #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
  *
  *  @param  fc  The #vrna_fold_compound_t for the particular energy evaluation
  *  @param  i   5'-position of the base pair
@@ -129,13 +129,15 @@ vrna_eval_hp_loop(vrna_fold_compound_t  *fc,
  *  where X-Y marks the closing pair [e.g. a <B>(G,C)</B> pair]. The length of this loop is 6 as there are
  *  six unpaired nucleotides (a1-a6) enclosed by (X,Y). The 5' mismatching nucleotide is
  *  a1 while the 3' mismatch is a6. The nucleotide sequence of this loop is &quot;a1.a2.a3.a4.a5.a6&quot; <BR>
+ *
  *  @note The parameter sequence should contain the sequence of the loop in capital letters of the nucleic acid
- *  alphabet if the loop size is below 7. This is useful for unusually stable tri-, tetra- and hexa-loops
- *  which are treated differently (based on experimental data) if they are tabulated.
- *  @see scale_parameters()
- *  @see vrna_param_t
- *  @warning Not (really) thread safe! A threadsafe implementation will replace this function in a future release!\n
- *  Energy evaluation may change due to updates in global variable "tetra_loop"
+ *        alphabet if the loop size is below 7. This is useful for unusually stable tri-, tetra- and hexa-loops
+ *        which are treated differently (based on experimental data) if they are tabulated.
+ *
+ *  @see scale_parameters(), vrna_param_t
+ *
+ *  @warning  Not (really) thread safe! A threadsafe implementation will replace this function in a future release!\n
+ *            Energy evaluation may change due to updates in global variable "tetra_loop"
  *
  *  @param  size  The size of the loop (number of unpaired nucleotides)
  *  @param  type  The pair type of the base pair closing the hairpin
@@ -153,12 +155,23 @@ E_Hairpin(int           size,
           const char    *string,
           vrna_param_t  *P)
 {
-  int energy;
+  int energy, salt_correction;
+
+  salt_correction = 0;
+
+  if (P->model_details.salt != VRNA_MODEL_DEFAULT_SALT) {
+    if (size<=MAXLOOP)
+      salt_correction = P->SaltLoop[size+1];
+    else
+      salt_correction = vrna_salt_loop_int(size+1, P->model_details.salt, P->temperature+K0, P->model_details.backbone_length);
+  }
 
   if (size <= 30)
     energy = P->hairpin[size];
   else
     energy = P->hairpin[30] + (int)(P->lxc * log((size) / 30.));
+  
+  energy += salt_correction;
 
   if (size < 3)
     return energy;            /* should only be the case when folding alignments */
@@ -172,7 +185,7 @@ E_Hairpin(int           size,
       memcpy(tl, string, sizeof(char) * 6);
       tl[6] = '\0';
       if ((ts = strstr(P->Tetraloops, tl)))
-        return P->Tetraloop_E[(ts - P->Tetraloops) / 7];
+        return P->Tetraloop_E[(ts - P->Tetraloops) / 7] + salt_correction;
     } else if (size == 6) {
       char tl[9] = {
         0
@@ -180,7 +193,7 @@ E_Hairpin(int           size,
       memcpy(tl, string, sizeof(char) * 8);
       tl[8] = '\0';
       if ((ts = strstr(P->Hexaloops, tl)))
-        return P->Hexaloop_E[(ts - P->Hexaloops) / 9];
+        return P->Hexaloop_E[(ts - P->Hexaloops) / 9] + salt_correction;
     } else if (size == 3) {
       char tl[6] = {
         0
@@ -188,7 +201,7 @@ E_Hairpin(int           size,
       memcpy(tl, string, sizeof(char) * 5);
       tl[5] = '\0';
       if ((ts = strstr(P->Triloops, tl)))
-        return P->Triloop_E[(ts - P->Triloops) / 6];
+        return P->Triloop_E[(ts - P->Triloops) / 6] + salt_correction;
 
       return energy + (type > 2 ? P->TerminalAU : 0);
     }
@@ -213,12 +226,12 @@ E_Hairpin(int           size,
 /**
  *  @brief Compute Boltzmann weight @f$e^{-\Delta G/kT} @f$ of a hairpin loop
  *
- *  multiply by scale[u+2]
- *  @see get_scaled_pf_parameters()
- *  @see vrna_exp_param_t
- *  @see E_Hairpin()
- *  @warning Not (really) thread safe! A threadsafe implementation will replace this function in a future release!\n
- *  Energy evaluation may change due to updates in global variable "tetra_loop"
+ *  @note multiply by scale[u+2]
+ *
+ *  @see get_scaled_pf_parameters(), vrna_exp_param_t, E_Hairpin()
+ *
+ *  @warning  Not (really) thread safe! A threadsafe implementation will replace this function in a future release!\n
+ *            Energy evaluation may change due to updates in global variable "tetra_loop"
  *
  *  @param  u       The size of the loop (number of unpaired nucleotides)
  *  @param  type    The pair type of the base pair closing the hairpin
@@ -236,15 +249,25 @@ exp_E_Hairpin(int               u,
               const char        *string,
               vrna_exp_param_t  *P)
 {
-  double q, kT;
+  double q, kT, salt_correction;
 
   kT = P->kT;   /* kT in cal/mol  */
+  salt_correction = 1.;
+
+  if (P->model_details.salt != VRNA_MODEL_DEFAULT_SALT) {
+    if (u<=MAXLOOP)
+      salt_correction = P->expSaltLoop[u+1];
+    else
+      salt_correction = exp(-vrna_salt_loop_int(u+1, P->model_details.salt, P->temperature+K0, P->model_details.backbone_length) * 10. / kT);
+  }
 
   if (u <= 30)
     q = P->exphairpin[u];
   else
     q = P->exphairpin[30] * exp(-(P->lxc * log(u / 30.)) * 10. / kT);
 
+  q *= salt_correction;
+
   if (u < 3)
     return (FLT_OR_DBL)q;         /* should only be the case when folding alignments */
 
@@ -257,7 +280,7 @@ exp_E_Hairpin(int               u,
       tl[6] = '\0';
       if ((ts = strstr(P->Tetraloops, tl))) {
         if (type != 7)
-          return (FLT_OR_DBL)(P->exptetra[(ts - P->Tetraloops) / 7]);
+          return (FLT_OR_DBL)(P->exptetra[(ts - P->Tetraloops) / 7] * salt_correction);
         else
           q *= P->exptetra[(ts - P->Tetraloops) / 7];
       }
@@ -268,7 +291,7 @@ exp_E_Hairpin(int               u,
       memcpy(tl, string, sizeof(char) * 8);
       tl[8] = '\0';
       if ((ts = strstr(P->Hexaloops, tl)))
-        return (FLT_OR_DBL)(P->exphex[(ts - P->Hexaloops) / 9]);
+        return (FLT_OR_DBL)(P->exphex[(ts - P->Hexaloops) / 9] * salt_correction);
     } else if (u == 3) {
       char tl[6] = {
         0
@@ -276,7 +299,7 @@ exp_E_Hairpin(int               u,
       memcpy(tl, string, sizeof(char) * 5);
       tl[5] = '\0';
       if ((ts = strstr(P->Triloops, tl)))
-        return (FLT_OR_DBL)(P->exptri[(ts - P->Triloops) / 6]);
+        return (FLT_OR_DBL)(P->exptri[(ts - P->Triloops) / 6] * salt_correction);
 
       if (type > 2)
         return (FLT_OR_DBL)(q * P->expTermAU);
@@ -297,7 +320,7 @@ exp_E_Hairpin(int               u,
  *  @see vrna_E_hp_loop() for it's free energy counterpart
  *
  *  @note This function is polymorphic! The provided #vrna_fold_compound_t may be of type
- *  #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
+ *        #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
  *
  */
 FLT_OR_DBL
@@ -324,7 +347,7 @@ vrna_exp_E_hp_loop(vrna_fold_compound_t *fc,
  *  @brief Backtrack a hairpin loop closed by @f$ (i,j) @f$
  *
  *  @note This function is polymorphic! The provided #vrna_fold_compound_t may be of type
- *  #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
+ *        #VRNA_FC_TYPE_SINGLE or #VRNA_FC_TYPE_COMPARATIVE
  *
  */
 int
