@@ -375,7 +375,7 @@ E_internal_loop(vrna_fold_compound_t  *fc,
   vrna_md_t             *md;
   vrna_ud_t             *domains_up;
   struct hc_int_def_dat hc_dat_local;
-  eval_hc               *evaluate;
+  eval_hc               evaluate;
   struct sc_int_dat     sc_wrapper;
 
   evaluate = prepare_hc_int_def(fc, &hc_dat_local);
@@ -780,8 +780,6 @@ E_internal_loop(vrna_fold_compound_t  *fc,
 
       if (with_gquad) {
         /* include all cases where a g-quadruplex may be enclosed by base pair (i,j) */
-        eee = INF;
-
         switch (fc->type) {
           case VRNA_FC_TYPE_SINGLE:
             if (sliding_window)
@@ -789,6 +787,7 @@ E_internal_loop(vrna_fold_compound_t  *fc,
             else if (sn[j] == sn[i])
               eee = E_GQuad_IntLoop(i, j, type, S, ggg, idx, P);
 
+            e = MIN2(e, eee);
             break;
 
           case VRNA_FC_TYPE_COMPARATIVE:
@@ -817,10 +816,9 @@ E_internal_loop(vrna_fold_compound_t  *fc,
                                                 P);
             }
 
+            e = MIN2(e, eee);
             break;
         }
-
-        e = MIN2(e, eee);
       }
 
       free(tt);
@@ -847,7 +845,7 @@ E_ext_internal_loop(vrna_fold_compound_t  *fc,
   short                 **SS;
   vrna_md_t             *md;
   vrna_param_t          *P;
-  eval_hc               *evaluate;
+  eval_hc               evaluate;
   struct hc_int_def_dat hc_dat_local;
 
   n     = fc->length;
@@ -936,7 +934,7 @@ E_stack(vrna_fold_compound_t  *fc,
   int                   e, ij, pq, p, q, s, n_seq, *rtype, *indx;
   vrna_param_t          *P;
   vrna_md_t             *md;
-  eval_hc               *evaluate;
+  eval_hc               evaluate;
   struct hc_int_def_dat hc_dat_local;
   struct sc_int_dat     sc_wrapper;
 
