@@ -10,6 +10,7 @@
 #include <ViennaRNA/params/basic.h>
 #include <ViennaRNA/constraints/hard.h>
 #include <ViennaRNA/constraints/soft.h>
+#include <ViennaRNA/params/salt.h>
 
 #ifdef VRNA_WARN_DEPRECATED
 # if defined(DEPRECATED)
@@ -41,7 +42,6 @@
 /**
  *  @addtogroup   eval_loops_int
  *  @{
- *  @brief  Functions to evaluate the free energy contributions for internal loops
  */
 
 
@@ -194,11 +194,12 @@ vrna_BT_int_loop(vrna_fold_compound_t *fc,
  *  and for the enclosed base pair (V,U):<BR>
  *  5'-mismatch: b_1<BR>
  *  3'-mismatch: a_n<BR>
+ *
  *  @note Base pairs are always denoted in 5'->3' direction. Thus the enclosed base pair
- *  must be 'turned arround' when evaluating the free energy of the interior-loop
- *  @see scale_parameters()
- *  @see vrna_param_t
- *  @note This function is threadsafe
+ *        must be 'turned arround' when evaluating the free energy of the interior-loop<br>
+ *        This function is threadsafe
+ *
+ *  @see scale_parameters(), vrna_param_t
  *
  *  @param  n1      The size of the 'left'-loop (number of unpaired nucleotides)
  *  @param  n2      The size of the 'right'-loop (number of unpaired nucleotides)
@@ -225,11 +226,11 @@ PRIVATE INLINE int E_IntLoop(int          n1,
 /**
  *  <H2>Compute Boltzmann weight @f$e^{-\Delta G/kT} @f$ of interior loop</H2>
  *  multiply by scale[u1+u2+2] for scaling
- *  @see get_scaled_pf_parameters()
- *  @see vrna_exp_param_t
- *  @see E_IntLoop()
+ *
  *  @note This function is threadsafe
  *
+ *  @see get_scaled_pf_parameters(), vrna_exp_param_t, E_IntLoop()
+ *
  *  @param  u1      The size of the 'left'-loop (number of unpaired nucleotides)
  *  @param  u2      The size of the 'right'-loop (number of unpaired nucleotides)
  *  @param  type    The pair type of the base pair closing the interior loop
@@ -488,7 +489,10 @@ E_IntLoop(int           n1,
           vrna_param_t  *P)
 {
   /* compute energy of degree 2 loop (stack bulge or interior) */
-  int nl, ns, u, energy;
+  int nl, ns, u, energy, salt_stack_correction, salt_loop_correction, backbones;
+
+  salt_stack_correction = P->SaltStack;
+  salt_loop_correction = 0;
 
   if (n1 > n2) {
     nl  = n1;
@@ -498,8 +502,19 @@ E_IntLoop(int           n1,
     ns  = n1;
   }
 
-  if (nl == 0)
-    return P->stack[type][type_2];  /* stack */
+  if (nl == 0) {
+    return P->stack[type][type_2] + salt_stack_correction;  /* stack */
+  }
+  
+  backbones = nl+ns+2;
+
+  if (P->model_details.salt != VRNA_MODEL_DEFAULT_SALT) {
+    /* salt correction for loop */
+    if (backbones <= MAXLOOP+1)
+      salt_loop_correction = P->SaltLoop[backbones];
+    else
+      salt_loop_correction = vrna_salt_loop_int(backbones, P->model_details.salt, P->temperature+K0, P->model_details.backbone_length);
+  }
 
   if (ns == 0) {
     /* bulge */
@@ -514,13 +529,11 @@ E_IntLoop(int           n1,
       if (type_2 > 2)
         energy += P->TerminalAU;
     }
-
-    return energy;
   } else {
     /* interior loop */
     if (ns == 1) {
       if (nl == 1)                    /* 1x1 loop */
-        return P->int11[type][type_2][si1][sj1];
+        return P->int11[type][type_2][si1][sj1] + salt_loop_correction;
 
       if (nl == 2) {
         /* 2x1 loop */
@@ -529,7 +542,7 @@ E_IntLoop(int           n1,
         else
           energy = P->int21[type_2][type][sq1][si1][sp1];
 
-        return energy;
+        return energy + salt_loop_correction;
       } else {
         /* 1xn loop */
         energy =
@@ -538,17 +551,17 @@ E_IntLoop(int           n1,
                                                     (int)(P->lxc * log((nl + 1) / 30.)));
         energy  += MIN2(MAX_NINIO, (nl - ns) * P->ninio[2]);
         energy  += P->mismatch1nI[type][si1][sj1] + P->mismatch1nI[type_2][sq1][sp1];
-        return energy;
+        return energy + salt_loop_correction;
       }
     } else if (ns == 2) {
       if (nl == 2) {
         /* 2x2 loop */
-        return P->int22[type][type_2][si1][sp1][sq1][sj1];
+        return P->int22[type][type_2][si1][sp1][sq1][sj1] + salt_loop_correction;
       } else if (nl == 3) {
         /* 2x3 loop */
         energy  = P->internal_loop[5] + P->ninio[2];
         energy  += P->mismatch23I[type][si1][sj1] + P->mismatch23I[type_2][sq1][sp1];
-        return energy;
+        return energy + salt_loop_correction;
       }
     }
 
@@ -565,7 +578,7 @@ E_IntLoop(int           n1,
     }
   }
 
-  return energy;
+  return energy + salt_loop_correction;
 }
 
 
@@ -583,6 +596,9 @@ exp_E_IntLoop(int               u1,
   int     ul, us, no_close = 0;
   double  z           = 0.;
   int     noGUclosure = P->model_details.noGUclosure;
+  int     backbones;
+  double  salt_stack_correction = P->expSaltStack;
+  double  salt_loop_correction = 1.;
 
   if ((noGUclosure) && ((type2 == 3) || (type2 == 4) || (type == 3) || (type == 4)))
     no_close = 1;
@@ -595,9 +611,19 @@ exp_E_IntLoop(int               u1,
     us  = u1;
   }
 
+  /* salt correction for loop */
+  backbones = ul+us+2;
+
+  if (P->model_details.salt != VRNA_MODEL_DEFAULT_SALT) {
+    if (backbones <= MAXLOOP+1)
+      salt_loop_correction = P->expSaltLoop[backbones];
+    else
+      salt_loop_correction = exp(-vrna_salt_loop_int(backbones, P->model_details.salt, P->temperature+K0, P->model_details.backbone_length) * 10. / P->kT);
+  }
+
   if (ul == 0) {
     /* stack */
-    z = P->expstack[type][type2];
+    z = P->expstack[type][type2] * salt_stack_correction;
   } else if (!no_close) {
     if (us == 0) {
       /* bulge */
@@ -612,39 +638,39 @@ exp_E_IntLoop(int               u1,
           z *= P->expTermAU;
       }
 
-      return (FLT_OR_DBL)z;
+      return (FLT_OR_DBL)(z * salt_loop_correction);
     } else if (us == 1) {
       if (ul == 1)                     /* 1x1 loop */
-        return (FLT_OR_DBL)(P->expint11[type][type2][si1][sj1]);
+        return (FLT_OR_DBL)(P->expint11[type][type2][si1][sj1] * salt_loop_correction);
 
       if (ul == 2) {
         /* 2x1 loop */
         if (u1 == 1)
-          return (FLT_OR_DBL)(P->expint21[type][type2][si1][sq1][sj1]);
+          return (FLT_OR_DBL)(P->expint21[type][type2][si1][sq1][sj1] * salt_loop_correction);
         else
-          return (FLT_OR_DBL)(P->expint21[type2][type][sq1][si1][sp1]);
+          return (FLT_OR_DBL)(P->expint21[type2][type][sq1][si1][sp1] * salt_loop_correction);
       } else {
         /* 1xn loop */
         z = P->expinternal[ul + us] * P->expmismatch1nI[type][si1][sj1] *
             P->expmismatch1nI[type2][sq1][sp1];
-        return (FLT_OR_DBL)(z * P->expninio[2][ul - us]);
+        return (FLT_OR_DBL)(z * P->expninio[2][ul - us] * salt_loop_correction);
       }
     } else if (us == 2) {
       if (ul == 2) {
         /* 2x2 loop */
-        return (FLT_OR_DBL)(P->expint22[type][type2][si1][sp1][sq1][sj1]);
+        return (FLT_OR_DBL)(P->expint22[type][type2][si1][sp1][sq1][sj1] * salt_loop_correction);
       } else if (ul == 3) {
         /* 2x3 loop */
         z = P->expinternal[5] * P->expmismatch23I[type][si1][sj1] *
             P->expmismatch23I[type2][sq1][sp1];
-        return (FLT_OR_DBL)(z * P->expninio[2][1]);
+        return (FLT_OR_DBL)(z * P->expninio[2][1] * salt_loop_correction);
       }
     }
 
     /* generic interior loop (no else here!)*/
     z = P->expinternal[ul + us] * P->expmismatchI[type][si1][sj1] *
         P->expmismatchI[type2][sq1][sp1];
-    return (FLT_OR_DBL)(z * P->expninio[2][ul - us]);
+    return (FLT_OR_DBL)(z * P->expninio[2][ul - us] * salt_loop_correction);
   }
 
   return (FLT_OR_DBL)z;
@@ -667,6 +693,18 @@ E_IntLoop_Co(int          type,
              vrna_param_t *P)
 {
   int e, energy, ci, cj, cp, cq, d3, d5, d5_2, d3_2, tmm, tmm_2;
+  int salt_loop_correction, backbones;
+
+  salt_loop_correction = 0;
+
+  backbones = p - i + j - q;
+  /* salt correction for loop */
+  if (P->model_details.salt != VRNA_MODEL_DEFAULT_SALT) {
+    if (backbones <= MAXLOOP+1)
+      salt_loop_correction = P->SaltLoop[backbones];
+    else
+      salt_loop_correction = vrna_salt_loop_int(backbones, P->model_details.salt, P->temperature+K0, P->model_details.backbone_length);
+  }
 
   energy = 0;
   if (type > 2)
@@ -676,7 +714,7 @@ E_IntLoop_Co(int          type,
     energy += P->TerminalAU;
 
   if (!dangles)
-    return energy;
+    return energy + salt_loop_correction;
 
   ci  = ON_SAME_STRAND(i, i + 1, cutpoint);
   cj  = ON_SAME_STRAND(j - 1, j, cutpoint);
@@ -692,7 +730,7 @@ E_IntLoop_Co(int          type,
   tmm_2 = (cp && cq) ? P->mismatchExt[type_2][sp1][sq1] : d5_2 + d3_2;
 
   if (dangles == 2)
-    return energy + tmm + tmm_2;
+    return energy + tmm + tmm_2 + salt_loop_correction;
 
   /* now we may have non-double dangles only */
   if (p - i > 2) {
@@ -754,7 +792,7 @@ E_IntLoop_Co(int          type,
     }
   }
 
-  return energy;
+  return energy + salt_loop_correction;
 }
 
 
