@@ -29,38 +29,10 @@
  *  MFE folding...
  */
 
-/**
- *  @addtogroup mfe
- *  @{
- *  @brief  Predicting the Minimum Free Energy (MFE) and a corresponding (consensus) secondary structure
- *
- *  In a nutshell we provide two different flavors for MFE prediction:
- *  * @ref mfe_global - to compute the MFE for the entire sequence
- *  * @ref mfe_window - to compute MFEs for each window using a sliding window approach
- *
- *  Each of these flavors, again, provides two implementations to either compute the MFE based on
- *  *  single RNA (DNA) sequence(s), or
- *  *  a comparative approach using multiple sequence alignments (MSA).
- *
- *  For the latter, a consensus secondary structure is predicted and our implementations compute
- *  an average of free energies for each sequence in the MSA plus an additional covariance
- *  pseudo-energy term.
- *
- *  The implementations for @ref mfe_backtracking are generally agnostic with respect to whether
- *  local or global structure prediction is in place.
- *  @}
- */
-
 
 /**
  *  @addtogroup  mfe_global
  *  @{
- *  @brief  Variations of the global Minimum Free Energy (MFE) prediction algorithm
- *
- *  We provide implementations of the global MFE prediction algorithm for
- *  * Single sequences,
- *  * Multiple sequence alignments (MSA), and
- *  * RNA-RNA hybrids
  */
 
 /**
@@ -88,14 +60,14 @@
  *  @see #vrna_fold_compound_t, vrna_fold_compound(), vrna_fold(), vrna_circfold(),
  *        vrna_fold_compound_comparative(), vrna_alifold(), vrna_circalifold()
  *
- *  @param vc             fold compound
+ *  @param fc             fold compound
  *  @param structure      A pointer to the character array where the
  *                        secondary structure in dot-bracket notation will be written to (Maybe NULL)
  *
  *  @return the minimum free energy (MFE) in kcal/mol
  */
 float
-vrna_mfe(vrna_fold_compound_t *vc,
+vrna_mfe(vrna_fold_compound_t *fc,
          char                 *structure);
 
 
@@ -110,12 +82,12 @@ vrna_mfe(vrna_fold_compound_t *vc,
  *
  *  @see  vrna_mfe()
  *
- *  @param    vc  fold compound
+ *  @param    fc  fold compound
  *  @param    structure Will hold the barcket dot structure of the dimer molecule
  *  @return   minimum free energy of the structure
  */
 DEPRECATED(float
-           vrna_mfe_dimer(vrna_fold_compound_t  *vc,
+           vrna_mfe_dimer(vrna_fold_compound_t  *fc,
                           char                  *structure),
            "Use vrna_mfe() instead");
 
@@ -140,8 +112,8 @@ DEPRECATED(float
  *  matrices are not available any more for any post-processing, e.g. suboptimal backtracking, etc.
  *
  *  @note In case you want to use the filled DP matrices for any subsequent post-processing step, or
- *  you require other conditions than specified by the default model details, use vrna_mfe(),
- *  and the data structure #vrna_fold_compound_t instead.
+ *        you require other conditions than specified by the default model details, use vrna_mfe(),
+ *        and the data structure #vrna_fold_compound_t instead.
  *
  *  @see vrna_circfold(), vrna_mfe()
  *
@@ -164,11 +136,11 @@ vrna_fold(const char  *sequence,
  *  matrices are not available any more for any post-processing, e.g. suboptimal backtracking, etc.
  *
  *  Folding of circular RNA sequences is handled as a post-processing step of the forward
- *  recursions. See @cite hofacker:2006 for further details.
+ *  recursions. See @rstinline :cite:t:`hofacker:2006` @endrst for further details.
  *
  *  @note In case you want to use the filled DP matrices for any subsequent post-processing step, or
- *  you require other conditions than specified by the default model details, use vrna_mfe(),
- *  and the data structure #vrna_fold_compound_t instead.
+ *        you require other conditions than specified by the default model details, use vrna_mfe(),
+ *        and the data structure #vrna_fold_compound_t instead.
  *
  *  @see vrna_fold(), vrna_mfe()
  *
@@ -193,8 +165,8 @@ vrna_circfold(const char  *sequence,
  *  backtracking, etc.
  *
  *  @note In case you want to use the filled DP matrices for any subsequent post-processing step, or
- *  you require other conditions than specified by the default model details, use vrna_mfe(),
- *  and the data structure #vrna_fold_compound_t instead.
+ *        you require other conditions than specified by the default model details, use vrna_mfe(),
+ *        and the data structure #vrna_fold_compound_t instead.
  *
  *  @see vrna_circalifold(), vrna_mfe()
  *
@@ -219,11 +191,11 @@ vrna_alifold(const char **sequences,
  *  backtracking, etc.
  *
  *  Folding of circular RNA sequences is handled as a post-processing step of the forward
- *  recursions. See @cite hofacker:2006 for further details.
+ *  recursions. See @rstinline :cite:t:`hofacker:2006` @endrst for further details.
  *
  *  @note In case you want to use the filled DP matrices for any subsequent post-processing step, or
- *  you require other conditions than specified by the default model details, use vrna_mfe(),
- *  and the data structure #vrna_fold_compound_t instead.
+ *        you require other conditions than specified by the default model details, use vrna_mfe(),
+ *        and the data structure #vrna_fold_compound_t instead.
  *
  *  @see vrna_alifold(), vrna_mfe()
  *
@@ -247,8 +219,8 @@ vrna_circalifold(const char **sequences,
  *  backtracking, etc.
  *
  *  @note In case you want to use the filled DP matrices for any subsequent post-processing step, or
- *  you require other conditions than specified by the default model details, use vrna_mfe(),
- *  and the data structure #vrna_fold_compound_t instead.
+ *        you require other conditions than specified by the default model details, use vrna_mfe(),
+ *        and the data structure #vrna_fold_compound_t instead.
  *
  *  @deprecated This function is obsolete since vrna_mfe()/vrna_fold() can handle complexes multiple
  *              sequences since v2.5.0. Use vrna_mfe()/vrna_fold() for connected component MFE instead
@@ -280,14 +252,13 @@ DEPRECATED(float
 /**
  *  @addtogroup mfe_backtracking
  *  @{
- *  @brief   Backtracking related interfaces
  */
 
 /**
  *  @brief
  */
 int
-vrna_backtrack_from_intervals(vrna_fold_compound_t  *vc,
+vrna_backtrack_from_intervals(vrna_fold_compound_t  *fc,
                               vrna_bp_stack_t       *bp_stack,
                               sect                  bt_stack[],
                               int                   s);
