@@ -99,9 +99,9 @@ backtrack(vrna_fold_compound_t  *vc,
 PRIVATE int
 fill_arrays(vrna_fold_compound_t            *vc,
             int                             *underflow,
-            vrna_mfe_window_callback        *cb,
+            vrna_mfe_window_f        cb,
 #ifdef VRNA_WITH_SVM
-            vrna_mfe_window_zscore_callback *cb_z,
+            vrna_mfe_window_zscore_f cb_z,
 #endif
             void                            *data);
 
@@ -220,7 +220,7 @@ vrna_mfe_window(vrna_fold_compound_t  *vc,
 
 PUBLIC float
 vrna_mfe_window_cb(vrna_fold_compound_t     *vc,
-                   vrna_mfe_window_callback *cb,
+                   vrna_mfe_window_f cb,
                    void                     *data)
 {
   int   energy, underflow, n_seq;
@@ -268,7 +268,7 @@ vrna_mfe_window_zscore(vrna_fold_compound_t *vc,
 PUBLIC float
 vrna_mfe_window_zscore_cb(vrna_fold_compound_t            *vc,
                           double                          min_z,
-                          vrna_mfe_window_zscore_callback *cb_z,
+                          vrna_mfe_window_zscore_f cb_z,
                           void                            *data)
 {
   int   energy, underflow;
@@ -285,7 +285,10 @@ vrna_mfe_window_zscore_cb(vrna_fold_compound_t            *vc,
     return (float)(INF / 100.);
   }
 
-  vrna_zsc_filter_update(vc, min_z, VRNA_ZSCORE_OPTIONS_NONE);
+  if (!vc->zscore_data)
+    vrna_zsc_filter_init(vc, min_z, VRNA_ZSCORE_SETTINGS_DEFAULT);
+  else
+    vrna_zsc_filter_update(vc, min_z, VRNA_ZSCORE_OPTIONS_NONE);
 
   /* keep track of how many times we were close to an integer underflow */
   underflow = 0;
@@ -353,7 +356,7 @@ allocate_dp_matrices(vrna_fold_compound_t *fc)
             sc->energy_up[i] = (int *)vrna_alloc(sizeof(int) * (maxdist + 5));
 
         for (i = length; (i > length - maxdist - 5) && (i >= 0); i--)
-          vrna_sc_update(fc, i, VRNA_OPTION_MFE | VRNA_OPTION_WINDOW);
+          vrna_sc_update(fc, i, VRNA_OPTION_MFE | VRNA_OPTION_WINDOW_F3);
       }
 
       break;
@@ -508,15 +511,15 @@ init_constraints(vrna_fold_compound_t *fc)
     case VRNA_FC_TYPE_SINGLE:
       for (i = length; (i >= length - maxdist - 4) && (i > 0); i--) {
         make_ptypes(fc, i);
-        vrna_hc_update(fc, i, VRNA_CONSTRAINT_WINDOW_UPDATE_3);
-        vrna_sc_update(fc, i, VRNA_OPTION_MFE | VRNA_OPTION_WINDOW);
+        vrna_hc_update(fc, i, VRNA_OPTION_WINDOW_F3);
+        vrna_sc_update(fc, i, VRNA_OPTION_MFE | VRNA_OPTION_WINDOW_F3);
       }
       break;
 
     case VRNA_FC_TYPE_COMPARATIVE:
       for (i = length; (i >= length - maxdist - 4) && (i > 0); i--) {
         make_pscores(fc, i);
-        vrna_hc_update(fc, i, VRNA_CONSTRAINT_WINDOW_UPDATE_3);
+        vrna_hc_update(fc, i, VRNA_OPTION_WINDOW_F3);
       }
 
       /* for noLP option */
@@ -544,8 +547,8 @@ rotate_constraints(vrna_fold_compound_t *fc,
         fc->ptype_local[i + maxdist + 4]  = NULL;
         if (i > 1) {
           make_ptypes(fc, i - 1);
-          vrna_hc_update(fc, i - 1, VRNA_CONSTRAINT_WINDOW_UPDATE_3);
-          vrna_sc_update(fc, i - 1, VRNA_OPTION_MFE | VRNA_OPTION_WINDOW);
+          vrna_hc_update(fc, i - 1, VRNA_OPTION_WINDOW_F3);
+          vrna_sc_update(fc, i - 1, VRNA_OPTION_MFE | VRNA_OPTION_WINDOW_F3);
         }
       }
 
@@ -559,7 +562,7 @@ rotate_constraints(vrna_fold_compound_t *fc,
           if (i > 2)
             make_pscores(fc, i - 2);
 
-          vrna_hc_update(fc, i - 1, VRNA_CONSTRAINT_WINDOW_UPDATE_3);
+          vrna_hc_update(fc, i - 1, VRNA_OPTION_WINDOW_F3);
         } else if (i == 1) {
           free(fc->pscore_local[i - 1]);
           fc->pscore_local[i - 1]           = fc->pscore_local[i + maxdist + 4];
@@ -575,9 +578,9 @@ rotate_constraints(vrna_fold_compound_t *fc,
 PRIVATE int
 fill_arrays(vrna_fold_compound_t            *vc,
             int                             *underflow,
-            vrna_mfe_window_callback        *cb,
+            vrna_mfe_window_f        cb,
 #ifdef VRNA_WITH_SVM
-            vrna_mfe_window_zscore_callback *cb_z,
+            vrna_mfe_window_zscore_f cb_z,
 #endif
             void                            *data)
 {
