@@ -79,6 +79,12 @@ FLT_OR_DBL      *pr               = NULL; /* base pairing prob. matrix */
 int             *iindx            = NULL; /* pr[i,j] -> pr[iindx[i]-j] */
 int             fold_constrained  = 0;    /* fold with constraints */
 
+double          salt             = VRNA_MODEL_DEFAULT_SALT;
+int             saltDPXInit      = VRNA_MODEL_DEFAULT_SALT_DPXINIT;
+float           saltDPXInitFact  = VRNA_MODEL_DEFAULT_SALT_DPXINIT_FACT;
+float           helical_rise     = VRNA_MODEL_DEFAULT_HELICAL_RISE;
+float           backbone_length  = VRNA_MODEL_DEFAULT_BACKBONE_LENGTH;
+
 #endif
 
 /*
@@ -149,7 +155,14 @@ PRIVATE vrna_md_t defaults = {
   BP_REV_DEFAULT,
   BP_ALIAS_DEFAULT,
   BP_ENCODING_DEFAULT,
-  DM_DEFAULT
+  DM_DEFAULT,
+  VRNA_MODEL_DEFAULT_SALT,
+  VRNA_MODEL_DEFAULT_SALT_MLLOWER,
+  VRNA_MODEL_DEFAULT_SALT_MLUPPER,
+  VRNA_MODEL_DEFAULT_SALT_DPXINIT,
+  VRNA_MODEL_DEFAULT_SALT_DPXINIT_FACT,
+  VRNA_MODEL_DEFAULT_HELICAL_RISE,
+  VRNA_MODEL_DEFAULT_BACKBONE_LENGTH
 };
 
 /*
@@ -354,7 +367,13 @@ vrna_md_defaults_reset(vrna_md_t *md_p)
   defaults.pf_smooth        = VRNA_MODEL_DEFAULT_PF_SMOOTH;
   defaults.sfact            = 1.07;
   defaults.nonstandards[0]  = '\0';
-
+  defaults.salt             = VRNA_MODEL_DEFAULT_SALT;
+  defaults.saltMLLower      = VRNA_MODEL_DEFAULT_SALT_MLLOWER;
+  defaults.saltMLUpper      = VRNA_MODEL_DEFAULT_SALT_MLUPPER;
+  defaults.saltDPXInit      = VRNA_MODEL_DEFAULT_SALT_DPXINIT;
+  defaults.saltDPXInitFact  = VRNA_MODEL_DEFAULT_SALT_DPXINIT_FACT;
+  defaults.helical_rise     = VRNA_MODEL_DEFAULT_HELICAL_RISE;
+  defaults.backbone_length  = VRNA_MODEL_DEFAULT_BACKBONE_LENGTH;
   if (md_p) {
     /* now try to apply user settings */
     /*
@@ -387,6 +406,13 @@ vrna_md_defaults_reset(vrna_md_t *md_p)
     vrna_md_defaults_betaScale(md_p->betaScale);
     vrna_md_defaults_pf_smooth(md_p->pf_smooth);
     vrna_md_defaults_sfact(md_p->sfact);
+    vrna_md_defaults_salt(md_p->salt);
+    vrna_md_defaults_saltMLLower(md_p->saltMLLower);
+    vrna_md_defaults_saltMLUpper(md_p->saltMLUpper);
+    vrna_md_defaults_saltDPXInit(md_p->saltDPXInit);
+    vrna_md_defaults_saltDPXInitFact(md_p->saltDPXInitFact);
+    vrna_md_defaults_helical_rise(md_p->helical_rise);
+    vrna_md_defaults_backbone_length(md_p->backbone_length);
     copy_nonstandards(&defaults, &(md_p->nonstandards[0]));
   }
 
@@ -414,6 +440,10 @@ vrna_md_defaults_reset(vrna_md_t *md_p)
   cv_fact         = defaults.cv_fact;
   nc_fact         = defaults.nc_fact;
   logML           = defaults.logML;
+  salt            = defaults.salt;
+  saltDPXInit     = defaults.saltDPXInit;
+  helical_rise    = defaults.helical_rise;
+  backbone_length = defaults.backbone_length;
 #endif
 }
 
@@ -842,6 +872,105 @@ vrna_md_defaults_sfact_get(void)
 }
 
 
+PUBLIC void
+vrna_md_defaults_salt(double value)
+{
+  defaults.salt = value;
+#ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
+  salt = value;
+#endif
+}
+
+PUBLIC double
+vrna_md_defaults_salt_get(void)
+{
+  return defaults.salt;
+}
+
+
+PUBLIC void
+vrna_md_defaults_saltMLLower(int lower)
+{
+  defaults.saltMLLower = lower;
+}
+
+PUBLIC int 
+vrna_md_defaults_saltMLLower_get(void)
+{
+  return defaults.saltMLLower;
+}
+
+
+PUBLIC void
+vrna_md_defaults_saltMLUpper(int upper)
+{
+  defaults.saltMLUpper = upper;
+}
+
+PUBLIC int 
+vrna_md_defaults_saltMLUpper_get(void)
+{
+  return defaults.saltMLUpper;
+}
+
+
+PUBLIC void
+vrna_md_defaults_saltDPXInit(int value)
+{
+  defaults.saltDPXInit = value;
+#ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
+  saltDPXInit = value;
+#endif
+}
+
+PUBLIC int 
+vrna_md_defaults_saltDPXInit_get(void)
+{
+  return defaults.saltDPXInit;
+}
+
+PUBLIC void
+vrna_md_defaults_saltDPXInitFact(float value)
+{
+  defaults.saltDPXInitFact = value;
+}
+
+PUBLIC float
+vrna_md_defaults_saltDPXInitFact_get(void)
+{
+  return defaults.saltDPXInitFact;
+}
+
+PUBLIC void
+vrna_md_defaults_helical_rise(float value)
+{
+  defaults.helical_rise = value;
+#ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
+  helical_rise = value;
+#endif
+}
+
+PUBLIC float
+vrna_md_defaults_helical_rise_get(void)
+{
+  return defaults.helical_rise;
+}
+
+PUBLIC void
+vrna_md_defaults_backbone_length(float value)
+{
+  defaults.backbone_length = value;
+#ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
+  backbone_length = value;
+#endif
+}
+
+PUBLIC float
+vrna_md_defaults_backbone_length_get(void)
+{
+  return defaults.backbone_length;
+}
+
 PUBLIC void
 vrna_md_update(vrna_md_t *md)
 {
@@ -1017,6 +1146,13 @@ set_model_details(vrna_md_t *md)
     md->betaScale       = VRNA_MODEL_DEFAULT_BETA_SCALE;
     md->pf_smooth       = VRNA_MODEL_DEFAULT_PF_SMOOTH;
     md->sfact           = 1.07;
+    md->salt            = defaults.salt;
+    md->saltMLLower     = defaults.saltMLLower;
+    md->saltMLUpper     = defaults.saltMLUpper;
+    md->saltDPXInit     = defaults.saltDPXInit;
+    md->saltDPXInitFact = defaults.saltDPXInitFact;
+    md->helical_rise    = defaults.helical_rise;
+    md->backbone_length = defaults.backbone_length;
 
     if (nonstandards)
       copy_nonstandards(md, nonstandards);
