@@ -10,8 +10,6 @@
 /**
  *  @addtogroup   model_details
  *  @{
- *    @brief      Functions and data structures to fine-tune the implemented
- *                secondary structure evaluation model.
  */
 
 #ifndef NBASES
@@ -25,47 +23,56 @@ typedef struct vrna_md_s vrna_md_t;
  *  @brief
  *  @htmlonly Default temperature for structure prediction and free energy evaluation in &#176C @endhtmlonly
  *  @latexonly Default temperature for structure prediction and free energy evaluation in $^\circ C$ @endlatexonly
+ *
  *  @see  #vrna_md_t.temperature, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_TEMPERATURE    37.0
 
 /**
  *  @brief  Default scaling factor for partition function computations
+ *
  *  @see  #vrna_exp_param_t.pf_scale, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_PF_SCALE       -1
 
 /**
  *  @brief  Default scaling factor for absolute thermodynamic temperature in Boltzmann factors
+ *
  *  @see    #vrna_exp_param_t.alpha, #vrna_md_t.betaScale, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_BETA_SCALE     1.
 
-/** @brief  Default dangling end model
+/**
+ *  @brief  Default dangling end model
+ *
  *  @see  #vrna_md_t.dangles, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_DANGLES        2
 
 /**
  *  @brief  Default model behavior for lookup of special tri-, tetra-, and hexa-loops
+ *
  *  @see    #vrna_md_t.special_hp, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_SPECIAL_HP     1
 
 /**
  *  @brief  Default model behavior for so-called 'lonely pairs'
+ *
  *  @see    #vrna_md_t.noLP, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_NO_LP          0
 
 /**
  *  @brief  Default model behavior for G-U base pairs
+ *
  *  @see    #vrna_md_t.noGU, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_NO_GU          0
 
 /**
  *  @brief  Default model behavior for G-U base pairs closing a loop
+ *
  *  @see    #vrna_md_t.noGUclosure, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_NO_GU_CLOSURE  0
@@ -78,18 +85,21 @@ typedef struct vrna_md_s vrna_md_t;
 
 /**
  *  @brief  Default model behavior regarding the treatment of G-Quadruplexes
+ *
  *  @see    #vrna_md_t.gquad, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_GQUAD          0
 
 /**
  *  @brief  Default behavior of the model regarding unique multi-branch loop decomposition
+ *
  *  @see    #vrna_md_t.uniq_ML, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_UNIQ_ML        0
 
 /**
  *  @brief  Default model behavior on which energy set to use
+ *
  *  @see    #vrna_md_t.energy_set, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_ENERGY_SET     0
@@ -102,30 +112,35 @@ typedef struct vrna_md_s vrna_md_t;
 
 /**
  *  @brief  Default model behavior on what type of backtracking to perform
+ *
  *  @see    #vrna_md_t.backtrack_type, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_BACKTRACK_TYPE 'F'
 
 /**
  *  @brief  Default model behavior with regards to computing base pair probabilities
+ *
  *  @see    #vrna_md_t.compute_bpp, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_COMPUTE_BPP    1
 
 /**
  *  @brief  Default model behavior for the allowed maximum base pair span
+ *
  *  @see    #vrna_md_t.max_bp_span, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_MAX_BP_SPAN    -1
 
 /**
  *  @brief  Default model behavior for the sliding window approach
+ *
  *  @see    #vrna_md_t.window_size, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_WINDOW_SIZE    -1
 
 /**
  *  @brief  Default model behavior on how to evaluate the energy contribution of multi-branch loops
+ *
  *  @see    #vrna_md_t.logML, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_LOG_ML         0
@@ -138,17 +153,20 @@ typedef struct vrna_md_s vrna_md_t;
 
 /**
  *  @brief  Default model behavior for consensus structure co-variance contribution assessment
+ *
  *  @see    #vrna_md_t.ribo, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_ALI_RIBO       0
 
 /**
  *  @brief  Default model behavior for weighting the co-variance score in consensus structure prediction
+ *
  *  @see    #vrna_md_t.cv_fact, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_ALI_CV_FACT    1.
 
 /** @brief  Default model behavior for weighting the nucleotide conservation? in consensus structure prediction
+ *
  *  @see    #vrna_md_t.nc_fact, vrna_md_defaults_reset(), vrna_md_set_default()
  */
 #define VRNA_MODEL_DEFAULT_ALI_NC_FACT    1.
@@ -156,6 +174,51 @@ typedef struct vrna_md_s vrna_md_t;
 
 #define VRNA_MODEL_DEFAULT_PF_SMOOTH      1
 
+/**
+ *  @brief  Default model salt concentration (M)
+ */
+#define VRNA_MODEL_DEFAULT_SALT           1.021
+
+
+/**
+ *  @brief  Default model lower bound of multiloop size for salt correction fiting
+ */
+#define VRNA_MODEL_DEFAULT_SALT_MLLOWER    6
+
+
+/**
+ *  @brief  Default model upper bound of multiloop size for salt correction fiting
+ */
+#define VRNA_MODEL_DEFAULT_SALT_MLUPPER    24
+
+
+/**
+ *  @brief  Default model value to turn off user-provided salt correction for duplex initializtion
+ */
+#define VRNA_MODEL_DEFAULT_SALT_DPXINIT       99999
+
+#define VRNA_MODEL_SALT_DPXINIT_FACT_RNA      -45.324
+#define VRNA_MODEL_SALT_DPXINIT_FACT_DNA      -58.389
+
+
+#define VRNA_MODEL_DEFAULT_SALT_DPXINIT_FACT  VRNA_MODEL_SALT_DPXINIT_FACT_RNA
+
+/* Geometric parameters for RNA and DNA */
+
+#define VRNA_MODEL_HELICAL_RISE_RNA   2.8
+#define VRNA_MODEL_HELICAL_RISE_DNA   3.4
+/**
+ *  @brief  Default helical rise
+ */
+#define VRNA_MODEL_DEFAULT_HELICAL_RISE   VRNA_MODEL_HELICAL_RISE_RNA
+
+#define VRNA_MODEL_BACKBONE_LENGTH_RNA   6.0
+#define VRNA_MODEL_BACKBONE_LENGTH_DNA   6.76
+/**
+ *  @brief  Default backbone length
+ */
+#define VRNA_MODEL_DEFAULT_BACKBONE_LENGTH   VRNA_MODEL_BACKBONE_LENGTH_RNA
+
 
 #ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
 
@@ -199,11 +262,11 @@ struct vrna_md_s {
                                              *    and energy evaluation (vrna_mfe() and vrna_eval_structure()), as
                                              *    well as suboptimal folding (vrna_subopt()) via re-evaluation of energies.
                                              *    Co-axial stacking with one intervening mismatch is not considered so far.
-                                             *    @note   Some function do not implement all dangle model but only a subset of
-                                             *            (0,1,2,3). In particular, partition function algorithms can only handle
-                                             *            0 and 2. Read the documentation of the particular recurrences or
-                                             *            energy evaluation function for information about the provided dangle
-                                             *            model.
+                                             *    Note, that some function do not implement all dangle model but only a subset of
+                                             *    (0,1,2,3). In particular, partition function algorithms can only handle
+                                             *    0 and 2. Read the documentation of the particular recurrences or
+                                             *    energy evaluation function for information about the provided dangle
+                                             *    model.
                                              */
   int     special_hp;                       /**<  @brief  Include special hairpin contributions for tri, tetra and hexaloops */
   int     noLP;                             /**<  @brief  Only consider canonical structures, i.e. no 'lonely' base pairs */
@@ -221,7 +284,8 @@ struct vrna_md_s {
   int     max_bp_span;                      /**<  @brief  maximum allowed base pair span */
 
   int     min_loop_size;                    /**<  @brief  Minimum size of hairpin loops
-                                             *    @note The default value for this field is #TURN, however, it may
+                                             *
+                                             *    The default value for this field is #TURN, however, it may
                                              *    be 0 in cofolding context.
                                              */
   int     window_size;                      /**<  @brief  Size of the sliding window for locally optimal structure prediction */
@@ -234,6 +298,16 @@ struct vrna_md_s {
   short   alias[MAXALPHA + 1];              /**<  @brief  alias of an integer nucleotide representation */
   int     pair[MAXALPHA + 1][MAXALPHA + 1]; /**<  @brief  Integer representation of a base pair */
   float   pair_dist[7][7];                  /**<  @brief  Base pair dissimilarity, a.k.a. distance matrix */
+  double  salt;                             /**<  @brief  Salt (monovalent) concentration (M) in buffer */
+  int     saltMLLower;                      /**<  @brief  Lower bound of multiloop size to use in loop salt correction linear fitting */
+  int     saltMLUpper;                      /**<  @brief  Upper bound of multiloop size to use in loop salt correction linear fitting */
+  int     saltDPXInit;                      /**<  @brief  User-provided salt correction for duplex initialization (in dcal/mol).
+                                             *    If set to 99999 the default salt correction is used.
+                                             *    If set to 0 there is no salt correction for duplex initialization.
+                                             */
+  float   saltDPXInitFact;                  /**<  @brief  */
+  float   helical_rise;                     /**<  @brief  */
+  float   backbone_length;                  /**<  @brief  */
 };
 
 
@@ -304,9 +378,11 @@ vrna_md_set_nonstandards(vrna_md_t  *md,
  *  @note The global default parameters affect all function calls of RNAlib where
  *        model details are not explicitly provided. Hence, any change of them
  *        is not considered threadsafe
+ *
  *  @warning  This function first resets the global default settings to factory
  *            defaults, and only then applies user provided settings (if any).
  *            User settings that do not meet specifications are skipped.
+ *
  *  @see  vrna_md_set_default(), #vrna_md_t
  *
  *  @param md_p A set of model details to use as global default (if NULL is passed, factory defaults are restored)
@@ -317,7 +393,9 @@ vrna_md_defaults_reset(vrna_md_t *md_p);
 
 /**
  *  @brief  Set default temperature for energy evaluation of loops
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_TEMPERATURE
+ *
  *  @param T  Temperature in centigrade
  */
 void
@@ -326,7 +404,9 @@ vrna_md_defaults_temperature(double T);
 
 /**
  *  @brief  Get default temperature for energy evaluation of loops
+ *
  *  @see vrna_md_defaults_temperature(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_TEMPERATURE
+ *
  *  @return  The global default settings for temperature in centigrade
  */
 double
@@ -337,7 +417,9 @@ vrna_md_defaults_temperature_get(void);
  *  @brief  Set default scaling factor of thermodynamic temperature in Boltzmann factors
  *
  *  Bolzmann factors are then computed as @f$ exp(-E / (b \cdot kT))@f$.
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_BETA_SCALE
+ *
  *  @param b  The scaling factor, default is 1.0
  */
 void
@@ -348,6 +430,7 @@ vrna_md_defaults_betaScale(double b);
  *  @brief  Get default scaling factor of thermodynamic temperature in Boltzmann factors
  *
  *  @see vrna_md_defaults_betaScale(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_BETA_SCALE
+ *
  *  @return  The global default thermodynamic temperature scaling factor
  */
 double
@@ -364,7 +447,9 @@ vrna_md_defaults_pf_smooth_get(void);
 
 /**
  *  @brief  Set default dangle model for structure prediction
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_DANGLES
+ *
  *  @param d  The dangle model
  */
 void
@@ -373,7 +458,9 @@ vrna_md_defaults_dangles(int d);
 
 /**
  *  @brief  Get default dangle model for structure prediction
+ *
  *  @see vrna_md_defaults_dangles(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_DANGLES
+ *
  *  @return The global default settings for the dangle model
  */
 int
@@ -382,7 +469,9 @@ vrna_md_defaults_dangles_get(void);
 
 /**
  *  @brief  Set default behavior for lookup of tabulated free energies for special hairpin loops, such as Tri-, Tetra-, or Hexa-loops.
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_SPECIAL_HP
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -391,7 +480,9 @@ vrna_md_defaults_special_hp(int flag);
 
 /**
  *  @brief  Get default behavior for lookup of tabulated free energies for special hairpin loops, such as Tri-, Tetra-, or Hexa-loops.
+ *
  *  @see vrna_md_defaults_special_hp(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_SPECIAL_HP
+ *
  *  @return  The global default settings for the treatment of special hairpin loops
  */
 int
@@ -400,7 +491,9 @@ vrna_md_defaults_special_hp_get(void);
 
 /**
  *  @brief  Set default behavior for prediction of canonical secondary structures
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_NO_LP
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -409,7 +502,9 @@ vrna_md_defaults_noLP(int flag);
 
 /**
  *  @brief  Get default behavior for prediction of canonical secondary structures
+ *
  *  @see vrna_md_defaults_noLP(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_NO_LP
+ *
  *  @return  The global default settings for predicting canonical secondary structures
  */
 int
@@ -418,7 +513,9 @@ vrna_md_defaults_noLP_get(void);
 
 /**
  *  @brief  Set default behavior for treatment of G-U wobble pairs
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_NO_GU
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -427,7 +524,9 @@ vrna_md_defaults_noGU(int flag);
 
 /**
  *  @brief  Get default behavior for treatment of G-U wobble pairs
+ *
  *  @see vrna_md_defaults_noGU(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_NO_GU
+ *
  *  @return The global default settings for treatment of G-U wobble pairs
  */
 int
@@ -436,7 +535,9 @@ vrna_md_defaults_noGU_get(void);
 
 /**
  *  @brief  Set default behavior for G-U pairs as closing pair for loops
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_NO_GU_CLOSURE
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -445,7 +546,9 @@ vrna_md_defaults_noGUclosure(int flag);
 
 /**
  *  @brief  Get default behavior for G-U pairs as closing pair for loops
+ *
  *  @see vrna_md_defaults_noGUclosure(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_NO_GU_CLOSURE
+ *
  *  @return The global default settings for treatment of G-U pairs closing a loop
  */
 int
@@ -454,7 +557,9 @@ vrna_md_defaults_noGUclosure_get(void);
 
 /**
  *  @brief  Set default behavior recomputing free energies of multi-branch loops using a logarithmic model
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_LOG_ML
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -463,7 +568,9 @@ vrna_md_defaults_logML(int flag);
 
 /**
  *  @brief  Get default behavior recomputing free energies of multi-branch loops using a logarithmic model
+ *
  *  @see vrna_md_defaults_logML(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_LOG_ML
+ *
  *  @return The global default settings for logarithmic model in multi-branch loop free energy evaluation
  */
 int
@@ -472,7 +579,9 @@ vrna_md_defaults_logML_get(void);
 
 /**
  *  @brief  Set default behavior whether input sequences are circularized
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_CIRC
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -481,7 +590,9 @@ vrna_md_defaults_circ(int flag);
 
 /**
  *  @brief  Get default behavior whether input sequences are circularized
+ *
  *  @see vrna_md_defaults_circ(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_CIRC
+ *
  *  @return The global default settings for treating input sequences as circular
  */
 int
@@ -490,7 +601,9 @@ vrna_md_defaults_circ_get(void);
 
 /**
  *  @brief  Set default behavior for treatment of G-Quadruplexes
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_GQUAD
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -499,7 +612,9 @@ vrna_md_defaults_gquad(int flag);
 
 /**
  *  @brief  Get default behavior for treatment of G-Quadruplexes
+ *
  *  @see vrna_md_defaults_gquad(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_GQUAD
+ *
  *  @return The global default settings for treatment of G-Quadruplexes
  */
 int
@@ -508,8 +623,11 @@ vrna_md_defaults_gquad_get(void);
 
 /**
  *  @brief  Set default behavior for creating additional matrix for unique multi-branch loop prediction
+ *
  *  @note   Activating this option usually results in higher memory consumption!
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_UNIQ_ML
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -518,7 +636,9 @@ vrna_md_defaults_uniq_ML(int flag);
 
 /**
  *  @brief  Get default behavior for creating additional matrix for unique multi-branch loop prediction
+ *
  *  @see vrna_md_defaults_uniq_ML(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_UNIQ_ML
+ *
  *  @return The global default settings for creating additional matrices for unique multi-branch loop prediction
  */
 int
@@ -527,7 +647,9 @@ vrna_md_defaults_uniq_ML_get(void);
 
 /**
  *  @brief  Set default energy set
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ENERGY_SET
+ *
  *  @param  e   Energy set (0, 1, 2, 3)
  */
 void
@@ -536,7 +658,9 @@ vrna_md_defaults_energy_set(int e);
 
 /**
  *  @brief  Get default energy set
+ *
  *  @see vrna_md_defaults_energy_set(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ENERGY_SET
+ *
  *  @return The global default settings for the energy set
  */
 int
@@ -545,7 +669,9 @@ vrna_md_defaults_energy_set_get(void);
 
 /**
  *  @brief  Set default behavior for whether to backtrack secondary structures
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_BACKTRACK
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -554,7 +680,9 @@ vrna_md_defaults_backtrack(int flag);
 
 /**
  *  @brief  Get default behavior for whether to backtrack secondary structures
+ *
  *  @see vrna_md_defaults_backtrack(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_BACKTRACK
+ *
  *  @return The global default settings for backtracking structures
  */
 int
@@ -563,7 +691,9 @@ vrna_md_defaults_backtrack_get(void);
 
 /**
  *  @brief  Set default backtrack type, i.e. which DP matrix is used
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_BACKTRACK_TYPE
+ *
  *  @param  t   The type ('F', 'C', or 'M')
  */
 void
@@ -572,7 +702,9 @@ vrna_md_defaults_backtrack_type(char t);
 
 /**
  *  @brief  Get default backtrack type, i.e. which DP matrix is used
+ *
  *  @see vrna_md_defaults_backtrack_type(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_BACKTRACK_TYPE
+ *
  *  @return The global default settings that specify which DP matrix is used for backtracking
  */
 char
@@ -581,7 +713,9 @@ vrna_md_defaults_backtrack_type_get(void);
 
 /**
  *  @brief  Set the default behavior for whether to compute base pair probabilities after partition function computation
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_COMPUTE_BPP
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -590,7 +724,9 @@ vrna_md_defaults_compute_bpp(int flag);
 
 /**
  *  @brief  Get the default behavior for whether to compute base pair probabilities after partition function computation
+ *
  *  @see vrna_md_defaults_compute_bpp(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_COMPUTE_BPP
+ *
  *  @return The global default settings that specify whether base pair probabilities are computed together with partition function
  */
 int
@@ -599,7 +735,9 @@ vrna_md_defaults_compute_bpp_get(void);
 
 /**
  *  @brief  Set default maximal base pair span
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_MAX_BP_SPAN
+ *
  *  @param  span  Maximal base pair span
  */
 void
@@ -608,7 +746,9 @@ vrna_md_defaults_max_bp_span(int span);
 
 /**
  *  @brief  Get default maximal base pair span
+ *
  *  @see vrna_md_defaults_max_bp_span(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_MAX_BP_SPAN
+ *
  *  @return The global default settings for maximum base pair span
  */
 int
@@ -617,7 +757,9 @@ vrna_md_defaults_max_bp_span_get(void);
 
 /**
  *  @brief  Set default minimal loop size
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #TURN
+ *
  *  @param  size  Minimal size, i.e. number of unpaired nucleotides for a hairpin loop
  */
 void
@@ -626,7 +768,9 @@ vrna_md_defaults_min_loop_size(int size);
 
 /**
  *  @brief  Get default minimal loop size
+ *
  *  @see vrna_md_defaults_min_loop_size(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #TURN
+ *
  *  @return The global default settings for minimal size of hairpin loops
  */
 int
@@ -635,7 +779,9 @@ vrna_md_defaults_min_loop_size_get(void);
 
 /**
  *  @brief  Set default window size for sliding window structure prediction approaches
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_WINDOW_SIZE
+ *
  *  @param  size  The size of the sliding window
  */
 void
@@ -644,7 +790,9 @@ vrna_md_defaults_window_size(int size);
 
 /**
  *  @brief  Get default window size for sliding window structure prediction approaches
+ *
  *  @see vrna_md_defaults_window_size(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_WINDOW_SIZE
+ *
  *  @return The global default settings for the size of the sliding window
  */
 int
@@ -653,9 +801,12 @@ vrna_md_defaults_window_size_get(void);
 
 /**
  *  @brief  Set default behavior for whether to use old energy model for comparative structure prediction
+ *
  *  @note   This option is outdated. Activating the old energy model usually results in worse consensus
  *          structure predictions.
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_OLD_EN
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -664,7 +815,9 @@ vrna_md_defaults_oldAliEn(int flag);
 
 /**
  *  @brief  Get default behavior for whether to use old energy model for comparative structure prediction
+ *
  *  @see vrna_md_defaults_oldAliEn(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_OLD_EN
+ *
  *  @return The global default settings for using old energy model for comparative structure prediction
  */
 int
@@ -673,7 +826,9 @@ vrna_md_defaults_oldAliEn_get(void);
 
 /**
  *  @brief  Set default behavior for whether to use Ribosum Scoring in comparative structure prediction
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_RIBO
+ *
  *  @param  flag  On/Off switch (0 = OFF, else = ON)
  */
 void
@@ -682,7 +837,9 @@ vrna_md_defaults_ribo(int flag);
 
 /**
  *  @brief  Get default behavior for whether to use Ribosum Scoring in comparative structure prediction
+ *
  *  @see vrna_md_defaults_ribo(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_RIBO
+ *
  *  @return The global default settings for using Ribosum scoring in comparative structure prediction
  */
 int
@@ -691,7 +848,9 @@ vrna_md_defaults_ribo_get(void);
 
 /**
  *  @brief  Set the default co-variance scaling factor used in comparative structure prediction
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_CV_FACT
+ *
  *  @param  factor  The co-variance factor
  */
 void
@@ -700,7 +859,9 @@ vrna_md_defaults_cv_fact(double factor);
 
 /**
  *  @brief  Get the default co-variance scaling factor used in comparative structure prediction
+ *
  *  @see vrna_md_defaults_cv_fact(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_CV_FACT
+ *
  *  @return The global default settings for the co-variance factor
  */
 double
@@ -709,7 +870,9 @@ vrna_md_defaults_cv_fact_get(void);
 
 /**
  *  @brief
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_NC_FACT
+ *
  *  @param factor
  */
 void
@@ -718,7 +881,9 @@ vrna_md_defaults_nc_fact(double factor);
 
 /**
  *  @brief
+ *
  *  @see vrna_md_defaults_nc_fact(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t, #VRNA_MODEL_DEFAULT_ALI_NC_FACT
+ *
  *  @return
  */
 double
@@ -727,7 +892,9 @@ vrna_md_defaults_nc_fact_get(void);
 
 /**
  *  @brief  Set the default scaling factor used to avoid under-/overflows in partition function computation
+ *
  *  @see vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t
+ *
  *  @param  factor  The scaling factor  (default: 1.07)
  */
 void
@@ -736,13 +903,110 @@ vrna_md_defaults_sfact(double factor);
 
 /**
  *  @brief  Get the default scaling factor used to avoid under-/overflows in partition function computation
+ *
  *  @see vrna_md_defaults_sfact(), vrna_md_defaults_reset(), vrna_md_set_default(), #vrna_md_t
+ *
  *  @return The global default settings of the scaling factor
  */
 double
 vrna_md_defaults_sfact_get(void);
 
 
+/**
+ *  @brief Set the default salt concentration
+ *
+ *  @param salt The sodium concentration in M (default: 1.021)
+ */
+void
+vrna_md_defaults_salt(double salt);
+
+
+/**
+ *  @brief Get the default salt concentration
+ *  @return The default salt concentration
+ */
+double
+vrna_md_defaults_salt_get(void);
+
+
+/**
+ *  @brief Set the default multiloop size lower bound for loop salt correciton linear fitting
+ *
+ *  @param lower Size lower bound (number of backbone in loop)
+ */
+void
+vrna_md_defaults_saltMLLower(int lower);
+
+
+/**
+ *  @brief Get the default multiloop size lower bound for loop salt correciton linear fitting
+ *  @return The default lower bound
+ */
+int
+vrna_md_defaults_saltMLLower_get(void);
+
+
+/**
+ *  @brief Set the default multiloop size upper bound for loop salt correciton linear fitting
+ *
+ *  @param upper Size Upper bound (number of backbone in loop)
+ */
+void
+vrna_md_defaults_saltMLUpper(int upper);
+
+
+/**
+ *  @brief Get the default multiloop size upper bound for loop salt correciton linear fitting
+ *  @return The default upper bound
+ */
+int
+vrna_md_defaults_saltMLUpper_get(void);
+
+
+/**
+ *  @brief Set user-provided salt correciton for duplex initialization
+ *  If value is 99999 the default value from fitting is used
+ *
+ *  @param value The value of salt correction for duplex initialization (in dcal/mol)
+ */
+void
+vrna_md_defaults_saltDPXInit(int value);
+
+
+/**
+ *  @brief Get user-provided salt correciton for duplex initialization
+ *  If value is 99999 the default value from fitting is used
+ *
+ *  @return The user-provided salt correction for duplex initialization
+ */
+int
+vrna_md_defaults_saltDPXInit_get(void);
+
+
+void
+vrna_md_defaults_saltDPXInitFact(float value);
+
+
+float
+vrna_md_defaults_saltDPXInitFact_get(void);
+
+
+void
+vrna_md_defaults_helical_rise(float value);
+
+
+float
+vrna_md_defaults_helical_rise_get(void);
+
+
+void
+vrna_md_defaults_backbone_length(float value);
+
+
+float
+vrna_md_defaults_backbone_length_get(void);
+
+
 #ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
 
 #define model_detailsT        vrna_md_t               /* restore compatibility of struct rename */
@@ -754,8 +1018,10 @@ vrna_md_defaults_sfact_get(void);
  *
  *  Default is 37C. You have to call the update_..._params() functions after
  *  changing this parameter.
+ *
  *  @deprecated   Use vrna_md_defaults_temperature(), and vrna_md_defaults_temperature_get()
  *                to change, and read the global default temperature settings
+ *
  *  @see vrna_md_defaults_temperature(), vrna_md_defaults_temperature_get(), vrna_md_defaults_reset()
  */
 extern double temperature;
@@ -896,6 +1162,15 @@ extern double nc_fact;
 /** @brief if nonzero use logarithmic ML energy in energy_of_struct  */
 extern int    logML;
 
+/** @brief salt concentration */
+extern double salt;
+
+/** @brief Salt correction for duplex initialization */
+extern int saltDPXInit;
+
+extern float  helical_rise;
+extern float  backbone_length;
+
 /* END deprecated global variables: */
 
 /**
