@@ -22,14 +22,6 @@
 /**
  *  @addtogroup energy_parameters
  *  @{
- *
- *  @brief All relevant functions to retrieve and copy pre-calculated energy parameter sets as well as
- *  reading/writing the energy parameter set from/to file(s).
- *
- *  This module covers all relevant functions for pre-calculation of the energy parameters
- *  necessary for the folding routines provided by RNAlib. Furthermore, the energy parameter set
- *  in the RNAlib can be easily exchanged by a user-defined one. It is also possible to write the
- *  current energy parameter set into a text file.
  */
 
 /** @brief Typename for the free energy parameter data structure #vrna_params */
@@ -95,6 +87,13 @@ struct vrna_param_s {
 
   vrna_md_t model_details;    /**<  @brief  Model details to be used in the recursions */
   char      param_file[256];  /**<  @brief  The filename the parameters were derived from, or empty string if they represent the default */
+  int       SaltStack;
+  int       SaltLoop[MAXLOOP + 2];
+  double    SaltLoopDbl[MAXLOOP + 2];
+  int       SaltMLbase;
+  int       SaltMLintern;
+  int       SaltMLclosing;
+  int       SaltDPXInit;
 };
 
 /**
@@ -153,6 +152,14 @@ struct vrna_exp_param_s {
 
   vrna_md_t model_details;    /**<  @brief  Model details to be used in the recursions */
   char      param_file[256];  /**<  @brief  The filename the parameters were derived from, or empty string if they represent the default */
+
+  double    expSaltStack;
+  double    expSaltLoop[MAXLOOP + 2];
+  double    SaltLoopDbl[MAXLOOP + 2];
+  int       SaltMLbase;
+  int       SaltMLintern;
+  int       SaltMLclosing;
+  int       SaltDPXInit;
 };
 
 
@@ -249,16 +256,16 @@ vrna_exp_params_copy(vrna_exp_param_t *par);
  *  @brief  Update/Reset energy parameters data structure within a #vrna_fold_compound_t
  *
  *  Passing NULL as second argument leads to a reset of the energy parameters within
- *  vc to their default values. Otherwise, the energy parameters provided will be copied
- *  over into vc.
+ *  fc to their default values. Otherwise, the energy parameters provided will be copied
+ *  over into fc.
  *
  *  @see vrna_params_reset(), #vrna_param_t, #vrna_md_t, vrna_params()
  *
- *  @param  vc    The #vrna_fold_compound_t that is about to receive updated energy parameters
- *  @param  par   The energy parameters used to substitute those within vc (Maybe NULL)
+ *  @param  fc    The #vrna_fold_compound_t that is about to receive updated energy parameters
+ *  @param  par   The energy parameters used to substitute those within fc (Maybe NULL)
  */
 void
-vrna_params_subst(vrna_fold_compound_t  *vc,
+vrna_params_subst(vrna_fold_compound_t  *fc,
                   vrna_param_t          *par);
 
 
@@ -267,20 +274,20 @@ vrna_params_subst(vrna_fold_compound_t  *vc,
  *
  *  This function can be used to properly assign new energy parameters for partition
  *  function computations to a #vrna_fold_compound_t. For this purpose, the data of the
- *  provided pointer `params`  will be copied into `vc` and a recomputation of the partition
+ *  provided pointer `params`  will be copied into `fc` and a recomputation of the partition
  *  function scaling factor is issued, if the `pf_scale` attribute of `params` is less than `1.0`.
  *
  *  Passing NULL as second argument leads to a reset of the energy parameters within
- *  vc to their default values
+ *  fc to their default values
  *
- *  @see vrna_exp_params_reset(), vrna_exp_params_rescale(), #vrna_exp_param_t, #vrna_md_t,
- *  vrna_exp_params()
+ *  @see  vrna_exp_params_reset(), vrna_exp_params_rescale(), #vrna_exp_param_t, #vrna_md_t,
+ *        vrna_exp_params()
  *
- *  @param  vc      The fold compound data structure
+ *  @param  fc      The fold compound data structure
  *  @param  params  A pointer to the new energy parameters
  */
 void
-vrna_exp_params_subst(vrna_fold_compound_t  *vc,
+vrna_exp_params_subst(vrna_fold_compound_t  *fc,
                       vrna_exp_param_t      *params);
 
 
@@ -303,7 +310,7 @@ vrna_exp_params_subst(vrna_fold_compound_t  *vc,
  *  the scaling factor is recomputed according to a mean free energy of `184.3*length` cal
  *  for random sequences.
  *  @note This recomputation only takes place if the `pf_scale` attribute of the
- *  `exp_params` data structure contained in `vc` has a value below `1.0`.
+ *        `exp_params` data structure contained in `fc` has a value below `1.0`.
  *
  *  On the other hand, if the MFE for a sequence is known, it can be used to recompute
  *  a more robust scaling factor, since it represents the lowest free energy of the entire
@@ -311,18 +318,18 @@ vrna_exp_params_subst(vrna_fold_compound_t  *vc,
  *  mode of _automatic adjustment according to MFE_, a pointer to the MFE value needs to
  *  be passed as second argument. This value is then taken to compute the scaling factor
  *  as @f$ s = exp((sfact * MFE) / kT / length )@f$, where sfact is an additional
- *  scaling weight located in the vrna_md_t data structure of `exp_params` in `vc`.
+ *  scaling weight located in the vrna_md_t data structure of `exp_params` in `fc`.
  *
  *  The computed scaling factor @f$s@f$ will be stored as `pf_scale` attribute of the
- *  `exp_params` data structure in `vc`.
+ *  `exp_params` data structure in `fc`.
  *
  *  @see vrna_exp_params_subst(), vrna_md_t, vrna_exp_param_t, #vrna_fold_compound_t
  *
- *  @param  vc  The fold compound data structure
+ *  @param  fc  The fold compound data structure
  *  @param  mfe A pointer to the MFE (in kcal/mol) or NULL
  */
 void
-vrna_exp_params_rescale(vrna_fold_compound_t  *vc,
+vrna_exp_params_rescale(vrna_fold_compound_t  *fc,
                         double                *mfe);
 
 
@@ -336,12 +343,13 @@ vrna_exp_params_rescale(vrna_fold_compound_t  *vc,
  *  to be used for rescaling, or NULL if global default setting should be used.
  *
  *  @see vrna_exp_params_reset(), vrna_params_subs()
- *  @param  vc    The fold compound data structure
- *  @param  md_p  A pointer to the new model details (or NULL for reset to defaults)
+ *
+ *  @param  fc    The fold compound data structure
+ *  @param  md    A pointer to the new model details (or NULL for reset to defaults)
  */
 void
-vrna_params_reset(vrna_fold_compound_t  *vc,
-                  vrna_md_t             *md_p);
+vrna_params_reset(vrna_fold_compound_t  *fc,
+                  vrna_md_t             *md);
 
 
 /**
@@ -355,16 +363,17 @@ vrna_params_reset(vrna_fold_compound_t  *vc,
  *  to be used for rescaling, or NULL if global default setting should be used.
  *
  *  @see vrna_params_reset(), vrna_exp_params_subst(), vrna_exp_params_rescale()
- *  @param  vc    The fold compound data structure
- *  @param  md_p  A pointer to the new model details (or NULL for reset to defaults)
+ *
+ *  @param  fc    The fold compound data structure
+ *  @param  md    A pointer to the new model details (or NULL for reset to defaults)
  */
 void
-vrna_exp_params_reset(vrna_fold_compound_t  *vc,
-                      vrna_md_t             *md_p);
+vrna_exp_params_reset(vrna_fold_compound_t  *fc,
+                      vrna_md_t             *md);
 
 
 void
-vrna_params_prepare(vrna_fold_compound_t  *vc,
+vrna_params_prepare(vrna_fold_compound_t  *fc,
                     unsigned int          options);
 
 
