@@ -16,6 +16,7 @@
 #include <math.h>
 #include <stdarg.h>
 #include "ViennaRNA/utils/basic.h"
+#include "ViennaRNA/model.h"
 #include "ViennaRNA/io/utils.h"
 #include "ViennaRNA/params/constants.h"
 #include "ViennaRNA/params/default.h"
@@ -351,6 +352,9 @@ vrna_params_load_defaults(void)
 PUBLIC int
 vrna_params_load_RNA_Turner2004(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_RNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_RNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_RNA);
   return vrna_params_load_from_string((const char *)parameter_set_rna_turner2004,
                                       "RNA - Turner 2004",
                                       0);
@@ -360,6 +364,9 @@ vrna_params_load_RNA_Turner2004(void)
 PUBLIC int
 vrna_params_load_RNA_Turner1999(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_RNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_RNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_RNA);
   return vrna_params_load_from_string((const char *)parameter_set_rna_turner1999,
                                       "RNA - Turner 1999",
                                       0);
@@ -369,6 +376,9 @@ vrna_params_load_RNA_Turner1999(void)
 PUBLIC int
 vrna_params_load_RNA_Andronescu2007(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_RNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_RNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_RNA);
   return vrna_params_load_from_string((const char *)parameter_set_rna_andronescu2007,
                                       "RNA - Andronescu 2007",
                                       0);
@@ -378,6 +388,9 @@ vrna_params_load_RNA_Andronescu2007(void)
 PUBLIC int
 vrna_params_load_RNA_Langdon2018(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_RNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_RNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_RNA);
   return vrna_params_load_from_string((const char *)parameter_set_rna_langdon2018,
                                       "RNA - Langdon 2018",
                                       0);
@@ -387,6 +400,9 @@ vrna_params_load_RNA_Langdon2018(void)
 PUBLIC int
 vrna_params_load_RNA_misc_special_hairpins(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_RNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_RNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_RNA);
   return vrna_params_load_from_string((const char *)parameter_set_rna_misc_special_hairpins,
                                       "RNA - Misc. Special Hairpins",
                                       0);
@@ -396,6 +412,9 @@ vrna_params_load_RNA_misc_special_hairpins(void)
 PUBLIC int
 vrna_params_load_DNA_Mathews2004(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_DNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_DNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_DNA);
   return vrna_params_load_from_string((const char *)parameter_set_dna_mathews2004,
                                       "DNA - Mathews 2004",
                                       0);
@@ -405,6 +424,9 @@ vrna_params_load_DNA_Mathews2004(void)
 PUBLIC int
 vrna_params_load_DNA_Mathews1999(void)
 {
+  vrna_md_defaults_helical_rise(VRNA_MODEL_HELICAL_RISE_DNA);
+  vrna_md_defaults_backbone_length(VRNA_MODEL_BACKBONE_LENGTH_DNA);
+  vrna_md_defaults_saltDPXInitFact(VRNA_MODEL_SALT_DPXINIT_FACT_DNA);
   return vrna_params_load_from_string((const char *)parameter_set_dna_mathews1999,
                                       "DNA - Mathews 1999",
                                       0);
@@ -1624,7 +1646,9 @@ last_parameter_file(void)
 PUBLIC void
 read_parameter_file(const char fname[])
 {
-  (void)vrna_params_load(fname, VRNA_PARAMETER_FORMAT_DEFAULT);
+  int ret = vrna_params_load(fname, VRNA_PARAMETER_FORMAT_DEFAULT);
+  if (!ret)
+    vrna_message_warning("Failed to load parameters from file \"%s\"", fname);
 }
 
 
