@@ -36,6 +36,20 @@
 #define SIZE 452.
 #define PMIN 0.00001
 
+typedef struct {
+  vrna_data_lin_t **data;
+  char            **titles;
+  size_t          size;
+  size_t          mem;
+} lin_data_container;
+
+typedef struct {
+  lin_data_container north;
+  lin_data_container east;
+  lin_data_container south;
+  lin_data_container west;
+} lin_dat;
+
 /*
 #################################
 # GLOBAL VARIABLES              #
@@ -83,15 +97,22 @@ PRIVATE void  EPS_print_header(FILE *eps, int bbox[4], const char *comment, unsi
 PRIVATE void  EPS_print_ud_data(FILE *eps, plist *pl, plist *mf);
 PRIVATE void  EPS_print_sc_motif_data(FILE *eps, plist *pl, plist *mf);
 PRIVATE void  EPS_print_bpp_data(FILE *eps, plist *pl, plist *mf);
-PRIVATE void  EPS_print_linear_data_top(FILE *eps, const char **data_title, vrna_data_lin_t **data);
-PRIVATE void  EPS_print_linear_data_left(FILE *eps, const char **data_title, vrna_data_lin_t **data);
-PRIVATE void  EPS_print_linear_data_bottom(FILE *eps, const char **data_title, vrna_data_lin_t **data);
-PRIVATE void  EPS_print_linear_data_right(FILE *eps, const char **data_title, vrna_data_lin_t **data);
-PRIVATE void  EPS_print_linear_data(FILE *eps, const char *varname, const char **data_title, vrna_data_lin_t **data);
+PRIVATE void  EPS_print_linear_data(FILE *eps, const char *varname, lin_data_container *data);
 PRIVATE vrna_data_lin_t *plist_to_accessibility(plist *pl, unsigned int length);
 PRIVATE vrna_data_lin_t *plist_to_ud_motif_prob(plist *pl, unsigned int length);
 PRIVATE void  EPS_print_sd_data(FILE *eps, vrna_ep_t *pl, vrna_ep_t *mf);
 
+INLINE PRIVATE int
+init_lin_data(lin_dat *dat);
+
+INLINE PRIVATE void
+free_lin_data(lin_dat *dat);
+
+INLINE PRIVATE int
+push_lin_data(lin_data_container  *c,
+              vrna_data_lin_t     *data,
+              char                *title);
+
 /*
 #################################
 # BEGIN OF FUNCTION DEFINITIONS #
@@ -147,7 +168,8 @@ PS_color_dot_plot(char *seq,
               pi[i].i,
               pi[i].j,
               sqrt(pi[i].p));
-    } else if (pi[i].type == VRNA_PLIST_TYPE_BASEPAIR) {
+    } else if ((pi[i].type == VRNA_PLIST_TYPE_BASEPAIR) ||
+               (pi[i].type == VRNA_PLIST_TYPE_TRIPLE)) {
       fprintf(wastl,"%1.2f %1.2f hsb %d %d %1.6f ubox\n",
              pi[i].hue, pi[i].sat, pi[i].i, pi[i].j, sqrt(pi[i].p));
 
@@ -237,11 +259,13 @@ vrna_plot_dp_PS_list( char *seq,
   fprintf(wastl,"%%data starts here\n");
 
   /* sort the plist to bring all gquad triangles to the front */
-  for(gq_num = pl_size = 0, pl1 = pl; pl1->i > 0; pl1++, pl_size++)
-    if (pl1->type == VRNA_PLIST_TYPE_GQUAD) gq_num++;
-  qsort(pl, pl_size, sizeof(plist), sort_plist_by_type_desc);
-  /* sort all gquad triangles by probability to bring lower probs to the front */
-  qsort(pl, gq_num, sizeof(plist), sort_plist_by_prob_asc);
+  if (pl) {
+    for(gq_num = pl_size = 0, pl1 = pl; pl1->i > 0; pl1++, pl_size++)
+      if (pl1->type == VRNA_PLIST_TYPE_GQUAD) gq_num++;
+    qsort(pl, pl_size, sizeof(plist), sort_plist_by_type_desc);
+    /* sort all gquad triangles by probability to bring lower probs to the front */
+    qsort(pl, gq_num, sizeof(plist), sort_plist_by_prob_asc);
+  }
 
   EPS_print_sd_data(wastl, pl, mf);
   EPS_print_sc_motif_data(wastl, pl, mf);
@@ -273,7 +297,8 @@ vrna_plot_dp_EPS( const char              *filename,
                   linright_size, bbox[4];
   FILE            *fh;
   vrna_data_lin_t **lintop, **linbottom, **linleft, **linright, *ud_lin, *access;
-
+  lin_dat         linear_data;
+  
   fh = fopen(filename, "w");
   if(!fh){
     vrna_message_warning("can't open %s for dot plot", filename);
@@ -282,6 +307,8 @@ vrna_plot_dp_EPS( const char              *filename,
 
   comment = title = NULL;
 
+  init_lin_data(&linear_data);
+
   lintop_num      = 0;
   lintop_size     = 5;
   linbottom_num   = 0;
@@ -309,46 +336,41 @@ vrna_plot_dp_EPS( const char              *filename,
   if(options & VRNA_PLOT_PROBABILITIES_UD_LIN){
     ud_lin = plist_to_ud_motif_prob(upper, strlen(sequence));
     if(ud_lin){
-      dp_add_lindata(lintop, ud_lin, lintoptitle, "Protein binding", lintop_num, lintop_size);
-      dp_add_lindata(linleft, ud_lin, linlefttitle, "Protein binding", linleft_num, linleft_size);
-      dp_add_lindata(linbottom, ud_lin, linbottomtitle, "Protein binding", linbottom_num, linbottom_size);
-      dp_add_lindata(linright, ud_lin, linrighttitle, "Protein binding", linright_num, linright_size);
+      push_lin_data(&(linear_data.north), ud_lin, "Protein binding");
+      push_lin_data(&(linear_data.east), ud_lin, "Protein binding");
+      push_lin_data(&(linear_data.south), ud_lin, "Protein binding");
+      push_lin_data(&(linear_data.west), ud_lin, "Protein binding");
     }
   }
 
   if(options & VRNA_PLOT_PROBABILITIES_ACC){
     access = plist_to_accessibility(upper, strlen(sequence));
-    dp_add_lindata(lintop, access, lintoptitle, "Accessibility", lintop_num, lintop_size);
+    push_lin_data(&(linear_data.north), access, "Accessibility");
   }
 
   if(auxdata){
     if(auxdata->top){
       for(i = 0; auxdata->top[i]; i++){
-        dp_add_lindata(lintop, auxdata->top[i], lintoptitle, auxdata->top_title[i], lintop_num, lintop_size);
+        push_lin_data(&(linear_data.north), auxdata->top[i], auxdata->top_title[i]);
       }
     }
     if(auxdata->bottom){
       for(i = 0; auxdata->bottom[i]; i++){
-        dp_add_lindata(linbottom, auxdata->bottom[i], linbottomtitle, auxdata->bottom_title[i], linbottom_num, linbottom_size);
+        push_lin_data(&(linear_data.south), auxdata->bottom[i], auxdata->bottom_title[i]);
       }
     }
     if(auxdata->left){
       for(i = 0; auxdata->left[i]; i++){
-        dp_add_lindata(linleft, auxdata->left[i], linlefttitle, auxdata->left_title[i], linleft_num, linleft_size);
+        push_lin_data(&(linear_data.west), auxdata->left[i], auxdata->left_title[i]);
       }
     }
     if(auxdata->right){
       for(i = 0; auxdata->right[i]; i++){
-        dp_add_lindata(linright, auxdata->right[i], linrighttitle, auxdata->right_title[i], linright_num, linright_size);
+        push_lin_data(&(linear_data.east), auxdata->right[i], auxdata->right_title[i]);
       }
     }
   }
 
-  dp_finalize_lindata(lintop, lintoptitle, lintop_num);
-  dp_finalize_lindata(linbottom, linbottomtitle, linbottom_num);
-  dp_finalize_lindata(linleft, linlefttitle, linleft_num);
-  dp_finalize_lindata(linright, linrighttitle, linright_num);
-
   if(auxdata){
     comment = auxdata->comment;
     title   = (auxdata->title) ? strdup(auxdata->title) : NULL;
@@ -367,10 +389,11 @@ vrna_plot_dp_EPS( const char              *filename,
   print_PS_sequence(fh, sequence);
 
   fprintf(fh,"%% BEGIN linear data array\n\n");
-  EPS_print_linear_data_top(fh, (const char **)lintoptitle, lintop);
-  EPS_print_linear_data_left(fh, (const char **)linlefttitle, linleft);
-  EPS_print_linear_data_bottom(fh, (const char **)linbottomtitle, linbottom);
-  EPS_print_linear_data_right(fh, (const char **)linrighttitle, linright);
+  EPS_print_linear_data(fh, "topData", &(linear_data.north));
+  EPS_print_linear_data(fh, "leftData", &(linear_data.west));
+  EPS_print_linear_data(fh, "bottomData", &(linear_data.south));
+  EPS_print_linear_data(fh, "rightData", &(linear_data.east));
+
   fprintf(fh,"%% END linear data arrays\n");
 
   fprintf(fh, "\n%%Finally, prepare canvas\n\n"
@@ -398,6 +421,8 @@ vrna_plot_dp_EPS( const char              *filename,
 
   print_PS_footer(fh);
 
+  free_lin_data(&linear_data);
+
   fclose(fh);
   free(lintoptitle);
   free(lintop);
@@ -576,23 +601,26 @@ EPS_print_sd_data(FILE          *eps,
   plist   *pl1;
 
   /* sort the plist to bring all gquad triangles to the front */
-  for(gq_num = pl_size = 0, pl1 = pl; pl1->i > 0; pl1++, pl_size++)
-    if(pl1->type == VRNA_PLIST_TYPE_GQUAD) gq_num++;
+  if (pl) {
+    for(gq_num = pl_size = 0, pl1 = pl; pl1->i > 0; pl1++, pl_size++)
+      if(pl1->type == VRNA_PLIST_TYPE_GQUAD) gq_num++;
 
-  qsort(pl, pl_size, sizeof(plist), sort_plist_by_type_desc);
+    qsort(pl, pl_size, sizeof(plist), sort_plist_by_type_desc);
 
-  /* sort all gquad triangles by probability to bring lower probs to the front */
-  qsort(pl, gq_num, sizeof(plist), sort_plist_by_prob_asc);
+    /* sort all gquad triangles by probability to bring lower probs to the front */
+    qsort(pl, gq_num, sizeof(plist), sort_plist_by_prob_asc);
+  }
 
   /* print triangles for g-quadruplexes in upper half */
   fprintf(eps,"\n%%start of quadruplex data\n");
 
-  for (pl1=pl; pl1->i > 0; pl1++) {
-    if(pl1->type == VRNA_PLIST_TYPE_GQUAD){
-      tmp = sqrt(pl1->p);
-      fprintf(eps, "%d %d %1.9f utri\n", pl1->i, pl1->j, tmp);
+  if (pl)
+    for (pl1=pl; pl1->i > 0; pl1++) {
+      if(pl1->type == VRNA_PLIST_TYPE_GQUAD){
+        tmp = sqrt(pl1->p);
+        fprintf(eps, "%d %d %1.9f utri\n", pl1->i, pl1->j, tmp);
+      }
     }
-  }
 }
 
 
@@ -606,48 +634,55 @@ EPS_print_sc_motif_data(FILE          *eps,
 
   /* print triangles for hairpin loop motifs in upper half */
   fprintf(eps,"\n%%start of Hmotif data\n");
-  for (pl1=pl; pl1->i > 0; pl1++) {
-    if(pl1->type == VRNA_PLIST_TYPE_H_MOTIF){
-      tmp = sqrt(pl1->p);
-      fprintf(eps, "%d %d %1.9f uHmotif\n", pl1->i, pl1->j, tmp);
+  if (pl)
+    for (pl1=pl; pl1->i > 0; pl1++) {
+      if(pl1->type == VRNA_PLIST_TYPE_H_MOTIF){
+        tmp = sqrt(pl1->p);
+        fprintf(eps, "%d %d %1.9f uHmotif\n", pl1->i, pl1->j, tmp);
+      }
     }
-  }
-  for (pl1=mf; pl1->i > 0; pl1++) {
-    if(pl1->type == VRNA_PLIST_TYPE_H_MOTIF){
-      tmp = sqrt(pl1->p);
-      fprintf(eps, "%d %d %1.9f lHmotif\n", pl1->i, pl1->j, tmp);
+
+  if (mf)
+    for (pl1=mf; pl1->i > 0; pl1++) {
+      if(pl1->type == VRNA_PLIST_TYPE_H_MOTIF){
+        tmp = sqrt(pl1->p);
+        fprintf(eps, "%d %d %1.9f lHmotif\n", pl1->i, pl1->j, tmp);
+      }
     }
-  }
 
   /* print triangles for interior loop motifs in upper half */
   fprintf(eps,"\n%%start of Imotif data\n");
   int   a,b;
   float ppp;
   a = b = 0;
-  for (pl1=pl; pl1->i > 0; pl1++) {
-    if(pl1->type == VRNA_PLIST_TYPE_I_MOTIF){
-      if(a == 0){
-        a = pl1->i;
-        b = pl1->j;
-        ppp = tmp = sqrt(pl1->p);
-      } else {
-        fprintf(eps, "%d %d %d %d %1.9f uImotif\n", a, b, pl1->i, pl1->j, ppp);
-        a = b = 0;
+
+  if (pl)
+    for (pl1=pl; pl1->i > 0; pl1++) {
+      if(pl1->type == VRNA_PLIST_TYPE_I_MOTIF){
+        if(a == 0){
+          a = pl1->i;
+          b = pl1->j;
+          ppp = tmp = sqrt(pl1->p);
+        } else {
+          fprintf(eps, "%d %d %d %d %1.9f uImotif\n", a, b, pl1->i, pl1->j, ppp);
+          a = b = 0;
+        }
       }
     }
-  }
-  for (a = b= 0, pl1=mf; pl1->i > 0; pl1++) {
-    if(pl1->type == VRNA_PLIST_TYPE_I_MOTIF){
-      if(a == 0){
-        a = pl1->i;
-        b = pl1->j;
-        ppp = sqrt(pl1->p);
-      } else {
-        fprintf(eps, "%d %d %d %d %1.9f lImotif\n", a, b, pl1->i, pl1->j, ppp);
-        a = b = 0;
+
+  if (mf)
+    for (a = b= 0, pl1=mf; pl1->i > 0; pl1++) {
+      if(pl1->type == VRNA_PLIST_TYPE_I_MOTIF){
+        if(a == 0){
+          a = pl1->i;
+          b = pl1->j;
+          ppp = sqrt(pl1->p);
+        } else {
+          fprintf(eps, "%d %d %d %d %1.9f lImotif\n", a, b, pl1->i, pl1->j, ppp);
+          a = b = 0;
+        }
       }
     }
-  }
 }
 
 
@@ -662,19 +697,23 @@ EPS_print_bpp_data( FILE          *eps,
   fprintf(eps,"%%start of base pair probability data\n");
 
   /* print boxes in upper right half*/
-  for (pl1 = pl; pl1->i>0; pl1++) {
-    tmp = sqrt(pl1->p);
-    if(pl1->type == VRNA_PLIST_TYPE_BASEPAIR)
-        fprintf(eps,"%d %d %1.9f ubox\n", pl1->i, pl1->j, tmp);
-  }
+  if (pl)
+    for (pl1 = pl; pl1->i>0; pl1++) {
+      tmp = sqrt(pl1->p);
+      if ((pl1->type == VRNA_PLIST_TYPE_BASEPAIR) ||
+          (pl1->type == VRNA_PLIST_TYPE_TRIPLE))
+          fprintf(eps,"%d %d %1.9f ubox\n", pl1->i, pl1->j, tmp);
+    }
 
 
   /* print boxes in lower left half (mfe) */
-  for (pl1=mf; pl1->i>0; pl1++) {
-    tmp = sqrt(pl1->p);
-    if(pl1->type == VRNA_PLIST_TYPE_BASEPAIR)
-      fprintf(eps,"%d %d %1.7f lbox\n", pl1->i, pl1->j, tmp);
-  }
+  if (mf)
+    for (pl1=mf; pl1->i>0; pl1++) {
+      tmp = sqrt(pl1->p);
+      if ((pl1->type == VRNA_PLIST_TYPE_BASEPAIR) ||
+          (pl1->type == VRNA_PLIST_TYPE_TRIPLE))
+        fprintf(eps,"%d %d %1.7f lbox\n", pl1->i, pl1->j, tmp);
+    }
 }
 
 
@@ -688,73 +727,38 @@ EPS_print_ud_data(FILE          *eps,
 
   /* print triangles for unstructured domain motifs in upper half */
   fprintf(eps,"\n%%start of unstructured domain motif data\n");
-  for(pl1 = pl; pl1->i > 0; pl1++){
-    if(pl1->type == VRNA_PLIST_TYPE_UD_MOTIF){
-      tmp = sqrt(pl1->p);
-      fprintf(eps, "%d %d %1.9f uUDmotif\n", pl1->i, pl1->j, tmp);
+  if (pl)
+    for(pl1 = pl; pl1->i > 0; pl1++){
+      if(pl1->type == VRNA_PLIST_TYPE_UD_MOTIF){
+        tmp = sqrt(pl1->p);
+        fprintf(eps, "%d %d %1.9f uUDmotif\n", pl1->i, pl1->j, tmp);
+      }
     }
-  }
-  for(pl1 = mf; pl1->i > 0; pl1++){
-    if(pl1->type == VRNA_PLIST_TYPE_UD_MOTIF){
-      tmp = sqrt(pl1->p);
-      fprintf(eps, "%d %d %1.9f lUDmotif\n", pl1->i, pl1->j, tmp);
+
+  if (mf)
+    for(pl1 = mf; pl1->i > 0; pl1++){
+      if(pl1->type == VRNA_PLIST_TYPE_UD_MOTIF){
+        tmp = sqrt(pl1->p);
+        fprintf(eps, "%d %d %1.9f lUDmotif\n", pl1->i, pl1->j, tmp);
+      }
     }
-  }
 }
 
 
 PRIVATE void
-EPS_print_linear_data_top(FILE            *eps,
-                          const char      **data_title,
-                          vrna_data_lin_t **data){
+EPS_print_linear_data(FILE                *eps,
+                      const char          *varname,
+                      lin_data_container  *c){
 
-  EPS_print_linear_data(eps, "topData", data_title, data);
-}
-
-
-PRIVATE void
-EPS_print_linear_data_left( FILE            *eps,
-                            const char      **data_title,
-                            vrna_data_lin_t **data){
-
-  EPS_print_linear_data(eps, "leftData", data_title, data);
-}
-
-
-PRIVATE void
-EPS_print_linear_data_bottom( FILE            *eps,
-                              const char      **data_title,
-                              vrna_data_lin_t **data){
-
-  EPS_print_linear_data(eps, "bottomData", data_title, data);
-}
-
-
-PRIVATE void
-EPS_print_linear_data_right(FILE            *eps,
-                            const char      **data_title,
-                            vrna_data_lin_t **data){
-
-  EPS_print_linear_data(eps, "rightData", data_title, data);
-}
-
-
-PRIVATE void
-EPS_print_linear_data(FILE            *eps,
-                      const char      *varname,
-                      const char      **data_title,
-                      vrna_data_lin_t **data){
-
-  int             n, i;
+  size_t          i;
   vrna_data_lin_t *ptr;
 
   /* count number of data sets */
-  for(n = 0; data_title[n]; n++);
 
   fprintf(eps, "/%s [\n", varname);
-  for(i = 0; i < n; i++){
-    fprintf(eps, "[ (%s)\n", data_title[i]);
-    for(ptr = data[i]; ptr->position > 0; ptr++){
+  for(i = 0; i < c->size; i++){
+    fprintf(eps, "[ (%s)\n", c->titles[i]);
+    for(ptr = c->data[i]; ptr->position > 0; ptr++){
       if((ptr->color.hue + ptr->color.sat + ptr->color.bri) == 0.){
         fprintf(eps, "  [ %d %1.9f ]\n", ptr->position, ptr->value);
       } else {
@@ -898,6 +902,101 @@ plist_to_ud_motif_prob(plist *pl, unsigned int length){
 }
 
 
+INLINE PRIVATE int
+init_lin_data(lin_dat *dat)
+{
+  if (dat) {
+    dat->north.size   = 0;
+    dat->north.mem    = 8;
+    dat->north.data   = (vrna_data_lin_t **)vrna_alloc(sizeof(vrna_data_lin_t *) * dat->north.mem);
+    dat->north.titles = (char **)vrna_alloc(sizeof(char *) * dat->north.mem);
+
+    dat->east.size   = 0;
+    dat->east.mem    = 8;
+    dat->east.data   = (vrna_data_lin_t **)vrna_alloc(sizeof(vrna_data_lin_t *) * dat->east.mem);
+    dat->east.titles = (char **)vrna_alloc(sizeof(char *) * dat->east.mem);
+
+    dat->south.size   = 0;
+    dat->south.mem    = 8;
+    dat->south.data   = (vrna_data_lin_t **)vrna_alloc(sizeof(vrna_data_lin_t *) * dat->south.mem);
+    dat->south.titles = (char **)vrna_alloc(sizeof(char *) * dat->south.mem);
+
+    dat->west.size   = 0;
+    dat->west.mem    = 8;
+    dat->west.data   = (vrna_data_lin_t **)vrna_alloc(sizeof(vrna_data_lin_t *) * dat->west.mem);
+    dat->west.titles = (char **)vrna_alloc(sizeof(char *) * dat->west.mem);
+
+    if ((dat->north.data == NULL) ||
+        (dat->east.data == NULL) ||
+        (dat->south.data == NULL) ||
+        (dat->west.data == NULL) ||
+        (dat->north.titles == NULL) ||
+        (dat->east.titles == NULL) ||
+        (dat->south.titles == NULL) ||
+        (dat->west.titles == NULL))  {
+      free(dat->north.data);
+      free(dat->east.data);
+      free(dat->south.data);
+      free(dat->west.data);
+      free(dat->north.titles);
+      free(dat->east.titles);
+      free(dat->south.titles);
+      free(dat->west.titles);
+      return 0; 
+    }
+  }
+
+  return 1;
+}
+
+
+INLINE PRIVATE void
+free_lin_data(lin_dat *dat)
+{
+  if (dat) {
+      free(dat->north.data);
+      free(dat->east.data);
+      free(dat->south.data);
+      free(dat->west.data);
+      free(dat->north.titles);
+      free(dat->east.titles);
+      free(dat->south.titles);
+      free(dat->west.titles);
+  }
+}
+
+
+INLINE PRIVATE int
+push_lin_data(lin_data_container  *c,
+              vrna_data_lin_t     *data,
+              char                *title)
+{
+  c->data[c->size]    = data;
+  c->titles[c->size]  = title;
+
+  if (++(c->size) == c->mem) {
+    c->mem += 8;
+    c->data = (vrna_data_lin_t **)vrna_realloc(c->data,
+                                               sizeof(vrna_data_lin_t *) *
+                                               c->mem);
+    c->titles = (char **)vrna_realloc(c->titles,
+                                      sizeof(char *) *
+                                      c->mem);
+  }
+
+  /* check whether we successfully re-allocated memory */
+  if ((c->data == NULL) ||
+      (c->titles == NULL)) {
+    free(c->data);
+    free(c->titles);
+    c->size = 0;
+    c->mem  = 0;
+    return 0;
+  }
+
+  return 1;
+}
+
 
 PRIVATE FILE *
 PS_dot_common(const char    *seq,
@@ -991,39 +1090,55 @@ int PS_dot_plot(char *string, char *wastlfile) {
   plist *pl;
   plist *mf;
 
-  length = strlen(string);
-  maxl = 2*length;
-  pl = (plist *)vrna_alloc(maxl*sizeof(plist));
-  k=0;
-  /*make plist out of pr array*/
-  for (i=1; i<length; i++)
-    for (j=i+1; j<=length; j++) {
-      if (pr[iindx[i]-j]<PMIN) continue;
-      if (k>=maxl-1) {
-        maxl *= 2;
-        pl = (plist *)vrna_realloc(pl,maxl*sizeof(plist));
+  i = 0;
+
+  if ((string) &&
+      (wastlfile) &&
+      (pr) &&
+      (iindx)) {
+    length = strlen(string);
+    maxl = 2*length;
+    pl = (plist *)vrna_alloc(maxl*sizeof(plist));
+    k=0;
+    /*make plist out of pr array*/
+    for (i=1; i<length; i++)
+      for (j=i+1; j<=length; j++) {
+        if (pr[iindx[i]-j]<PMIN) continue;
+        if (k>=maxl-1) {
+          maxl *= 2;
+          pl = (plist *)vrna_realloc(pl,maxl*sizeof(plist));
+        }
+        pl[k].i = i;
+        pl[k].j = j;
+        pl[k].p = pr[iindx[i]-j];
+        pl[k++].type = VRNA_PLIST_TYPE_BASEPAIR;
       }
-      pl[k].i = i;
-      pl[k].j = j;
-      pl[k++].p = pr[iindx[i]-j];
+    pl[k].i=0;
+    pl[k].j=0;
+    pl[k].p=0.;
+    pl[k++].type=VRNA_PLIST_TYPE_BASEPAIR;
+    /*make plist out of base_pair array*/
+    mf_num = base_pair ? base_pair[0].i : 0;
+    if (mf_num > 0) {
+      mf = (plist *)vrna_alloc((mf_num+1)*sizeof(plist));
+      for (k=0; k<mf_num; k++) {
+        mf[k].i = base_pair[k+1].i;
+        mf[k].j = base_pair[k+1].j;
+        mf[k].p = 0.95*0.95;
+        mf[k].type = VRNA_PLIST_TYPE_BASEPAIR;
+      }
+      mf[k].i=0;
+      mf[k].j=0;
+      mf[k].p=0.;
+      mf[k].type=0;
+    } else {
+      mf = NULL;
     }
-  pl[k].i=0;
-  pl[k].j=0;
-  pl[k++].p=0.;
-  /*make plist out of base_pair array*/
-  mf_num = base_pair ? base_pair[0].i : 0;
-  mf = (plist *)vrna_alloc((mf_num+1)*sizeof(plist));
-  for (k=0; k<mf_num; k++) {
-    mf[k].i = base_pair[k+1].i;
-    mf[k].j = base_pair[k+1].j;
-    mf[k].p = 0.95*0.95;
+    i = PS_dot_plot_list(string, wastlfile, pl, mf, "");
+    free(mf);
+    free(pl);
   }
-  mf[k].i=0;
-  mf[k].j=0;
-  mf[k].p=0.;
-  i = PS_dot_plot_list(string, wastlfile, pl, mf, "");
-  free(mf);
-  free(pl);
+
   return (i);
 }
 
