@@ -10,7 +10,17 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+
+#ifdef _WIN32
+#ifdef __MINGW32__
 #include <unistd.h>
+#else
+#include "ViennaRNA/unistd_win.h"
+#endif
+#else
+#include <unistd.h>
+#endif
+
 #include <ctype.h>
 #include <string.h>
 #include <math.h>
@@ -58,16 +68,16 @@
 
 typedef struct {
   struct hc_ext_def_dat     hc_dat_ext;
-  vrna_callback_hc_evaluate *hc_eval_ext;
+  vrna_hc_eval_f hc_eval_ext;
 
   struct hc_hp_def_dat      hc_dat_hp;
-  vrna_callback_hc_evaluate *hc_eval_hp;
+  vrna_hc_eval_f hc_eval_hp;
 
   struct hc_int_def_dat     hc_dat_int;
-  eval_hc                   *hc_eval_int;
+  eval_hc                   hc_eval_int;
 
   struct hc_mb_def_dat      hc_dat_mb;
-  vrna_callback_hc_evaluate *hc_eval_mb;
+  vrna_hc_eval_f hc_eval_mb;
 
   struct sc_f5_dat          sc_dat_ext;
   struct sc_hp_dat          sc_dat_hp;
@@ -104,7 +114,8 @@ struct old_subopt_dat {
   unsigned long           n_sol;
   vrna_subopt_solution_t  *SolutionList;
   FILE                    *fp;
-  int                     cp;
+  unsigned int            strands;
+  unsigned int            *strand_start;
 };
 
 /*
@@ -198,7 +209,6 @@ print_state(STATE *state);
 
 
 PRIVATE void
-UNUSED
 print_stack(LIST *list);
 
 
@@ -341,7 +351,9 @@ compare_en(const void *a,
 
 PRIVATE void
 make_output(vrna_subopt_solution_t  *SL,
-            int                     cp,
+            unsigned int            strands,
+            const unsigned int      *strand_start,
+            int                     compressed,
             FILE                    *fp);
 
 
@@ -401,13 +413,14 @@ vrna_subopt(vrna_fold_compound_t  *fc,
             FILE                  *fp)
 {
   struct old_subopt_dat data;
-  vrna_subopt_callback  *cb;
+  vrna_subopt_result_f  cb;
 
   data.SolutionList = NULL;
   data.max_sol      = 128;
   data.n_sol        = 0;
   data.fp           = fp;
-  data.cp           = fc->cutpoint;
+  data.strands      = fc->strands;
+  data.strand_start = fc->strand_start;
 
   if (fc) {
     /* SolutionList stores the suboptimal structures found */
@@ -421,8 +434,18 @@ vrna_subopt(vrna_fold_compound_t  *fc,
       float min_en;
       char  *SeQ, *energies = NULL;
       min_en = vrna_mfe(fc, NULL);
+      char  *tmp_seq = strdup(fc->sequence);
+
+      if (fc->strands == 1) {
+        SeQ = tmp_seq;
+      } else {
+        for (unsigned int i = 1; i < fc->strands; i++) {
+          SeQ = vrna_cut_point_insert(tmp_seq, (int)fc->strand_start[i] + (i - 1));
+          free(tmp_seq);
+          tmp_seq = SeQ;
+        }
+      }
 
-      SeQ       = vrna_cut_point_insert(fc->sequence, fc->cutpoint);
       energies  = vrna_strdup_printf(" %6.2f %6.2f", min_en, (float)delta / 100.);
       print_structure(fp, SeQ, energies);
       free(SeQ);
@@ -433,8 +456,12 @@ vrna_subopt(vrna_fold_compound_t  *fc,
 
     cb = old_subopt_store;
 
-    if (fp)
-      cb = (sorted) ? old_subopt_store_compressed : old_subopt_print;
+    if (fp) {
+      if (!sorted)
+        cb = old_subopt_print;
+      else if (!(fc->params->model_details.gquad))
+        cb = old_subopt_store_compressed;
+    }
 
     /* call subopt() */
     vrna_subopt_cb(fc, delta, cb, (void *)&data);
@@ -459,7 +486,11 @@ vrna_subopt(vrna_fold_compound_t  *fc,
       }
 
       if (fp)
-        make_output(data.SolutionList, fc->cutpoint, fp);
+        make_output(data.SolutionList,
+                    fc->strands,
+                    fc->strand_start,
+                    !(fc->params->model_details.gquad),
+                    fp);
     }
 
     if (fp) {
@@ -479,7 +510,7 @@ vrna_subopt(vrna_fold_compound_t  *fc,
 PUBLIC void
 vrna_subopt_cb(vrna_fold_compound_t *fc,
                int                  delta,
-               vrna_subopt_callback *cb,
+               vrna_subopt_result_f cb,
                void                 *data)
 {
   subopt_env          *env;
@@ -625,10 +656,22 @@ vrna_subopt_cb(vrna_fold_compound_t *fc,
         e = MAXDOS;
 
       density_of_states[e]++;
+
       if (structure_energy <= eprint) {
-        char *outstruct = vrna_cut_point_insert(structure, (fc->strands > 1) ? ss[so[1]] : -1);
-        cb((const char *)outstruct, structure_energy, data);
-        free(outstruct);
+        char  *outstruct = NULL;
+        char  *tmp_struct = strdup(structure);
+
+        if (fc->strands == 1) {
+          outstruct = tmp_struct;
+        } else {
+          for (unsigned int i = 1; i < fc->strands; i++) {
+            outstruct = vrna_cut_point_insert(tmp_struct, (int)fc->strand_start[i] + (i - 1));
+            free(tmp_struct);
+            tmp_struct = outstruct;
+          }
+        }
+        cb((const char *)tmp_struct, structure_energy, data);
+        free(tmp_struct);
       }
 
       free(structure);
@@ -983,18 +1026,28 @@ compare_en(const void *a,
 
 PRIVATE void
 make_output(vrna_subopt_solution_t  *SL,
-            int                     cp,
+            unsigned int            strands,
+            const unsigned int      *strand_start,
+            int                     compressed,
             FILE                    *fp)                  /* prints stuff */
 {
   vrna_subopt_solution_t *sol;
 
   for (sol = SL; sol->structure != NULL; sol++) {
     char  *e_string = vrna_strdup_printf(" %6.2f", sol->energy);
-    char  *ss       = vrna_db_unpack(sol->structure);
-    char  *s        = vrna_cut_point_insert(ss, cp);
+    char  *ss       = (compressed) ? vrna_db_unpack(sol->structure) : strdup(sol->structure);
+    char  *s        = ss;
+
+    if (strands > 1) {
+      for (unsigned int i = 1; i < strands; i++) {
+        s = vrna_cut_point_insert(ss, (int)strand_start[i] + (i - 1));
+        free(ss);
+        ss = s;
+      }
+    }
+
     print_structure(fp, s, e_string);
     free(s);
-    free(ss);
     free(e_string);
   }
 }
@@ -1260,10 +1313,10 @@ scan_mb(vrna_fold_compound_t  *fc,
   vrna_param_t              *P;
   vrna_md_t                 *md;
   struct hc_mb_def_dat      *hc_dat;
-  vrna_callback_hc_evaluate *evaluate;
+  vrna_hc_eval_f evaluate;
   struct sc_mb_dat          *sc_dat;
-  sc_mb_red_cb              *sc_red_stem;
-  sc_mb_red_cb              *sc_decomp_ml;
+  sc_mb_red_cb              sc_red_stem;
+  sc_mb_red_cb              sc_decomp_ml;
 
   STATE                     *temp_state;
 
@@ -1461,10 +1514,10 @@ scan_m1(vrna_fold_compound_t  *fc,
   vrna_param_t              *P;
   vrna_md_t                 *md;
   struct hc_mb_def_dat      *hc_dat;
-  vrna_callback_hc_evaluate *evaluate;
+  vrna_hc_eval_f evaluate;
   struct sc_mb_dat          *sc_dat;
-  sc_mb_red_cb              *sc_red_stem;
-  sc_mb_red_cb              *sc_red_ml;
+  sc_mb_red_cb              sc_red_stem;
+  sc_mb_red_cb              sc_red_ml;
 
   length  = fc->length;
   sn      = fc->strand_number;
@@ -1644,12 +1697,13 @@ scan_ext(vrna_fold_compound_t *fc,
                             length, *indx, circular, with_gquad, kj, tmp_en;
   vrna_param_t              *P;
   vrna_md_t                 *md;
+  vrna_sc_t                 *sc;
   struct hc_ext_def_dat     *hc_dat;
-  vrna_callback_hc_evaluate *evaluate;
+  vrna_hc_eval_f evaluate;
   struct sc_f5_dat          *sc_dat;
-  sc_f5_cb                  *sc_red_ext;
-  sc_f5_cb                  *sc_red_stem;
-  sc_f5_cb                  *sc_decomp_stem;
+  sc_f5_cb                  sc_red_ext;
+  sc_f5_cb                  sc_red_stem;
+  sc_f5_cb                  sc_decomp_stem;
 
   STATE                     *temp_state;
 
@@ -1661,6 +1715,7 @@ scan_ext(vrna_fold_compound_t *fc,
   S1      = fc->sequence_encoding;
   P       = fc->params;
   md      = &(P->model_details);
+  sc      = fc->sc;
 
   dangle_model  = md->dangles;
   circular      = md->circ;
@@ -1826,8 +1881,9 @@ scan_ext(vrna_fold_compound_t *fc,
 
     element_energy = vrna_E_ext_stem(type, s5, s3, P);
 
-    if (sc_red_stem)
-      element_energy += sc_red_stem(j, 1, j, sc_dat);
+    if (sc)
+      if (sc->f)
+        element_energy += sc->f(1, j, 1, j, VRNA_DECOMP_EXT_STEM, sc->data);
 
     if (c[kj] + element_energy + best_energy <= threshold) {
       repeat(fc,
@@ -1867,14 +1923,14 @@ scan_circular(vrna_fold_compound_t  *fc,
   struct hc_ext_def_dat     *hc_dat_ext;
   struct hc_int_def_dat     *hc_dat_int;
   struct hc_mb_def_dat      *hc_dat_mb;
-  vrna_callback_hc_evaluate *evaluate_ext;
-  eval_hc                   *evaluate_int;
-  vrna_callback_hc_evaluate *evaluate_mb;
+  vrna_hc_eval_f evaluate_ext;
+  eval_hc                   evaluate_int;
+  vrna_hc_eval_f evaluate_mb;
 
   struct sc_int_dat         *sc_dat_int;
   struct sc_mb_dat          *sc_dat_mb;
-  sc_int_cb                 *sc_int_pair_ext;
-  sc_mb_red_cb              *sc_mb_decomp_ml;
+  sc_int_cb                 sc_int_pair_ext;
+  sc_mb_red_cb              sc_mb_decomp_ml;
 
   STATE                     *new_state;
   INTERVAL                  *new_interval;
@@ -2148,11 +2204,11 @@ scan_fms5(vrna_fold_compound_t  *fc,
   vrna_param_t              *P;
   vrna_md_t                 *md;
   struct hc_ext_def_dat     *hc_dat;
-  vrna_callback_hc_evaluate *evaluate;
+  vrna_hc_eval_f evaluate;
   struct sc_f5_dat          *sc_dat;
-  sc_ext_red_cb             *sc_red_ext;
-  sc_ext_red_cb             *sc_red_stem;
-  sc_ext_red_cb             *sc_decomp;
+  sc_ext_red_cb             sc_red_ext;
+  sc_ext_red_cb             sc_red_stem;
+  sc_ext_red_cb             sc_decomp;
 
   STATE                     *temp_state;
 
@@ -2352,11 +2408,11 @@ scan_fms3(vrna_fold_compound_t  *fc,
   vrna_param_t              *P;
   vrna_md_t                 *md;
   struct hc_ext_def_dat     *hc_dat;
-  vrna_callback_hc_evaluate *evaluate;
+  vrna_hc_eval_f evaluate;
   struct sc_f5_dat          *sc_dat;
-  sc_ext_red_cb             *sc_red_ext;
-  sc_ext_red_cb             *sc_red_stem;
-  sc_ext_red_cb             *sc_decomp;
+  sc_ext_red_cb             sc_red_ext;
+  sc_ext_red_cb             sc_red_stem;
+  sc_ext_red_cb             sc_decomp;
   STATE                     *temp_state;
 
   length  = fc->length;
@@ -2609,10 +2665,10 @@ repeat_gquad(vrna_fold_compound_t *fc,
 
       for (cnt = 0; L[cnt] != -1; cnt++) {
         new_state = copy_state(state);
-
         make_gquad(i, L[cnt], &(l[3 * cnt]), new_state);
         new_state->partial_energy += part_energy;
-        new_state->partial_energy += element_energy;
+        /* re-compute energies */
+        new_state->partial_energy += E_gquad(L[cnt], &(l[3*cnt]), P);
         /* new_state->best_energy =
          * hairpin[unpaired] + element_energy + best_energy; */
         push(env->Stack, new_state);
@@ -2656,18 +2712,19 @@ repeat(vrna_fold_compound_t *fc,
   vrna_param_t              *P;
   vrna_md_t                 *md;
   vrna_hc_t                 *hc;
+  vrna_sc_t                 *sc;
   struct hc_int_def_dat     *hc_dat_int;
   struct hc_ext_def_dat     *hc_dat_ext;
   struct hc_mb_def_dat      *hc_dat_mb;
-  eval_hc                   *evaluate_int;
-  vrna_callback_hc_evaluate *evaluate_ext;
-  vrna_callback_hc_evaluate *evaluate_mb;
+  eval_hc                   evaluate_int;
+  vrna_hc_eval_f evaluate_ext;
+  vrna_hc_eval_f evaluate_mb;
 
   struct sc_int_dat         *sc_dat_int;
   struct sc_mb_dat          *sc_dat_mb;
-  sc_int_cb                 *sc_int_pair;
-  sc_mb_pair_cb             *sc_mb_pair;
-  sc_mb_red_cb              *sc_mb_decomp_ml;
+  sc_int_cb                 sc_int_pair;
+  sc_mb_pair_cb             sc_mb_pair;
+  sc_mb_red_cb              sc_mb_decomp_ml;
   STATE                     *new_state;
 
   n     = fc->length;
@@ -2701,6 +2758,7 @@ repeat(vrna_fold_compound_t *fc,
   evaluate_int  = constraints_dat->hc_eval_int;
   evaluate_mb   = constraints_dat->hc_eval_mb;
 
+  sc              = fc->sc;
   sc_dat_int      = &(constraints_dat->sc_dat_int);
   sc_dat_mb       = &(constraints_dat->sc_dat_mb);
   sc_int_pair     = constraints_dat->sc_dat_int.pair;
@@ -2822,6 +2880,9 @@ repeat(vrna_fold_compound_t *fc,
         break;
     }
 
+    if ((sc) && (sc->f))
+      element_energy += sc->f(i, j, i, j, VRNA_DECOMP_EXT_STEM, sc->data);
+
     if (sn[i] != sn[i + 1]) {
       if ((sn[j - 1] != sn[j]) &&
           (i + 1 == j)) {
@@ -3050,9 +3111,14 @@ old_subopt_store_compressed(const char  *structure,
 
   if (structure) {
     d->SolutionList[d->n_sol].energy = energy;
-    if (d->cp > 0) {
-      int   cp  = d->cp;
-      char  *s  = vrna_cut_point_remove(structure, &cp);
+    if (d->strands > 1) {
+      char **tok  = vrna_strsplit(structure, NULL);
+      char *s     = vrna_strjoin((const char **)tok, NULL);
+
+      for (char **ptr = tok; *ptr!= NULL; ptr++)
+        free(*ptr);
+      free(tok);
+
       d->SolutionList[d->n_sol++].structure = vrna_db_pack(s);
       free(s);
     } else {
