@@ -20,11 +20,6 @@
  *  @brief RNAsubopt and density of states declarations
  */
 
-/**
- *  @addtogroup subopt_and_representatives
- *  @brief Sample and enumerate suboptimal secondary structures from RNA sequence data.
- */
-
 /**
  *  @brief Typename for the subopt solution list repesenting data structure #vrna_subopt_sol_s
  */
@@ -45,10 +40,15 @@ typedef struct vrna_subopt_sol_s vrna_subopt_solution_t;
  * @param energy    The free energy of the secondary structure in kcal/mol
  * @param data      Some arbitrary, auxiliary data address as passed to vrna_subopt_cb()
  */
-typedef void (vrna_subopt_callback)(const char  *stucture,
+typedef void (*vrna_subopt_result_f)(const char  *stucture,
                                     float       energy,
                                     void        *data);
 
+DEPRECATED(typedef void (vrna_subopt_callback)(const char  *stucture,
+                                    float       energy,
+                                    void        *data),
+          "Use vrna_subopt_result_f instead!");
+
 #ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
 
 /**
@@ -94,7 +94,7 @@ struct vrna_subopt_sol_s {
  *  @brief Returns list of subopt structures or writes to fp
  *
  *  This function produces <b>all</b> suboptimal secondary structures within
- *  'delta' * 0.01 kcal/mol of the optimum, see @cite wuchty:1999. The results
+ *  'delta' * 0.01 kcal/mol of the optimum, see @rstinline :cite:t:`wuchty:1999` @endrst. The results
  *  are either directly written to a 'fp' (if 'fp' is not NULL), or
  *  (fp==NULL) returned in a #vrna_subopt_solution_t * list terminated
  *  by an entry were the 'structure' member is NULL.
@@ -103,17 +103,18 @@ struct vrna_subopt_sol_s {
  *
  *  @note This function requires all multibranch loop DP matrices for unique
  *        multibranch loop backtracing. Therefore, the supplied #vrna_fold_compound_t
- *        @p vc (argument 1) must be initialized with #vrna_md_t.uniq_ML = 1, for
+ *        @p fc (argument 1) must be initialized with #vrna_md_t.uniq_ML = 1, for
  *        instance like this:
  *        @code
  * vrna_md_t md;
  * vrna_md_set_default(&md);
  * md.uniq_ML = 1;
  *
- * vrna_fold_compound_t *vc=vrna_fold_compound("GGGGGGAAAAAACCCCCC", &md, VRNA_OPTION_DEFAULT);
+ * vrna_fold_compound_t *fc=vrna_fold_compound("GGGGGGAAAAAACCCCCC", &md, VRNA_OPTION_DEFAULT);
  *        @endcode
  *
  *  @see vrna_subopt_cb(), vrna_subopt_zuker()
+ *
  *  @param  fc
  *  @param  delta
  *  @param  sorted  Sort results by energy in ascending order
@@ -131,7 +132,7 @@ vrna_subopt(vrna_fold_compound_t  *fc,
  *  @brief  Generate suboptimal structures within an energy band arround the MFE
  *
  *  This is the most generic implementation of the suboptimal structure generator
- *  according to Wuchty et al. 1999 @cite wuchty:1999. Identical to vrna_subopt(), it computes all
+ *  according to @rstinline :cite:t:`wuchty:1999` @endrst. Identical to vrna_subopt(), it computes all
  *  secondary structures within an energy band @p delta arround the MFE. However,
  *  this function does not print the resulting structures and their corresponding
  *  free energies to a file pointer, or returns them as a list. Instead, it calls
@@ -145,17 +146,18 @@ vrna_subopt(vrna_fold_compound_t  *fc,
  *
  *  @note This function requires all multibranch loop DP matrices for unique
  *        multibranch loop backtracing. Therefore, the supplied #vrna_fold_compound_t
- *        @p vc (argument 1) must be initialized with #vrna_md_t.uniq_ML = 1, for
+ *        @p fc (argument 1) must be initialized with #vrna_md_t.uniq_ML = 1, for
  *        instance like this:
  *        @code
  * vrna_md_t md;
  * vrna_md_set_default(&md);
  * md.uniq_ML = 1;
  *
- * vrna_fold_compound_t *vc=vrna_fold_compound("GGGGGGAAAAAACCCCCC", &md, VRNA_OPTION_DEFAULT);
+ * vrna_fold_compound_t *fc=vrna_fold_compound("GGGGGGAAAAAACCCCCC", &md, VRNA_OPTION_DEFAULT);
  *        @endcode
  *
- *  @see vrna_subopt_callback, vrna_subopt(), vrna_subopt_zuker()
+ *  @see vrna_subopt_result_f, vrna_subopt(), vrna_subopt_zuker()
+ *
  *  @param  fc      fold compount with the sequence data
  *  @param  delta   Energy band arround the MFE in 10cal/mol, i.e. deka-calories
  *  @param  cb      Pointer to a callback function that handles the backtracked structure and its free energy in kcal/mol
@@ -164,7 +166,7 @@ vrna_subopt(vrna_fold_compound_t  *fc,
 void
 vrna_subopt_cb(vrna_fold_compound_t *fc,
                int                  delta,
-               vrna_subopt_callback *cb,
+               vrna_subopt_result_f cb,
                void                 *data);
 
 
@@ -197,6 +199,7 @@ extern int subopt_sorted;
  *
  *  @pre  Call one of the functions subopt_par(), subopt() or subopt_circ() prior accessing the contents
  *        of this array
+ *
  *  @see  subopt_par(), subopt(), subopt_circ()
  *
  */
