@@ -22,7 +22,6 @@
 /**
  *  @addtogroup aln_utils
  *  @{
- *  @brief  Functions to extract features from and to manipulate multiple sequence alignments
  */
 
 /** @brief Typename for the base pair info repesenting data structure #vrna_pinfo_s */
@@ -119,13 +118,13 @@ vrna_aln_mpi(const char **alignment);
  *
  *  \see #vrna_pinfo_t, and vrna_pf()
  *
- *  \param  vc          The #vrna_fold_compound_t of type #VRNA_FC_TYPE_COMPARATIVE with precomputed partition function matrices
+ *  \param  fc          The #vrna_fold_compound_t of type #VRNA_FC_TYPE_COMPARATIVE with precomputed partition function matrices
  *  \param  structure   An optional structure in dot-bracket notation (Maybe NULL)
  *  \param  threshold   Do not include results with pair probabilities below threshold
  *  \return             The #vrna_pinfo_t array
  */
 vrna_pinfo_t *
-vrna_aln_pinfo(vrna_fold_compound_t *vc,
+vrna_aln_pinfo(vrna_fold_compound_t *fc,
                const char           *structure,
                double               threshold);
 
@@ -273,7 +272,7 @@ vrna_aln_consensus_sequence(const char      **alignment,
 /**
  *  @brief  Compute the Most Informative Sequence (MIS) for a given multiple sequence alignment
  *
- *  The most informative sequence (MIS) @cite freyhult:2005 displays for each alignment column
+ *  The most informative sequence (MIS) @rstinline :cite:p:`freyhult:2005` @endrst displays for each alignment column
  *  the nucleotides with frequency greater than the background frequency, projected into IUPAC
  *  notation. Columns where gaps are over-represented are in lower case.
  *
