@@ -26,6 +26,7 @@
 #include "ViennaRNA/io/utils.h"
 #include "ViennaRNA/utils/alignments.h"
 
+#define NONE -10000 /* score for forbidden pairs */
 /*
  #################################
  # GLOBAL VARIABLES              #
@@ -131,7 +132,6 @@ vrna_aln_pinfo(vrna_fold_compound_t *vc,
   int           *my_iindx = vc->iindx;
   FLT_OR_DBL    *probs    = vc->exp_matrices->probs;
   vrna_md_t     *md       = &(vc->exp_params->model_details);
-  int           turn      = md->min_loop_size;
 
   max_p = 64;
   pi    = vrna_alloc(max_p * sizeof(vrna_pinfo_t));
@@ -140,7 +140,7 @@ vrna_aln_pinfo(vrna_fold_compound_t *vc,
     ptable = vrna_ptable(structure);
 
   for (i = 1; i < n; i++)
-    for (j = i + turn + 1; j <= n; j++) {
+    for (j = i + 1; j <= n; j++) {
       if ((p = probs[my_iindx[i] - j]) >= threshold) {
         duck[i] -= p * log(p);
         duck[j] -= p * log(p);
@@ -186,6 +186,106 @@ vrna_aln_pinfo(vrna_fold_compound_t *vc,
 }
 
 
+PUBLIC int
+vrna_pscore(vrna_fold_compound_t  *fc,
+            unsigned int          i,
+            unsigned int          j)
+{
+  char          **AS;
+  short         **S;
+  unsigned int  n, tmp, u, s, n_seq;
+  int           max_span;
+  vrna_md_t     *md;
+
+  if (i > j) {
+    tmp = i;
+    i   = j;
+    j   = tmp;
+  }
+
+  if ((fc) &&
+      (fc->type == VRNA_FC_TYPE_COMPARATIVE) &&
+      (fc->length >= j)) {
+    n         = fc->length;
+    n_seq     = fc->n_seq;
+    u         = j - i - 1;
+    md        = &(fc->params->model_details);
+    max_span  = md->max_bp_span;
+    AS        = fc->sequences;
+    S         = fc->S;
+
+    if ((max_span < 2) ||
+        (max_span > (int)n))
+      max_span = (int)n;
+
+    if ((u + 2) <= max_span) {
+      unsigned int pfreq[8] = {
+        0, 0, 0, 0, 0, 0, 0, 0
+      };
+
+      /* collect base pair frequencies */
+      for (s = 0; s < n_seq; s++) {
+        unsigned int type;
+
+        if (S[s][i] == 0 && S[s][j] == 0) {
+          type = 7;                             /* gap-gap  */
+        } else {
+          if ((AS[s][i] == '~') || (AS[s][j] == '~'))
+            type = 7;
+          else
+            type = md->pair[S[s][i]][S[s][j]];
+        }
+
+        pfreq[type]++;
+      }
+
+      return vrna_pscore_freq(fc, (const unsigned int *)pfreq, 6);
+    }
+  }
+
+  return NONE;
+}
+
+
+PUBLIC int
+vrna_pscore_freq(vrna_fold_compound_t *fc,
+                 const unsigned int   *frequencies,
+                 unsigned int         pairs)
+{
+  if ((fc) &&
+      (frequencies)) {
+    unsigned int  k, l, n_seq;
+    double        score;
+    vrna_md_t     *md;
+
+    n_seq = fc->n_seq;
+    md    = &(fc->params->model_details);
+
+    /*
+     *  assume first (0) and last (pairs + 1) frequency to reflect
+     *  counter-examples and gap-pairs, respectively
+     */
+    if (2 * frequencies[0] +
+        frequencies[pairs + 1] < n_seq) {
+      score = 0.;
+
+      for (k = 1; k <= pairs; k++) /* ignore pairtype 7 (gap-gap) */
+        for (l = k; l <= pairs; l++) {
+          score += (double)frequencies[k] *
+                   (double)frequencies[l] *
+                   md->pair_dist[k][l];
+        }
+
+      /* counter examples score -1, gap-gap scores -0.25   */
+      return md->cv_fact * ((UNIT * score) / n_seq -
+                            md->nc_fact * UNIT * (frequencies[0] + frequencies[pairs + 1] * 0.25));
+    }
+  }
+
+  return NONE;
+}
+
+
 PUBLIC int *
 vrna_aln_pscore(const char  **alignment,
                 vrna_md_t   *md)
@@ -196,9 +296,8 @@ vrna_aln_pscore(const char  **alignment,
    * should be 0 for conserved pairs, >0 for good pairs
    */
 
-#define NONE -10000 /* score for forbidden pairs */
 
-  int       i, j, k, l, s, n, n_seq, *indx, turn, max_span;
+  int       i, j, k, l, s, n, n_seq, *indx, max_span;
   float     **dm;
   vrna_md_t md_default;
   int       *pscore;
@@ -234,8 +333,6 @@ vrna_aln_pscore(const char  **alignment,
 
     indx = vrna_idx_col_wise(n);
 
-    turn = md->min_loop_size;
-
     pscore = (int *)vrna_alloc(sizeof(int) * ((n + 1) * (n + 2) / 2 + 2));
 
     if (md->ribo) {
@@ -254,17 +351,21 @@ vrna_aln_pscore(const char  **alignment,
     }
 
     max_span = md->max_bp_span;
-    if ((max_span < turn + 2) || (max_span > n))
+    if ((max_span < 2) || (max_span > n))
       max_span = n;
 
     for (i = 1; i < n; i++) {
-      for (j = i + 1; (j < i + turn + 1) && (j <= n); j++)
-        pscore[indx[j] + i] = NONE;
-      for (j = i + turn + 1; j <= n; j++) {
+      for (j = i + 1; j <= n; j++) {
         int     pfreq[8] = {
           0, 0, 0, 0, 0, 0, 0, 0
         };
         double  score;
+
+        if ((j - i + 1) > max_span) {
+          pscore[indx[j] + i] = NONE;
+          continue;
+        }
+
         for (s = 0; s < n_seq; s++) {
           int type;
           if (S[s][i] == 0 && S[s][j] == 0) {
@@ -278,7 +379,8 @@ vrna_aln_pscore(const char  **alignment,
 
           pfreq[type]++;
         }
-        if (pfreq[0] * 2 + pfreq[7] > n_seq) {
+
+        if (pfreq[0] * 2 + pfreq[7] >= n_seq) {
           pscore[indx[j] + i] = NONE;
           continue;
         }
@@ -287,22 +389,18 @@ vrna_aln_pscore(const char  **alignment,
           for (l = k; l <= 6; l++)
             score += pfreq[k] * pfreq[l] * dm[k][l];
         /* counter examples score -1, gap-gap scores -0.25   */
-        pscore[indx[j] + i] = md->cv_fact *
-                              ((UNIT * score) / n_seq - md->nc_fact * UNIT *
-                               (pfreq[0] + pfreq[7] * 0.25));
-
-        if ((j - i + 1) > max_span)
-          pscore[indx[j] + i] = NONE;
+        pscore[indx[j] + i] = md->cv_fact * ((UNIT * score) / n_seq -
+                                             md->nc_fact * UNIT * (pfreq[0] + pfreq[7] * 0.25));
       }
     }
 
     if (md->noLP) {
       /* remove unwanted pairs */
-      for (k = 1; k < n - turn - 1; k++)
+      for (k = 1; k < n - 1; k++)
         for (l = 1; l <= 2; l++) {
           int type, ntype = 0, otype = 0;
           i     = k;
-          j     = i + turn + l;
+          j     = i + l;
           type  = pscore[indx[j] + i];
           while ((i >= 1) && (j <= n)) {
             if ((i > 1) && (j < n))
