@@ -30,6 +30,18 @@
 # define INLINE
 #endif
 
+
+#define SHAPES_OPEN   '['
+#define SHAPES_CLOSE  ']'
+#define SHAPES_UP     '_'
+
+struct shrep {
+  struct shrep  *pred;
+  struct shrep  *succ;
+  char          character;
+};
+
+
 /*
  #################################
  # PRIVATE FUNCTION DECLARATIONS #
@@ -68,6 +80,39 @@ extract_pairs(short       *pt,
               const char  *pair);
 
 
+PRIVATE INLINE struct shrep *
+shrep_insert_after(struct shrep *target,
+                   char         character);
+
+
+PRIVATE INLINE struct shrep *
+shrep_insert_before(struct shrep  *target,
+                    char          character);
+
+
+PRIVATE INLINE void
+shrep_concat(struct shrep **target,
+             struct shrep *suffix);
+
+
+PRIVATE INLINE char *
+db2shapes(const char    *structure,
+          unsigned int  level);
+
+
+PRIVATE INLINE char *
+db2shapes_pt(const short  *pt,
+             unsigned int n,
+             unsigned int level);
+
+
+PRIVATE INLINE struct shrep *
+get_shrep(const short   *pt,
+          unsigned int  start,
+          unsigned int  end,
+          unsigned int  level);
+
+
 /*
  #################################
  # BEGIN OF FUNCTION DEFINITIONS #
@@ -308,25 +353,75 @@ vrna_db_pk_remove(const char    *structure,
 
 
 PUBLIC char *
-vrna_db_from_ptable(short *pt)
+vrna_db_from_ptable(const short *ptable)
 {
-  unsigned int  n;
-  int           i;
-  char          *dotbracket = NULL;
+  char          *dotbracket           = NULL;
+  const char    *bracket_open_avail   = "([{<ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+  const char    *bracket_close_avail  = ")]}>abcdefghijklmnopqrstuvwxyz";
+  short         *pt;
+  unsigned int  n, i, stack_cnt, *stack, bracket_count, recheck;
 
-  if (pt) {
-    n = (unsigned int)pt[0];
+  if (ptable) {
+    n = (unsigned int)ptable[0];
     if (n > 0) {
+      pt = (short *)vrna_alloc(sizeof(short) * (n + 1));
+      pt = memcpy(pt, ptable, sizeof(short) * (n + 1));
+
+      /* check for validity, i.e. both pairing positions must specify pairing partner */
+      for (i = 1; i <= n; i++) {
+        if (((unsigned int)pt[i] > i) &&
+            ((unsigned int)pt[pt[i]] != i))
+          return NULL;
+      }
+
+      /* prepare everything */
       dotbracket = (char *)vrna_alloc((n + 1) * sizeof(char));
       memset(dotbracket, '.', n);
 
-      for (i = 1; i <= n; i++) {
-        if (pt[i] > i) {
-          dotbracket[i - 1]     = '(';
-          dotbracket[pt[i] - 1] = ')';
+      bracket_count = 0;
+      recheck       = 1;
+      stack         = (unsigned int *)vrna_alloc(sizeof(unsigned int) * (n + 1));
+      stack_cnt     = 0;
+
+      while (recheck) {
+        recheck = 0;
+
+        for (i = 1; i <= n; i++) {
+          if (pt[i] > i) {
+            /* check for clash */
+            if ((stack_cnt > 0) &&
+                (pt[i] > stack[stack_cnt - 1])) {
+              recheck = 1;
+              continue;
+            } else {
+              stack[stack_cnt++] = pt[i];
+              dotbracket[i - 1] = bracket_open_avail[bracket_count];
+              dotbracket[pt[i] - 1] = bracket_close_avail[bracket_count];
+            }
+          } else if (pt[i] != 0) {
+            if (stack_cnt == 0)
+              continue;
+
+            if (i == stack[stack_cnt - 1]) {
+              /* remove pair from pair table */
+              pt[i] = pt[pt[i]] = 0;
+              stack_cnt--;
+            }
+          }
+        }
+
+        stack_cnt = 0;
+        bracket_count++;
+
+        if (bracket_count >= 30) {
+          vrna_message_warning("Not enough bracket types available in vrna_db_from_ptable()! Skipping remaining base pairs!");
+          break;
         }
       }
+
       dotbracket[i - 1] = '\0';
+      free(stack);
+      free(pt);
     }
   }
 
@@ -493,33 +588,51 @@ vrna_db_from_WUSS(const char *wuss)
 
 /*---------------------------------------------------------------------------*/
 
+PUBLIC int
+vrna_bp_distance_pt(const short *pt1,
+                    const short *pt2)
+{
+  /*
+   * dist = {number of base pairs in one structure but not in the other}
+   * same as edit distance with pair_open pair_close as move set
+   */
+  int   dist;
+  short i, l;
+
+  dist = 0;
+
+  if (pt1 && pt2) {
+    l = (pt1[0] < pt2[0]) ? pt1[0] : pt2[0]; /* minimum of the two lengths */
+
+    for (i = 1; i <= l; i++)
+      if (pt1[i] != pt2[i]) {
+        if (pt1[i] > i)
+          dist++;
+
+        if (pt2[i] > i)
+          dist++;
+      }
+  }
+
+  return dist;
+}
+
+
 PUBLIC int
 vrna_bp_distance(const char *str1,
                  const char *str2)
 {
-  /* dist = {number of base pairs in one structure but not in the other} */
-  /* same as edit distance with pair_open pair_close as move set */
-  int   dist;
-  short i, l;
-  short *t1, *t2;
+  int   dist = 0;
+  short *pt1, *pt2;
 
-  dist  = 0;
-  t1    = vrna_ptable(str1);
-  t2    = vrna_ptable(str2);
+  pt1 = vrna_ptable(str1);
+  pt2 = vrna_ptable(str2);
 
-  l = (t1[0] < t2[0]) ? t1[0] : t2[0]; /* minimum of the two lengths */
+  dist = vrna_bp_distance_pt(pt1, pt2);
 
-  for (i = 1; i <= l; i++)
-    if (t1[i] != t2[i]) {
-      if (t1[i] > i)
-        dist++;
+  free(pt1);
+  free(pt2);
 
-      if (t2[i] > i)
-        dist++;
-    }
-
-  free(t1);
-  free(t2);
   return dist;
 }
 
@@ -643,6 +756,7 @@ vrna_refBPdist_matrix(const short   *pt1,
   size  = ((n + 1) * (n + 2)) / 2;
   array = (unsigned int *)vrna_alloc(sizeof(unsigned int) * size);
   int           *iindx = vrna_idx_row_wise(n);
+
   for (i = n - turn - 1; i >= 1; i--) {
     d = 0;
     for (j = i + turn + 1; j <= n; j++) {
@@ -704,24 +818,28 @@ vrna_db_from_probs(const FLT_OR_DBL *p,
   float P[3];    /* P[][0] unpaired, P[][1] upstream p, P[][2] downstream p */
   char  *s;
 
-  index = vrna_idx_row_wise(length);
-  s     = (char *)vrna_alloc(sizeof(char) * (length + 1));
+  s = NULL;
 
-  for (j = 1; j <= length; j++) {
-    P[0]  = 1.0;
-    P[1]  = P[2] = 0.0;
-    for (i = 1; i < j; i++) {
-      P[2]  += (float)p[index[i] - j];  /* j is paired downstream */
-      P[0]  -= (float)p[index[i] - j];  /* j is unpaired */
+  if (p) {
+    index = vrna_idx_row_wise(length);
+    s     = (char *)vrna_alloc(sizeof(char) * (length + 1));
+
+    for (j = 1; j <= length; j++) {
+      P[0]  = 1.0;
+      P[1]  = P[2] = 0.0;
+      for (i = 1; i < j; i++) {
+        P[2]  += (float)p[index[i] - j];  /* j is paired downstream */
+        P[0]  -= (float)p[index[i] - j];  /* j is unpaired */
+      }
+      for (i = j + 1; i <= length; i++) {
+        P[1]  += (float)p[index[j] - i];  /* j is paired upstream */
+        P[0]  -= (float)p[index[j] - i];  /* j is unpaired */
+      }
+      s[j - 1] = vrna_bpp_symbol(P);
     }
-    for (i = j + 1; i <= length; i++) {
-      P[1]  += (float)p[index[j] - i];  /* j is paired upstream */
-      P[0]  -= (float)p[index[j] - i];  /* j is unpaired */
-    }
-    s[j - 1] = vrna_bpp_symbol(P);
+    s[length] = '\0';
+    free(index);
   }
-  s[length] = '\0';
-  free(index);
 
   return s;
 }
@@ -771,37 +889,42 @@ vrna_db_from_bp_stack(vrna_bp_stack_t *bp,
   int   k, i, j, temp;
   char  *structure;
 
-  structure = vrna_alloc(sizeof(char) * (length + 1));
+  structure = NULL;
 
-  if (length > 0)
-    memset(structure, '.', length);
+  if (bp) {
+    structure = vrna_alloc(sizeof(char) * (length + 1));
 
-  structure[length] = '\0';
+    if (length > 0)
+      memset(structure, '.', length);
 
-  for (k = 1; k <= bp[0].i; k++) {
-    i = bp[k].i;
-    j = bp[k].j;
-    if (i > length)
-      i -= length;
+    structure[length] = '\0';
 
-    if (j > length)
-      j -= length;
+    for (k = 1; k <= bp[0].i; k++) {
+      i = bp[k].i;
+      j = bp[k].j;
+      if (i > length)
+        i -= length;
 
-    if (i > j) {
-      temp  = i;
-      i     = j;
-      j     = temp;
-    }
+      if (j > length)
+        j -= length;
 
-    if (i == j) {
-      /* Gquad bonds are marked as bp[i].i == bp[i].j */
-      structure[i - 1] = '+';
-    } else {
-      /* the following ones are regular base pairs */
-      structure[i - 1]  = '(';
-      structure[j - 1]  = ')';
+      if (i > j) {
+        temp  = i;
+        i     = j;
+        j     = temp;
+      }
+
+      if (i == j) {
+        /* Gquad bonds are marked as bp[i].i == bp[i].j */
+        structure[i - 1] = '+';
+      } else {
+        /* the following ones are regular base pairs */
+        structure[i - 1]  = '(';
+        structure[j - 1]  = ')';
+      }
     }
   }
+
   return structure;
 }
 
@@ -815,40 +938,44 @@ vrna_plist(const char *struc,
   int       i, k = 0, size, n;
   vrna_ep_t *gpl, *ptr, *pl;
 
-  size  = strlen(struc);
-  n     = 2;
+  pl = NULL;
 
-  pt  = vrna_ptable(struc);
-  pl  = (vrna_ep_t *)vrna_alloc(n * size * sizeof(vrna_ep_t));
-  for (i = 1; i < size; i++) {
-    if (pt[i] > i) {
-      (pl)[k].i       = i;
-      (pl)[k].j       = pt[i];
-      (pl)[k].p       = pr;
-      (pl)[k++].type  = VRNA_PLIST_TYPE_BASEPAIR;
-    }
-  }
+  if (struc) {
+    size  = strlen(struc);
+    n     = 2;
 
-  gpl = get_plist_gquad_from_db(struc, pr);
-  for (ptr = gpl; ptr->i != 0; ptr++) {
-    if (k == n * size - 1) {
-      n   *= 2;
-      pl  = (vrna_ep_t *)vrna_realloc(pl, n * size * sizeof(vrna_ep_t));
+    pt  = vrna_ptable(struc);
+    pl  = (vrna_ep_t *)vrna_alloc(n * size * sizeof(vrna_ep_t));
+    for (i = 1; i < size; i++) {
+      if (pt[i] > i) {
+        (pl)[k].i       = i;
+        (pl)[k].j       = pt[i];
+        (pl)[k].p       = pr;
+        (pl)[k++].type  = VRNA_PLIST_TYPE_BASEPAIR;
+      }
     }
 
-    (pl)[k].i       = ptr->i;
-    (pl)[k].j       = ptr->j;
-    (pl)[k].p       = ptr->p;
-    (pl)[k++].type  = ptr->type;
-  }
-  free(gpl);
+    gpl = get_plist_gquad_from_db(struc, pr);
+    for (ptr = gpl; ptr->i != 0; ptr++) {
+      if (k == n * size - 1) {
+        n   *= 2;
+        pl  = (vrna_ep_t *)vrna_realloc(pl, n * size * sizeof(vrna_ep_t));
+      }
 
-  (pl)[k].i       = 0;
-  (pl)[k].j       = 0;
-  (pl)[k].p       = 0.;
-  (pl)[k++].type  = 0.;
-  free(pt);
-  pl = (vrna_ep_t *)vrna_realloc(pl, k * sizeof(vrna_ep_t));
+      (pl)[k].i       = ptr->i;
+      (pl)[k].j       = ptr->j;
+      (pl)[k].p       = ptr->p;
+      (pl)[k++].type  = ptr->type;
+    }
+    free(gpl);
+
+    (pl)[k].i       = 0;
+    (pl)[k].j       = 0;
+    (pl)[k].p       = 0.;
+    (pl)[k++].type  = 0.;
+    free(pt);
+    pl = (vrna_ep_t *)vrna_realloc(pl, k * sizeof(vrna_ep_t));
+  }
 
   return pl;
 }
@@ -876,7 +1003,8 @@ vrna_db_from_plist(vrna_ep_t    *pairs,
   vrna_ep_t *ptr;
   char      *structure = NULL;
 
-  if (n > 0) {
+  if ((n > 0) &&
+      (pairs)) {
     structure = (char *)vrna_alloc(sizeof(char) * (n + 1));
     memset(structure, '.', n);
     structure[n] = '\0';
@@ -912,7 +1040,8 @@ vrna_plist_append(vrna_ep_t       **target,
 
     if (*target) {
       memcpy(*target + size1, list, sizeof(vrna_ep_t) * size2);
-      (*target)[size1 + size2].i = (*target)[size1 + size2].j = 0;
+      (*target)[size1 + size2].i    = (*target)[size1 + size2].j = 0;
+      (*target)[size1 + size2].type = 0;
       return 1;
     }
   }
@@ -927,40 +1056,45 @@ vrna_hx_from_ptable(short *pt)
   int       i, k, n, l, s, *stack;
   vrna_hx_t *list;
 
-  n     = pt[0];
-  l     = 0;
-  s     = 1;
-  list  = (vrna_hx_t *)vrna_alloc(sizeof(vrna_hx_t) * n / 2);
-  stack = (int *)vrna_alloc(sizeof(int) * n / 2);
+  list = NULL;
 
-  stack[s] = 1;
+  if (pt) {
+    n     = pt[0];
+    l     = 0;
+    s     = 1;
+    list  = (vrna_hx_t *)vrna_alloc(sizeof(vrna_hx_t) * (n / 2 + 2));
+    stack = (int *)vrna_alloc(sizeof(int) * (n / 2 + 2));
 
-  do {
-    for (i = stack[s--]; i <= n; i++) {
-      if (pt[i] > (short)i) {
-        /* found a base pair */
-        k = i;
-        /* go through stack */
-        for (; pt[k + 1] == pt[k] - 1; k++);
-        list[l].start   = i;
-        list[l].end     = pt[i];
-        list[l].length  = k - i + 1;
-        list[l].up5     = list[l].up3 = 0;
-        l++;
-        stack[++s]  = pt[i] + 1;
-        stack[++s]  = k + 1;
-        break;
-      } else if (pt[i]) {
-        /* end of region */
-        break;
+    stack[s] = 1;
+
+    do {
+      for (i = stack[s--]; i <= n; i++) {
+        if (pt[i] > (short)i) {
+          /* found a base pair */
+          k = i;
+          /* go through stack */
+          for (; pt[k + 1] == pt[k] - 1; k++);
+          list[l].start   = i;
+          list[l].end     = pt[i];
+          list[l].length  = k - i + 1;
+          list[l].up5     = list[l].up3 = 0;
+          l++;
+          stack[++s]  = pt[i] + 1;
+          stack[++s]  = k + 1;
+          break;
+        } else if (pt[i]) {
+          /* end of region */
+          break;
+        }
       }
-    }
-  } while (s > 0);
+    } while (s > 0);
 
-  list          = vrna_realloc(list, (l + 1) * sizeof(vrna_hx_t));
-  list[l].start = list[l].end = list[l].length = list[l].up5 = list[l].up3 = 0;
+    list          = vrna_realloc(list, (l + 1) * sizeof(vrna_hx_t));
+    list[l].start = list[l].end = list[l].length = list[l].up5 = list[l].up3 = 0;
+
+    free(stack);
+  }
 
-  free(stack);
   return list;
 }
 
@@ -972,58 +1106,62 @@ vrna_hx_merge(const vrna_hx_t *list,
   int       merged, i, j, s, neighbors, n;
   vrna_hx_t *merged_list;
 
-  for (n = 0; list[n].length > 0; n++); /* check size of list */
+  merged_list = NULL;
 
-  merged_list = (vrna_hx_t *)vrna_alloc(sizeof(vrna_hx_t) * (n + 1));
-  memcpy(merged_list, list, sizeof(vrna_hx_t) * (n + 1));
+  if (list) {
+    for (n = 0; list[n].length > 0; n++); /* check size of list */
 
-  s = n + 1;
+    merged_list = (vrna_hx_t *)vrna_alloc(sizeof(vrna_hx_t) * (n + 1));
+    memcpy(merged_list, list, sizeof(vrna_hx_t) * (n + 1));
 
-  do {
-    merged = 0;
-    for (i = 1; merged_list[i].length > 0; i++) {
-      /*
-       * GOAL: merge two consecutive helices i and i-1, if i-1
-       * subsumes i, and not more than i
-       */
+    s = n + 1;
 
-      /* 1st, check for neighbors */
-      neighbors = 0;
-      for (j = i + 1; merged_list[j].length > 0; j++) {
-        if (merged_list[j].start > merged_list[i - 1].end)
-          break;
+    do {
+      merged = 0;
+      for (i = 1; merged_list[i].length > 0; i++) {
+        /*
+         * GOAL: merge two consecutive helices i and i-1, if i-1
+         * subsumes i, and not more than i
+         */
 
-        if (merged_list[j].start < merged_list[i].end)
+        /* 1st, check for neighbors */
+        neighbors = 0;
+        for (j = i + 1; merged_list[j].length > 0; j++) {
+          if (merged_list[j].start > merged_list[i - 1].end)
+            break;
+
+          if (merged_list[j].start < merged_list[i].end)
+            continue;
+
+          neighbors = 1;
+        }
+        if (neighbors)
           continue;
 
-        neighbors = 1;
+        /* check if we may merge i with i-1 */
+        if (merged_list[i].end < merged_list[i - 1].end) {
+          merged_list[i - 1].up5 += merged_list[i].start
+                                    - merged_list[i - 1].start
+                                    - merged_list[i - 1].length
+                                    - merged_list[i - 1].up5
+                                    + merged_list[i].up5;
+          merged_list[i - 1].up3 += merged_list[i - 1].end
+                                    - merged_list[i - 1].length
+                                    - merged_list[i - 1].up3
+                                    - merged_list[i].end
+                                    + merged_list[i].up3;
+          merged_list[i - 1].length += merged_list[i].length;
+          /* splice out helix i */
+          memmove(merged_list + i, merged_list + i + 1, sizeof(vrna_hx_t) * (n - i));
+          s--;
+          merged = 1;
+          break;
+        }
       }
-      if (neighbors)
-        continue;
+    } while (merged);
 
-      /* check if we may merge i with i-1 */
-      if (merged_list[i].end < merged_list[i - 1].end) {
-        merged_list[i - 1].up5 += merged_list[i].start
-                                  - merged_list[i - 1].start
-                                  - merged_list[i - 1].length
-                                  - merged_list[i - 1].up5
-                                  + merged_list[i].up5;
-        merged_list[i - 1].up3 += merged_list[i - 1].end
-                                  - merged_list[i - 1].length
-                                  - merged_list[i - 1].up3
-                                  - merged_list[i].end
-                                  + merged_list[i].up3;
-        merged_list[i - 1].length += merged_list[i].length;
-        /* splice out helix i */
-        memmove(merged_list + i, merged_list + i + 1, sizeof(vrna_hx_t) * (n - i));
-        s--;
-        merged = 1;
-        break;
-      }
-    }
-  } while (merged);
-
-  merged_list = vrna_realloc(merged_list, sizeof(vrna_hx_t) * s);
+    merged_list = vrna_realloc(merged_list, sizeof(vrna_hx_t) * s);
+  }
 
   return merged_list;
 }
@@ -1061,11 +1199,313 @@ vrna_db_to_element_string(const char *structure)
 }
 
 
+PUBLIC char *
+vrna_abstract_shapes(const char   *structure,
+                     unsigned int level)
+{
+  if (structure) {
+    if (level > 5)
+      level = 5;
+
+    return db2shapes(structure, level);
+  }
+
+  return NULL;
+}
+
+
+PUBLIC char *
+vrna_abstract_shapes_pt(const short   *pt,
+                        unsigned int  level)
+{
+  if (pt) {
+    if (level > 5)
+      level = 5;
+
+    return db2shapes_pt(pt, (unsigned int)pt[0], level);
+  }
+
+  return NULL;
+}
+
+
 /*
  #####################################
  # BEGIN OF STATIC HELPER FUNCTIONS  #
  #####################################
  */
+PRIVATE INLINE struct shrep *
+shrep_insert_after(struct shrep *target,
+                   char         character)
+{
+  struct shrep *entry, *ptr;
+
+  entry             = (struct shrep *)vrna_alloc(sizeof(struct shrep));
+  entry->character  = character;
+  entry->pred       = NULL;
+  entry->succ       = NULL;
+
+  if (target) {
+    for (ptr = target; ptr->succ; ptr = ptr->succ);
+    entry->pred = ptr;
+    ptr->succ   = entry;
+  }
+
+  return entry;
+}
+
+
+PRIVATE INLINE struct shrep *
+shrep_insert_before(struct shrep  *target,
+                    char          character)
+{
+  struct shrep *entry, *ptr;
+
+  entry             = (struct shrep *)vrna_alloc(sizeof(struct shrep));
+  entry->character  = character;
+  entry->pred       = NULL;
+  entry->succ       = NULL;
+
+  if (target) {
+    for (ptr = target; ptr->pred; ptr = ptr->pred);
+    entry->succ = ptr;
+    ptr->pred   = entry;
+  }
+
+  return entry;
+}
+
+
+PRIVATE INLINE void
+shrep_concat(struct shrep **target,
+             struct shrep *suffix)
+{
+  struct shrep *ptr_s, *ptr_p;
+
+  ptr_p = *target;
+  ptr_s = suffix;
+
+  if (ptr_p)
+    for (; ptr_p->succ; ptr_p = ptr_p->succ);
+
+  if (ptr_s)
+    for (; ptr_s->pred; ptr_s = ptr_s->pred);
+
+  if (!ptr_p) {
+    *target = ptr_s;
+  } else if (ptr_s) {
+    ptr_p->succ = ptr_s;
+    ptr_s->pred = ptr_p;
+  }
+}
+
+
+PRIVATE INLINE char *
+db2shapes(const char    *structure,
+          unsigned int  level)
+{
+  unsigned int  n;
+  char          *SHAPE;
+  short         *pt;
+
+  n   = strlen(structure);
+  pt  = vrna_ptable(structure);
+
+  SHAPE = db2shapes_pt(pt, n, level);
+
+  free(pt);
+
+  return SHAPE;
+}
+
+
+PRIVATE INLINE char *
+db2shapes_pt(const short  *pt,
+             unsigned int n,
+             unsigned int level)
+{
+  unsigned int  start;
+  struct shrep  *ptr, *ptr2;
+  char          *SHAPE;
+
+  SHAPE = NULL;
+  start = 1;
+
+  ptr = get_shrep(pt, start, n, level);
+
+  if (ptr) {
+    SHAPE = (char *)vrna_alloc(sizeof(char) * (n + 1));
+
+    for (; ptr->pred; ptr = ptr->pred);
+
+    for (n = 0; ptr; n++) {
+      SHAPE[n]  = ptr->character;
+      ptr2      = ptr;
+      ptr       = ptr->succ;
+      free(ptr2);
+    }
+
+    free(ptr);
+
+    SHAPE     = vrna_realloc(SHAPE, sizeof(char) * (n + 1));
+    SHAPE[n]  = '\0';
+  }
+
+  return SHAPE;
+}
+
+
+PRIVATE INLINE struct shrep *
+get_shrep(const short   *pt,
+          unsigned int  start,
+          unsigned int  end,
+          unsigned int  level)
+{
+  struct shrep  *shape_string, *substring, *sub5, *sub3;
+  unsigned int  components, i, k, l, ext, u5, u3, cnt;
+  unsigned char no_stack, bulge;
+
+  shape_string = NULL;
+
+  /* find out if there is more than one component */
+  for (i = start, components = 0; i <= end; i++) {
+    if (i < pt[i]) {
+      components++;
+      i = pt[i];
+      if (components > 1)
+        break;
+    }
+  }
+
+  /* find out if we process the exterior loop */
+  for (i = start - 1, ext = 1; i > 0; i--) {
+    if (pt[i] > end) {
+      ext = 0;
+      break;
+    }
+  }
+
+  for (; start <= end; start++) {
+    if (start < pt[start]) {
+      /* we have base pair (start, pt[start]) */
+      substring = sub5 = sub3 = NULL;
+      k         = start + 1;
+      l         = pt[start] - 1;
+
+      while (1) {
+        u5  = 0;
+        u3  = 0;
+
+        for (; pt[k] == 0; k++, u5++);  /* skip unpaired 5' side */
+        for (; pt[l] == 0; l--, u3++);  /* skip unpaired 3' side */
+
+        if (k >= l) {
+          /* hairpin loop */
+          if (level == 0)
+            for (cnt = 0; cnt < u5; cnt++)
+              substring = shrep_insert_after(substring, SHAPES_UP);
+
+          break;
+        } else {
+          if (pt[k] != l) {
+            /* multi branch loop or external loop */
+            substring = get_shrep(pt, k, l, level);
+            if (level == 1) {
+              if (u5)
+                sub5 = shrep_insert_after(sub5, SHAPES_UP);
+
+              if (u3)
+                sub3 = shrep_insert_before(sub3, SHAPES_UP);
+            } else if (level == 0) {
+              for (cnt = 0; cnt < u5; cnt++)
+                sub5 = shrep_insert_after(sub5, SHAPES_UP);
+
+              for (cnt = 0; cnt < u3; cnt++)
+                sub3 = shrep_insert_before(sub3, SHAPES_UP);
+            }
+
+            break;
+          } else {
+            /* interior loop with enclosed pair (k,l) */
+            no_stack  = (u5 + u3 > 0) ? 1 : 0;
+            bulge     = ((u5 > 0) && (u3 > 0)) ? 1 : 0;
+
+            switch (level) {
+              case 4:
+                if (bulge) {
+                  sub5  = shrep_insert_after(sub5, SHAPES_OPEN);
+                  sub3  = shrep_insert_before(sub3, SHAPES_CLOSE);
+                }
+
+                break;
+
+              case 3:
+                if (no_stack) {
+                  sub5  = shrep_insert_after(sub5, SHAPES_OPEN);
+                  sub3  = shrep_insert_before(sub3, SHAPES_CLOSE);
+                }
+
+                break;
+
+              case 2: /* fall through */
+              case 1:
+                if (no_stack) {
+                  if (u5)
+                    sub5 = shrep_insert_after(sub5, SHAPES_UP);
+
+                  if (u3)
+                    sub3 = shrep_insert_before(sub3, SHAPES_UP);
+
+                  sub5  = shrep_insert_after(sub5, SHAPES_OPEN);
+                  sub3  = shrep_insert_before(sub3, SHAPES_CLOSE);
+                }
+
+                break;
+
+              case 0:
+                for (unsigned int cnt = 0; cnt < u5; cnt++)
+                  sub5 = shrep_insert_after(sub5, SHAPES_UP);
+
+                for (unsigned int cnt = 0; cnt < u3; cnt++)
+                  sub3 = shrep_insert_before(sub3, SHAPES_UP);
+
+                sub5  = shrep_insert_after(sub5, SHAPES_OPEN);
+                sub3  = shrep_insert_before(sub3, SHAPES_CLOSE);
+                break;
+
+              default:
+                break;
+            }
+
+            k++;
+            l--;
+          }
+        }
+      }
+
+      sub5 = shrep_insert_before(sub5, SHAPES_OPEN);
+      shrep_concat(&sub5, substring);
+      shrep_concat(&sub5, sub3);
+      sub5 = shrep_insert_after(sub5, SHAPES_CLOSE);
+      shrep_concat(&shape_string, sub5);
+
+      start = pt[start];
+    } else if ((pt[start] == 0) && (level < 3)) {
+      if (level == 0) {
+        shape_string = shrep_insert_after(shape_string, SHAPES_UP);
+      } else if ((level == 1) ||
+                 ((components < 2) && (ext == 0))) {
+        shape_string = shrep_insert_after(shape_string, SHAPES_UP);
+        for (; (start <= end) && (pt[start] == 0); start++);
+        start--;
+      }
+    }
+  }
+
+  return shape_string;
+}
+
+
 PRIVATE INLINE void
 flatten_brackets(char       *string,
                  const char pair[3],
@@ -1187,12 +1627,13 @@ wrap_get_plist(vrna_mx_pf_t     *matrices,
 
           /* check if we've already seen this pair */
           for (k = 0; k < count; k++)
-            if (((pl)[k].i == ptr->i) && ((pl)[k].j == ptr->j))
+            if (((pl)[k].i == ptr->i) &&
+                ((pl)[k].j == ptr->j))
               break;
 
           (pl)[k].i     = ptr->i;
           (pl)[k].j     = ptr->j;
-          (pl)[k].type  = VRNA_PLIST_TYPE_GQUAD;
+          (pl)[k].type  = ptr->type;
           if (k == count) {
             (pl)[k].p = ptr->p;
             count++;
@@ -1258,7 +1699,9 @@ wrap_plist(vrna_fold_compound_t *vc,
       }
 
       /* check for presence of gquadruplex */
-      if (gquad && (S[i] == 3) && (S[j] == 3)) {
+      if ((gquad) &&
+          (S[i] == 3) &&
+          (S[j] == 3)) {
         /* add probability of a gquadruplex at position (i,j)
          * for dot_plot
          */
@@ -1278,13 +1721,14 @@ wrap_plist(vrna_fold_compound_t *vc,
 
           /* check if we've already seen this pair */
           for (k = 0; k < count; k++)
-            if (((pl)[k].i == ptr->i) && ((pl)[k].j == ptr->j) &&
-                ((pl)[k].type == VRNA_PLIST_TYPE_BASEPAIR))
+            if (((pl)[k].i == ptr->i) &&
+                ((pl)[k].j == ptr->j) &&
+                ((pl)[k].type == VRNA_PLIST_TYPE_TRIPLE))
               break;
 
           (pl)[k].i     = ptr->i;
           (pl)[k].j     = ptr->j;
-          (pl)[k].type  = VRNA_PLIST_TYPE_BASEPAIR;
+          (pl)[k].type  = ptr->type;
           if (k == count) {
             (pl)[k].p = ptr->p;
             count++;
@@ -1423,9 +1867,11 @@ assign_elements_pair(short  *pt,
 
 #ifndef VRNA_DISABLE_BACKWARD_COMPATIBILITY
 
-/*###########################################*/
-/*# deprecated functions below              #*/
-/*###########################################*/
+/*
+ * ###########################################
+ * # deprecated functions below              #
+ *###########################################
+ */
 
 
 PUBLIC char *
