@@ -20,6 +20,8 @@
 #include "ViennaRNA/params/io.h"
 #include "ViennaRNA/2Dfold.h"
 #include "ViennaRNA/2Dpfold.h"
+
+#include "gengetopt_helpers.h"
 #include "RNA2Dfold_cmdl.h"
 
 #include "ViennaRNA/color_output.inc"
@@ -124,8 +126,7 @@ main(int  argc,
 #endif
 
   /* get energy parameter file name */
-  if (args_info.paramFile_given)
-    ParamFile = strdup(args_info.paramFile_arg);
+  ggo_get_read_paramFile(args_info, &md);
 
   /* do not allow GU pairs ? */
   if (args_info.noGU_given)
@@ -135,6 +136,10 @@ main(int  argc,
   if (args_info.noClosingGU_given)
     md.noGUclosure = no_closingGU = 1;
 
+  /* set salt concentration */
+  if (args_info.salt_given)
+    md.salt = args_info.salt_arg;
+
   /* pf scaling factor */
   if (args_info.pfScale_given)
     md.sfact = args_info.pfScale_arg;
@@ -162,6 +167,9 @@ main(int  argc,
       }
     }
   }
+
+  ggo_geometry_settings(args_info, &md);
+
   /* free allocated memory of command line data structure */
   RNA2Dfold_cmdline_parser_free(&args_info);
 
@@ -170,13 +178,6 @@ main(int  argc,
    # begin actual program code
    #############################################
    */
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
-
   istty = isatty(fileno(stdout)) && isatty(fileno(stdin));
 
   /*
