@@ -27,9 +27,12 @@
 #include "ViennaRNA/io/utils.h"
 #include "ViennaRNA/commands.h"
 #include "ViennaRNA/constraints/SHAPE.h"
+#include "ViennaRNA/constraints/soft_special.h"
+
 #include "RNALfold_cmdl.h"
-#include "gengetopt_helper.h"
+#include "gengetopt_helpers.h"
 #include "input_id_helpers.h"
+#include "modified_bases_helpers.h"
 
 #include "ViennaRNA/color_output.inc"
 
@@ -76,30 +79,33 @@ main(int  argc,
   vrna_md_t                   md;
   vrna_cmd_t                  commands;
   dataset_id                  id_control;
+  vrna_sc_mod_param_t         *mod_params;
 
-  ParamFile       = ns_bases = NULL;
-  do_backtrack    = 1;
-  noconv          = 0;
-  backtrack       = 0;
-  dangles         = 2;
-  maxdist         = 150;
-  zsc             = 0;
-  zsc_pre         = 0;
-  zsc_subsumed    = 0;
-  min_z           = -2.0;
-  gquad           = 0;
-  rec_type        = read_opt = 0;
-  rec_id          = rec_sequence = orig_sequence = NULL;
-  rec_rest        = NULL;
-  outfile         = NULL;
-  infile          = NULL;
-  input           = NULL;
-  output          = NULL;
-  tofile          = 0;
-  filename_full   = 0;
-  command_file    = NULL;
-  commands        = NULL;
-  file_pos_start  = -1;
+  ParamFile           = ns_bases = NULL;
+  do_backtrack        = 1;
+  noconv              = 0;
+  backtrack           = 0;
+  dangles             = 2;
+  maxdist             = 150;
+  zsc                 = 0;
+  zsc_pre             = 0;
+  zsc_subsumed        = 0;
+  min_z               = -2.0;
+  gquad               = 0;
+  rec_type            = read_opt = 0;
+  rec_id              = rec_sequence = orig_sequence = NULL;
+  rec_rest            = NULL;
+  outfile             = NULL;
+  infile              = NULL;
+  input               = NULL;
+  output              = NULL;
+  tofile              = 0;
+  filename_full       = 0;
+  command_file        = NULL;
+  commands            = NULL;
+  file_pos_start      = -1;
+  verbose             = 0;
+  mod_params          = NULL;
 
   /* apply default model details */
   vrna_md_set_default(&md);
@@ -156,6 +162,10 @@ main(int  argc,
   if (args_info.noClosingGU_given)
     md.noGUclosure = no_closingGU = 1;
 
+  /* set salt concentration */
+  if (args_info.salt_given)
+    md.salt = args_info.salt_arg;
+
   /* do not convert DNA nucleotide "T" to appropriate RNA "U" */
   if (args_info.noconv_given)
     noconv = 1;
@@ -165,8 +175,7 @@ main(int  argc,
     md.energy_set = energy_set = args_info.energyModel_arg;
 
   /* take another energy parameter set */
-  if (args_info.paramFile_given)
-    ParamFile = strdup(args_info.paramFile_arg);
+  ggo_get_read_paramFile(args_info, &md);
 
   /* Allow other pairs in addition to the usual AU,GC,and GU pairs */
   if (args_info.nsp_given)
@@ -239,6 +248,12 @@ main(int  argc,
     exit(EXIT_FAILURE);
   }
 
+  ggo_get_modified_base_settings(args_info,
+                                 mod_params,
+                                 &(md));
+
+  ggo_geometry_settings(args_info, &md);
+
   /* free allocated memory of command line data structure */
   RNALfold_cmdline_parser_free(&args_info);
 
@@ -258,12 +273,6 @@ main(int  argc,
     input = stdin;
   }
 
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
 
   if (command_file != NULL)
     commands = vrna_file_commands_read(command_file, VRNA_CMD_PARSE_HC | VRNA_CMD_PARSE_SC);
@@ -291,9 +300,11 @@ main(int  argc,
      # init everything according to the data we've read
      ########################################################
      */
-    char  *SEQ_ID       = NULL;
-    char  *v_file_name  = NULL;
-    char  *tmp_string   = NULL;
+    size_t  **mod_positions, mod_param_sets;
+    char    *SEQ_ID       = NULL;
+    char    *v_file_name  = NULL;
+    char    *tmp_string   = NULL;
+
     /*
      ########################################################
      # init everything according to the data we've read
@@ -337,12 +348,18 @@ main(int  argc,
 
     length = (int)strlen(rec_sequence);
 
+    mod_positions = mod_positions_seq_prepare(rec_sequence,
+                                              mod_params,
+                                              verbose,
+                                              &mod_param_sets);
+
     /* convert DNA alphabet to RNA if not explicitely switched off */
     if (!noconv)
       vrna_seq_toRNA(rec_sequence);
 
     /* store case-unmodified sequence */
     orig_sequence = strdup(rec_sequence);
+
     /* convert sequence to uppercase letters only */
     vrna_seq_toupper(rec_sequence);
 
@@ -372,6 +389,12 @@ main(int  argc,
                                  VRNA_OPTION_WINDOW);
     }
 
+    /* apply modified base support if requested */
+    mod_bases_apply(vc,
+                    mod_param_sets,
+                    mod_positions,
+                    mod_params);
+
 #ifdef VRNA_WITH_SVM
     if (zsc) {
       unsigned int zsc_options = VRNA_ZSCORE_FILTER_ON;
@@ -459,6 +482,13 @@ main(int  argc,
   free(command_file);
   vrna_commands_free(commands);
 
+  if (mod_params) {
+    for (vrna_sc_mod_param_t *ptr = mod_params; *ptr != NULL; ptr++)
+      vrna_sc_mod_parameters_free(*ptr);
+
+    free(mod_params);
+  }
+
   free_id_data(id_control);
 
   return EXIT_SUCCESS;
