@@ -21,6 +21,8 @@
 #include "ViennaRNA/params/io.h"
 #include "ViennaRNA/subopt.h"
 #include "ViennaRNA/duplex.h"
+
+#include "gengetopt_helpers.h"
 #include "RNAaliduplex_cmdl.h"
 
 
@@ -85,6 +87,12 @@ main(int  argc,
   if (args_info.noClosingGU_given)
     no_closingGU = 1;
 
+  if (args_info.salt_given)
+    salt = args_info.salt_arg;
+
+  if (args_info.saltInit_given)
+    saltDPXInit = (int)(args_info.saltInit_arg * 100);
+
   /* take another energy parameter set */
   if (args_info.paramFile_given)
     ParamFile = strdup(args_info.paramFile_arg);
@@ -128,6 +136,8 @@ main(int  argc,
       vrna_message_error("unequal number of seqs in alignments");
   }
 
+  ggo_geometry_settings(args_info, NULL);
+
   /* free allocated memory of command line data structure */
   RNAaliduplex_cmdline_parser_free(&args_info);
 
