@@ -23,6 +23,7 @@
 #include "ViennaRNA/constraints/hard.h"
 #include "ViennaRNA/constraints/soft.h"
 #include "ViennaRNA/constraints/SHAPE.h"
+#include "ViennaRNA/constraints/soft_special.h"
 #include "ViennaRNA/io/file_formats.h"
 #include "ViennaRNA/io/utils.h"
 #include "ViennaRNA/cofold.h"
@@ -39,8 +40,9 @@
 #include "ViennaRNA/datastructures/stream_output.h"
 
 #include "RNAcofold_cmdl.h"
-#include "gengetopt_helper.h"
+#include "gengetopt_helpers.h"
 #include "input_id_helpers.h"
+#include "modified_bases_helpers.h"
 #include "ViennaRNA/color_output.inc"
 #include "parallel_helpers.h"
 
@@ -75,6 +77,8 @@ struct options {
   char            *shape_method;
   char            *shape_conversion;
 
+  vrna_sc_mod_param_t *mod_params;
+
   int             csv_output;
   int             csv_header;
   char            csv_output_delim;
@@ -199,6 +203,8 @@ init_default_options(struct options *opt)
   opt->shape_method     = NULL;
   opt->shape_conversion = NULL;
 
+  opt->mod_params         = NULL;
+
   opt->csv_output       = 0;    /* flag indicating whether we produce one-line outputs, a.k.a. CSV */
   opt->csv_header       = 1;    /* print header for one-line output */
   opt->csv_output_delim = ',';  /* delimiting character for one-line output */
@@ -318,6 +324,10 @@ main(int  argc,
     opt.concentration_file  = strdup(args_info.concfile_arg);
     opt.doC                 = opt.doT = opt.pf = 1;
   }
+  
+  /* Salt duplex init */
+  if (args_info.saltInit_given)
+    opt.md.saltDPXInit = args_info.saltInit_arg;
 
   /* partition function settings */
   if (args_info.partfunc_given) {
@@ -365,6 +375,10 @@ main(int  argc,
     opt.commands = vrna_file_commands_read(args_info.commands_arg,
                                            VRNA_CMD_PARSE_HC | VRNA_CMD_PARSE_SC);
 
+  ggo_get_modified_base_settings(args_info,
+                                 opt.mod_params,
+                                 &(opt.md));
+
   /* filename sanitize delimiter */
   if (args_info.filename_delim_given)
     opt.filename_delim = strdup(args_info.filename_delim_arg);
@@ -440,6 +454,8 @@ main(int  argc,
       opt.keep_order = 0;
   }
 
+  ggo_geometry_settings(args_info, &(opt.md));
+
   input_files = collect_unnamed_options(&args_info, &num_input);
 
   /* free allocated memory of command line data structure */
@@ -517,6 +533,13 @@ main(int  argc,
   vrna_commands_free(opt.commands);
   free(opt.concentration_file);
 
+  if (opt.mod_params) {
+    for (vrna_sc_mod_param_t *ptr = opt.mod_params; *ptr != NULL; ptr++)
+      vrna_sc_mod_parameters_free(*ptr);
+
+    free(opt.mod_params);
+  }
+
   free_id_data(opt.id_control);
 
   return EXIT_SUCCESS;
@@ -645,6 +668,8 @@ process_record(struct record_data *record)
   vrna_ep_t             *prAB, *prAA, *prBB, *prA, *prB, *mfAB, *mfAA, *mfBB, *mfA, *mfB;
   struct options        *opt;
   struct output_stream  *o_stream;
+  size_t                **mod_positions;
+  size_t                mod_param_sets;
 
   mfAB            = mfAA = mfBB = mfA = mfB = NULL;
   prAB            = prAA = prBB = prA = prB = NULL;
@@ -654,6 +679,11 @@ process_record(struct record_data *record)
   sequence        = strdup(record->sequence);
   rec_rest        = record->rest;
 
+  mod_positions   = mod_positions_seq_prepare(sequence,
+                                              opt->mod_params,
+                                              opt->verbose,
+                                              &mod_param_sets);
+
   /* convert DNA alphabet to RNA if not explicitely switched off */
   if (!opt->noconv) {
     vrna_seq_toRNA(sequence);
@@ -759,6 +789,12 @@ process_record(struct record_data *record)
   if (opt->commands)
     vrna_commands_apply(vc, opt->commands, VRNA_CMD_PARSE_HC | VRNA_CMD_PARSE_SC);
 
+  /* apply modified base support if requested */
+  mod_bases_apply(vc,
+                  mod_param_sets,
+                  mod_positions,
+                  opt->mod_params);
+
   if (opt->doC) {
     if (opt->concentration_file) {
       /* read from file */
@@ -1228,77 +1264,50 @@ write_csv_header(FILE           *output,
 {
   vrna_cstr_t stream = vrna_cstr(100, output);
 
+  vrna_cstr_printf(stream,
+                   "seq_num%c"
+                   "seq_id%c"
+                   "seq%c"
+                   "mfe_struct%c"
+                   "mfe",
+                   opt->csv_output_delim,
+                   opt->csv_output_delim,
+                   opt->csv_output_delim,
+                   opt->csv_output_delim);
+
   /* compose header line for CSV output */
   if (opt->pf) {
     if (opt->md.compute_bpp) {
-      if (opt->doT) {
-        vrna_cstr_printf(stream,
-                         "seq_num%c"
-                         "seq_id%c"
-                         "seq%c"
-                         "mfe_struct%c"
-                         "mfe%c"
-                         "bpp_string%c"
-                         "ensemble_energy%c"
-                         "AB%c"
-                         "AA%c"
-                         "BB%c"
-                         "A%c"
-                         "B\n",
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim);
-      } else {
-        vrna_cstr_printf(stream,
-                         "seq_num%c"
-                         "seq_id%c"
-                         "seq%c"
-                         "mfe_struct%c"
-                         "mfe%c",
-                         "bpp_string%c"
-                         "ensemble_energy\n",
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim,
-                         opt->csv_output_delim);
-      }
-    } else {
       vrna_cstr_printf(stream,
-                       "seq_num%c"
-                       "seq_id%c"
-                       "seq%c"
-                       "mfe_struct%c"
-                       "mfe%c",
-                       "ensemble_energy\n",
+                       "%cbpp_string",
+                       opt->csv_output_delim);
+    }
+
+    vrna_cstr_printf(stream,
+                     "%censemble_energy%c"
+                     "prob_mfe%c"
+                     "dG_binding",
+                     opt->csv_output_delim,
+                     opt->csv_output_delim,
+                     opt->csv_output_delim);
+
+    if (opt->doT) {
+      vrna_cstr_printf(stream,
+                       "%cAB%c"
+                       "AA%c"
+                       "BB%c"
+                       "A%c"
+                       "B",
                        opt->csv_output_delim,
                        opt->csv_output_delim,
                        opt->csv_output_delim,
                        opt->csv_output_delim,
                        opt->csv_output_delim);
     }
-  } else {
-    vrna_cstr_printf(stream,
-                     "seq_num%c"
-                     "seq_id%c"
-                     "seq%c"
-                     "mfe_struct%c"
-                     "mfe\n",
-                     opt->csv_output_delim,
-                     opt->csv_output_delim,
-                     opt->csv_output_delim,
-                     opt->csv_output_delim);
   }
 
+  vrna_cstr_printf(stream, "\n");
+
   vrna_cstr_fflush(stream);
   vrna_cstr_close(stream);
 }
