@@ -22,6 +22,8 @@
 #ifdef _OPENMP
 #include <omp.h>
 #endif
+
+#include "gengetopt_helpers.h"
 #include "RNAdos_cmdl.h"
 
 
@@ -74,9 +76,9 @@ free_hash_entry_dos(void *hash_entry)
 static vrna_hash_table_t
 create_hashtable(int hashbits)
 {
-  vrna_callback_ht_free_entry       *my_free          = free_hash_entry_dos;
-  vrna_callback_ht_compare_entries  *my_comparison    = hash_comparison_dos;
-  vrna_callback_ht_hash_function    *my_hash_function = hash_function_dos;
+  vrna_ht_free_f       my_free          = free_hash_entry_dos;
+  vrna_ht_cmp_f  my_comparison    = hash_comparison_dos;
+  vrna_ht_hashfunc_f    my_hash_function = hash_function_dos;
   vrna_hash_table_t                 ht                = vrna_ht_init(hashbits,
                                                                      my_comparison,
                                                                      my_hash_function,
@@ -778,7 +780,11 @@ main(int  argc,
       exit(1);
     }
   } else {
-    rnaSequence = args_info.sequence_arg;
+    rnaSequence = strdup(args_info.sequence_arg);
+    if ((rnaSequence == NULL) || (*rnaSequence == '\0')){
+      fprintf(stderr, "No RNA sequence given!");
+      exit(1);
+    }
   }
 
   /* temperature */
@@ -794,6 +800,9 @@ main(int  argc,
       md.dangles = dangles = args_info.dangles_arg;
   }
 
+  if (args_info.salt_given)
+    md.salt = args_info.salt_arg;
+
   if (args_info.verbose_given)
     verbose = 1;
 
@@ -812,19 +821,13 @@ main(int  argc,
   }
 
   /* get energy parameter file name */
-  if (args_info.paramFile_given)
-    ParamFile = strdup(args_info.paramFile_arg);
+  ggo_get_read_paramFile(args_info, &md);
+
+  ggo_geometry_settings(args_info, &md);
 
   /* free allocated memory of command line data structure */
   RNAdos_cmdline_parser_free(&args_info);
 
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
-
   if (verbose)
     printf("%s\n", rnaSequence);
 
