@@ -39,6 +39,7 @@
 #include "ViennaRNA/constraints/basic.h"
 #include "ViennaRNA/constraints/SHAPE.h"
 #include "ViennaRNA/constraints/ligand.h"
+#include "ViennaRNA/constraints/soft_special.h"
 #include "ViennaRNA/structured_domains.h"
 #include "ViennaRNA/unstructured_domains.h"
 #include "ViennaRNA/io/file_formats.h"
@@ -50,8 +51,9 @@
 #include "ViennaRNA/color_output.inc"
 
 #include "RNAfold_cmdl.h"
-#include "gengetopt_helper.h"
+#include "gengetopt_helpers.h"
 #include "input_id_helpers.h"
+#include "modified_bases_helpers.h"
 #include "parallel_helpers.h"
 
 
@@ -82,6 +84,8 @@ struct options {
   char            *shape_method;
   char            *shape_conversion;
 
+  vrna_sc_mod_param_t *mod_params;
+
   int             jobs;
   int             tofile;
   char            *output_file;
@@ -384,6 +388,8 @@ init_default_options(struct options *opt)
   opt->shape_method     = NULL;
   opt->shape_conversion = NULL;
 
+  opt->mod_params         = NULL;
+
   opt->jobs               = 1;
   opt->tofile             = 0;
   opt->output_file        = NULL;
@@ -499,6 +505,10 @@ main(int  argc,
   if (args_info.commands_given)
     opt.cmds = vrna_file_commands_read(args_info.commands_arg, VRNA_CMD_PARSE_DEFAULTS);
 
+  ggo_get_modified_base_settings(args_info, opt.mod_params, &(opt.md));
+
+  ggo_geometry_settings(args_info, &(opt.md));
+
   /* filename sanitize delimiter */
   if (args_info.filename_delim_given)
     opt.filename_delim = strdup(args_info.filename_delim_arg);
@@ -627,6 +637,13 @@ main(int  argc,
   free(opt.filename_delim);
   vrna_commands_free(opt.cmds);
 
+  if (opt.mod_params) {
+    for (vrna_sc_mod_param_t *ptr = opt.mod_params; *ptr != NULL; ptr++)
+      vrna_sc_mod_parameters_free(*ptr);
+
+    free(opt.mod_params);
+  }
+
   free_id_data(opt.id_control);
 
   return EXIT_SUCCESS;
@@ -811,11 +828,18 @@ process_record(struct record_data *record)
   double                min_en, energy;
   vrna_fold_compound_t  *vc;
   struct output_stream  *o_stream;
+  size_t                **mod_positions;
+  size_t                mod_param_sets;
 
   opt = record->options;
 
   rec_sequence = strdup(record->sequence);
 
+  mod_positions   = mod_positions_seq_prepare(rec_sequence,
+                                              opt->mod_params,
+                                              opt->verbose,
+                                              &mod_param_sets);
+
   /* convert DNA alphabet to RNA if not explicitely switched off */
   if (!opt->noconv) {
     vrna_seq_toRNA(rec_sequence);
@@ -882,6 +906,12 @@ process_record(struct record_data *record)
                         opt->cmds,
                         VRNA_CMD_PARSE_DEFAULTS);
 
+  /* apply modified base support if requested */
+  mod_bases_apply(vc,
+                  mod_param_sets,
+                  mod_positions,
+                  opt->mod_params);
+
   /*
    ########################################################
    # begin actual computations
