@@ -29,7 +29,7 @@
 #include "ViennaRNA/color_output.inc"
 
 #include "RNAheat_cmdl.h"
-#include "gengetopt_helper.h"
+#include "gengetopt_helpers.h"
 #include "input_id_helpers.h"
 #include "parallel_helpers.h"
 
@@ -235,6 +235,8 @@ main(int  argc,
       opt.mpoints = 100;
   }
 
+  ggo_geometry_settings(args_info, &(opt.md));
+
   if (args_info.jobs_given) {
 #if VRNA_WITH_PTHREADS
     int thread_max = max_user_threads();
