@@ -22,6 +22,8 @@
 #include "ViennaRNA/utils/strings.h"
 #include "ViennaRNA/params/io.h"
 #include "ViennaRNA/io/file_formats.h"
+
+#include "gengetopt_helpers.h"
 #include "RNAinverse_cmdl.h"
 
 #include "ViennaRNA/color_output.inc"
@@ -51,7 +53,7 @@ main(int  argc,
   dangles       = 2;
   do_backtrack  = 0;
   pf            = 0;
-  mfe           = 1;
+  mfe           = 0;
   repeat        = 0;
   input_type    = 0;
   input_string  = ns_bases = NULL;
@@ -90,6 +92,9 @@ main(int  argc,
   if (args_info.noClosingGU_given)
     no_closingGU = 1;
 
+  if (args_info.salt_given)
+    salt = args_info.salt_arg;
+
   /* set energy model */
   if (args_info.energyModel_given)
     energy_set = args_info.energyModel_arg;
@@ -122,6 +127,8 @@ main(int  argc,
       if ((*args_info.function_arg == 'p') || (*(args_info.function_arg + 1) == 'p'))
         pf = 1;
     }
+  } else {
+    mfe = 1;
   }
 
   /* set repeat */
@@ -136,16 +143,14 @@ main(int  argc,
   if (args_info.verbose_given)
     inv_verbose = 1;
 
+  /* get energy parameter file name */
+  ggo_get_read_paramFile(args_info, NULL);
+
+  ggo_geometry_settings(args_info, NULL);
+
   /* free allocated memory of command line data structure */
   RNAinverse_cmdline_parser_free(&args_info);
 
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
-
   kT = (temperature + 273.15) * 1.98717 / 1000.0;
 
   istty = (isatty(fileno(stdout)) && isatty(fileno(stdin)));
