@@ -26,6 +26,8 @@
 #include "ViennaRNA/params/io.h"
 #include "ViennaRNA/io/utils.h"
 #include "ViennaRNA/plotting/probabilities.h"
+
+#include "gengetopt_helpers.h"
 #include "RNApaln_cmdl.h"
 
 #define MAXLENGTH  10000
@@ -309,14 +311,14 @@ command_line(int  argc,
   if (args_info.noClosingGU_given)
     no_closingGU = 1;
 
+  /* set salt concentration */
+  if (args_info.salt_given)
+    salt = args_info.salt_arg;
+
   /* set energy model */
   if (args_info.energyModel_given)
     energy_set = args_info.energyModel_arg;
 
-  /* take another energy parameter set */
-  if (args_info.paramFile_given)
-    ParamFile = strdup(args_info.paramFile_arg);
-
   /* Allow other pairs in addition to the usual AU,GC,and GU pairs */
   if (args_info.nsp_given)
     ns_bases = strdup(args_info.nsp_arg);
@@ -373,19 +375,15 @@ command_line(int  argc,
   if (args_info.noconv_given)
     noconv = 1;
 
+  ggo_get_read_paramFile(args_info, NULL);
+  ggo_geometry_settings(args_info, NULL);
+
   /* free allocated memory of command line data structure */
   RNApaln_cmdline_parser_free(&args_info);
 
   /* fprintf(stderr, "%f %f %f %d\n", gapo, gape, seqw, -endgaps); */
   set_paln_params(gapo, gape, seqw, 1 - endgaps);
 
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
-
   if (ns_bases != NULL) {
     nonstandards  = vrna_alloc(33);
     c             = ns_bases;
