@@ -26,12 +26,15 @@
 #include "ViennaRNA/LPfold.h"
 #include "ViennaRNA/params/basic.h"
 #include "ViennaRNA/constraints/SHAPE.h"
+#include "ViennaRNA/constraints/soft_special.h"
 #include "ViennaRNA/io/file_formats.h"
 #include "ViennaRNA/io/utils.h"
 #include "ViennaRNA/commands.h"
+
 #include "RNAplfold_cmdl.h"
-#include "gengetopt_helper.h"
+#include "gengetopt_helpers.h"
 #include "input_id_helpers.h"
+#include "modified_bases_helpers.h"
 
 #include "ViennaRNA/color_output.inc"
 
@@ -151,25 +154,27 @@ main(int  argc,
   vrna_md_t                   md;
   vrna_cmd_t                  commands;
   dataset_id                  id_control;
+  vrna_sc_mod_param_t         *mod_params;
 
-  pUfp          = NULL;
-  dangles       = 2;
-  cutoff        = 0.01;
-  winsize       = 70;
-  pairdist      = 0;
-  unpaired      = 0;
-  simply_putout = plexoutput = openenergies = noconv = 0;
-  binaries      = 0;
-  tempwin       = temppair = tempunpaired = 0;
-  structure     = ParamFile = ns_bases = NULL;
-  rec_type      = read_opt = 0;
-  rec_id        = rec_sequence = orig_sequence = NULL;
-  rec_rest      = NULL;
-  pf_parameters = NULL;
-  filename_full = 0;
-  command_file  = NULL;
-  commands      = NULL;
-  verbose       = 0;
+  pUfp                = NULL;
+  dangles             = 2;
+  cutoff              = 0.01;
+  winsize             = 70;
+  pairdist            = 0;
+  unpaired            = 0;
+  simply_putout       = plexoutput = openenergies = noconv = 0;
+  binaries            = 0;
+  tempwin             = temppair = tempunpaired = 0;
+  structure           = ParamFile = ns_bases = NULL;
+  rec_type            = read_opt = 0;
+  rec_id              = rec_sequence = orig_sequence = NULL;
+  rec_rest            = NULL;
+  pf_parameters       = NULL;
+  filename_full       = 0;
+  command_file        = NULL;
+  commands            = NULL;
+  verbose             = 0;
+  mod_params          = NULL;
 
   set_model_details(&md);
 
@@ -217,6 +222,9 @@ main(int  argc,
   if (args_info.noGU_given)
     md.noGU = noGU = 1;
 
+  if (args_info.salt_given)
+    md.salt = args_info.salt_arg;
+
   /* do not allow weak closing pairs (AU,GU) */
   if (args_info.noClosingGU_given)
     md.noGUclosure = no_closingGU = 1;
@@ -230,8 +238,7 @@ main(int  argc,
     md.energy_set = energy_set = args_info.energyModel_arg;
 
   /* take another energy parameter set */
-  if (args_info.paramFile_given)
-    ParamFile = strdup(args_info.paramFile_arg);
+  ggo_get_read_paramFile(args_info, &md);
 
   /* Allow other pairs in addition to the usual AU,GC,and GU pairs */
   if (args_info.nsp_given)
@@ -295,6 +302,12 @@ main(int  argc,
   if (args_info.commands_given)
     command_file = strdup(args_info.commands_arg);
 
+  ggo_get_modified_base_settings(args_info,
+                                 mod_params,
+                                 &(md));
+
+  ggo_geometry_settings(args_info, &md);
+
   /* free allocated memory of command line data structure */
   RNAplfold_cmdline_parser_free(&args_info);
 
@@ -303,13 +316,6 @@ main(int  argc,
    # begin initializing
    #############################################
    */
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
-
   if (ns_bases != NULL)
     vrna_md_set_nonstandards(&md, ns_bases);
 
@@ -350,7 +356,9 @@ main(int  argc,
   while (
     !((rec_type = vrna_file_fasta_read_record(&rec_id, &rec_sequence, &rec_rest, NULL, read_opt))
       & (VRNA_INPUT_ERROR | VRNA_INPUT_QUIT))) {
-    char *SEQ_ID = NULL;
+    size_t  **mod_positions, mod_param_sets;
+    char    *SEQ_ID = NULL;
+
     /*
      ########################################################
      # init everything according to the data we've read
@@ -366,6 +374,12 @@ main(int  argc,
     length    = (int)strlen(rec_sequence);
     structure = (char *)vrna_alloc(sizeof(char) * (length + 1));
 
+
+    mod_positions = mod_positions_seq_prepare(rec_sequence,
+                                              mod_params,
+                                              verbose,
+                                              &mod_param_sets);
+
     /* convert DNA alphabet to RNA if not explicitely switched off */
     if (!noconv)
       vrna_seq_toRNA(rec_sequence);
@@ -499,6 +513,12 @@ main(int  argc,
       if (commands)
         vrna_commands_apply(fc, commands, VRNA_CMD_PARSE_HC | VRNA_CMD_PARSE_SC);
 
+      /* apply modified base support if requested */
+      mod_bases_apply(fc,
+                      mod_param_sets,
+                      mod_positions,
+                      mod_params);
+
       pf_parameters = vrna_exp_params(&md);
 
       /* prepare data structure for callback */
@@ -641,6 +661,13 @@ rnaplfold_exit:
   free(shape_conversion);
   vrna_commands_free(commands);
 
+  if (mod_params) {
+    for (vrna_sc_mod_param_t *ptr = mod_params; *ptr != NULL; ptr++)
+      vrna_sc_mod_parameters_free(*ptr);
+
+    free(mod_params);
+  }
+
   free_id_data(id_control);
 
   return EXIT_SUCCESS;
