@@ -33,6 +33,8 @@
 #include "ViennaRNA/constraints/basic.h"
 #include "ViennaRNA/constraints/hard.h"
 #include "ViennaRNA/constraints/soft.h"
+
+#include "gengetopt_helpers.h"
 #include "RNAup_cmdl.h"
 
 #define MIN(x, y) (((x) < (y)) ? (x) : (y))
@@ -212,6 +214,19 @@ main(int  argc,
       vrna_strcat_printf(&cmdl_parameters, "--noClosingGU ");
   }
 
+  /* Set salt concentration related parameters */
+  if (args_info.salt_given) {
+    salt = args_info.salt_arg;
+    if (header)
+      vrna_strcat_printf(&cmdl_parameters, "-salt %f ", salt);
+  }
+
+  if (args_info.saltInit_given) {
+    saltDPXInit = (int)(args_info.saltInit_arg * 100);
+    if (header)
+      vrna_strcat_printf(&cmdl_parameters, "--saltInit %f ", args_info.saltInit_arg);
+  }
+
   /* do not convert DNA nucleotide "T" to appropriate RNA "U" */
   if (args_info.noconv_given) {
     noconv = 1;
@@ -360,6 +375,9 @@ main(int  argc,
    * WARNING: after this step ulength_num may not reflect actual number of ulength values anymore */
   adjustUnpairedValues(&unpaired_values);
 
+  ggo_get_read_paramFile(args_info, NULL);
+  ggo_geometry_settings(args_info, NULL);
+
   /* free allocated memory of command line data structure */
   RNAup_cmdline_parser_free(&args_info);
 
@@ -369,13 +387,6 @@ main(int  argc,
    #############################################
    */
 
-  if (ParamFile != NULL) {
-    if (!strcmp(ParamFile, "DNA"))
-      vrna_params_load_DNA_Mathews2004();
-    else
-      vrna_params_load(ParamFile, VRNA_PARAMETER_FORMAT_DEFAULT);
-  }
-
   if (ns_bases != NULL) {
     nonstandards  = vrna_alloc(33);
     c             = ns_bases;
